@@ -147,14 +147,15 @@ function set_cinder_quotas {
 function set_backend_availability_zones {
     ENABLED_BACKENDS=$1
     echo_summary "Setting up backend_availability_zone option \
-        for any enabled backends that do not use the Generic driver. \
-        Availability zones for the Generic driver must coincide with those \
-        created for Nova and Cinder."
+        for any enabled backends that do not use the Generic driver and have \
+        not been set previously. Availability zones for the Generic driver \
+        must coincide with those created for Nova and Cinder."
     local zonenum
     generic_driver='manila.share.drivers.generic.GenericShareDriver'
     for BE in ${ENABLED_BACKENDS//,/ }; do
         share_driver=$(iniget $MANILA_CONF $BE share_driver)
-        if [[ $share_driver != $generic_driver ]]; then
+        az=$(iniget $MANILA_CONF $BE backend_availability_zone)
+        if [[ -z $az && $share_driver != $generic_driver ]]; then
             zone="manila-zone-$((zonenum++))"
             iniset $MANILA_CONF $BE backend_availability_zone $zone
         fi
@@ -168,10 +169,6 @@ function configure_manila {
     fi
     sudo chown $STACK_USER $MANILA_CONF_DIR
 
-    if [[ -f $MANILA_DIR/etc/manila/policy.json ]]; then
-        cp -p $MANILA_DIR/etc/manila/policy.json $MANILA_CONF_DIR
-    fi
-
     # Set the paths of certain binaries
     MANILA_ROOTWRAP=$(get_rootwrap_location manila)
 
@@ -276,7 +273,7 @@ function configure_manila {
     iniset $MANILA_CONF DEFAULT enabled_share_backends $MANILA_ENABLED_BACKENDS
 
     if [ ! -f $MANILA_PATH_TO_PRIVATE_KEY ]; then
-        ssh-keygen -N "" -t rsa -f $MANILA_PATH_TO_PRIVATE_KEY;
+        ssh-keygen -N "" -t $MANILA_KEY_FORMAT -f $MANILA_PATH_TO_PRIVATE_KEY;
     fi
 
     iniset $MANILA_CONF DEFAULT manila_service_keypair_name $MANILA_SERVICE_KEYPAIR_NAME
@@ -308,14 +305,20 @@ function configure_manila {
     if [ $(trueorfalse False MANILA_USE_MOD_WSGI) == True ]; then
         _config_manila_apache_wsgi
     fi
+
+    if [[ "$MANILA_ENFORCE_SCOPE" == True ]] ; then
+        iniset $MANILA_CONF oslo_policy enforce_scope true
+        iniset $MANILA_CONF oslo_policy enforce_new_defaults true
+        OS_CLOUD="devstack-system-admin"
+    fi
 }
 
 
 function create_manila_service_keypair {
     if is_service_enabled nova; then
-        local keypair_exists=$( openstack keypair list | grep " $MANILA_SERVICE_KEYPAIR_NAME " )
+        local keypair_exists=$( openstack --os-cloud devstack-admin keypair list | grep " $MANILA_SERVICE_KEYPAIR_NAME " )
         if [[ -z $keypair_exists ]]; then
-            openstack keypair create $MANILA_SERVICE_KEYPAIR_NAME --public-key $MANILA_PATH_TO_PUBLIC_KEY
+            openstack --os-cloud devstack-admin keypair create $MANILA_SERVICE_KEYPAIR_NAME --public-key $MANILA_PATH_TO_PUBLIC_KEY
         fi
     fi
 }
@@ -344,10 +347,10 @@ function create_service_share_servers {
         if [[ $share_driver == $generic_driver ]]; then
             if [[ $(trueorfalse False driver_handles_share_servers) == False ]]; then
                 vm_name='manila_service_share_server_'$BE
-                local vm_exists=$( openstack server list --all-projects | grep " $vm_name " )
+                local vm_exists=$( openstack --os-cloud devstack-admin server list --all-projects | grep " $vm_name " )
                 if [[ -z $vm_exists ]]; then
-                    private_net_id=$(openstack network show $PRIVATE_NETWORK_NAME -f value -c id)
-                    vm_id=$(openstack server create $vm_name \
+                    private_net_id=$(openstack --os-cloud devstack-admin network show $PRIVATE_NETWORK_NAME -f value -c id)
+                    vm_id=$(openstack --os-cloud devstack-admin server create $vm_name \
                         --flavor $MANILA_SERVICE_VM_FLAVOR_NAME \
                         --image $MANILA_SERVICE_IMAGE_NAME \
                         --nic net-id=$private_net_id \
@@ -355,11 +358,11 @@ function create_service_share_servers {
                         --key-name $MANILA_SERVICE_KEYPAIR_NAME \
                         | grep ' id ' | get_field 2)
                 else
-                    vm_id=$(openstack server show $vm_name -f value -c id)
+                    vm_id=$(openstack --os-cloud devstack-admin server show $vm_name -f value -c id)
                 fi
 
-                floating_ip=$(openstack floating ip create $PUBLIC_NETWORK_NAME --subnet $PUBLIC_SUBNET_NAME | grep 'floating_ip_address' | get_field 2)
-                openstack server add floating ip $vm_id $floating_ip
+                floating_ip=$(openstack --os-cloud devstack-admin floating ip create $PUBLIC_NETWORK_NAME --subnet $PUBLIC_SUBNET_NAME | grep 'floating_ip_address' | get_field 2)
+                openstack --os-cloud devstack-admin server add floating ip $vm_id $floating_ip
 
                 iniset $MANILA_CONF $BE service_instance_name_or_id $vm_id
                 iniset $MANILA_CONF $BE service_net_name_or_ip $floating_ip
@@ -368,17 +371,17 @@ function create_service_share_servers {
                 if is_service_enabled neutron; then
                     if ! [[ -z $MANILA_ADMIN_NET_RANGE ]]; then
                         if [ $created_admin_network == false ]; then
-                            project_id=$(openstack project show $SERVICE_PROJECT_NAME -c id -f value)
-                            local admin_net_id=$( openstack network show admin_net -f value -c id )
+                            project_id=$(openstack --os-cloud devstack-admin project show $SERVICE_PROJECT_NAME -c id -f value)
+                            local admin_net_id=$( openstack --os-cloud devstack-admin network show admin_net -f value -c id )
                             if [[ -z $admin_net_id ]]; then
-                                openstack network create admin_net --project $project_id
-                                admin_net_id=$(openstack network show admin_net -f value -c id)
+                                openstack --os-cloud devstack-admin network create admin_net --project $project_id
+                                admin_net_id=$(openstack --os-cloud devstack-admin network show admin_net -f value -c id)
                             fi
 
-                            local admin_subnet_id=$( openstack subnet show admin_subnet -f value -c id )
+                            local admin_subnet_id=$( openstack --os-cloud devstack-admin subnet show admin_subnet -f value -c id )
                             if [[ -z $admin_subnet_id ]]; then
-                                openstack subnet create admin_subnet --project $project_id --ip-version 4 --network $admin_net_id --gateway None --subnet-range $MANILA_ADMIN_NET_RANGE
-                                admin_subnet_id=$(openstack subnet show admin_subnet -f value -c id)
+                                openstack --os-cloud devstack-admin subnet create admin_subnet --project $project_id --ip-version 4 --network $admin_net_id --gateway None --subnet-range $MANILA_ADMIN_NET_RANGE
+                                admin_subnet_id=$(openstack --os-cloud devstack-admin subnet show admin_subnet -f value -c id)
                             fi
                             created_admin_network=true
                         fi
@@ -411,10 +414,10 @@ function configure_data_service_generic_driver {
 # with configured generic driver to boot Nova VMs with.
 function create_manila_service_flavor {
     if is_service_enabled nova; then
-        local flavor_exists=$( openstack flavor list | grep " $MANILA_SERVICE_VM_FLAVOR_NAME " )
+        local flavor_exists=$( openstack --os-cloud devstack-admin flavor list | grep " $MANILA_SERVICE_VM_FLAVOR_NAME " )
         if [[ -z $flavor_exists ]]; then
             # Create flavor for Manila's service VM
-            openstack flavor create \
+            openstack --os-cloud devstack-admin --os-cloud devstack-admin flavor create \
                 $MANILA_SERVICE_VM_FLAVOR_NAME \
                 --id $MANILA_SERVICE_VM_FLAVOR_REF \
                 --ram $MANILA_SERVICE_VM_FLAVOR_RAM \
@@ -428,8 +431,8 @@ function create_manila_service_flavor {
 # with configured generic driver to boot Nova VMs from.
 function create_manila_service_image {
     if is_service_enabled nova g-api; then
-        TOKEN=$(openstack token issue -c id -f value)
-        local image_exists=$( openstack image list | grep " $MANILA_SERVICE_IMAGE_NAME " )
+        TOKEN=$(openstack --os-cloud devstack-admin token issue -c id -f value)
+        local image_exists=$( openstack --os-cloud devstack-admin image list | grep " $MANILA_SERVICE_IMAGE_NAME " )
         if [[ -z $image_exists ]]; then
             # Download Manila's image
             upload_image $MANILA_SERVICE_IMAGE_URL $TOKEN
@@ -441,42 +444,42 @@ function create_manila_service_image {
 # Nova VMs when generic driver is configured.
 function create_manila_service_secgroup {
     # Create a secgroup
-    if ! openstack security group list | grep -q $MANILA_SERVICE_SECGROUP; then
-        openstack security group create $MANILA_SERVICE_SECGROUP --description "$MANILA_SERVICE_SECGROUP description"
-        if ! timeout 30 sh -c "while ! openstack security group list | grep -q $MANILA_SERVICE_SECGROUP; do sleep 1; done"; then
+    if ! openstack --os-cloud devstack-admin security group list | grep -q $MANILA_SERVICE_SECGROUP; then
+        openstack --os-cloud devstack-admin security group create $MANILA_SERVICE_SECGROUP --description "$MANILA_SERVICE_SECGROUP description"
+        if ! timeout 30 sh -c "while ! openstack --os-cloud devstack-admin security group list | grep -q $MANILA_SERVICE_SECGROUP; do sleep 1; done"; then
             echo "Security group not created"
             exit 1
         fi
     fi
 
     # Configure Security Group Rules
-    if ! openstack security group rule list $MANILA_SERVICE_SECGROUP | grep -q icmp; then
-        openstack security group rule create $MANILA_SERVICE_SECGROUP --protocol icmp
+    if ! openstack --os-cloud devstack-admin security group rule list $MANILA_SERVICE_SECGROUP | grep -q icmp; then
+        openstack --os-cloud devstack-admin security group rule create $MANILA_SERVICE_SECGROUP --protocol icmp
     fi
-    if ! openstack security group rule list $MANILA_SERVICE_SECGROUP | grep -q " tcp .* 22 "; then
-        openstack security group rule create $MANILA_SERVICE_SECGROUP --protocol tcp --dst-port 22
+    if ! openstack --os-cloud devstack-admin security group rule list $MANILA_SERVICE_SECGROUP | grep -q " tcp .* 22 "; then
+        openstack --os-cloud devstack-admin security group rule create $MANILA_SERVICE_SECGROUP --protocol tcp --dst-port 22
     fi
-    if ! openstack security group rule list $MANILA_SERVICE_SECGROUP | grep -q " tcp .* 2049 "; then
-        openstack security group rule create $MANILA_SERVICE_SECGROUP --protocol tcp --dst-port 2049
+    if ! openstack --os-cloud devstack-admin security group rule list $MANILA_SERVICE_SECGROUP | grep -q " tcp .* 2049 "; then
+        openstack --os-cloud devstack-admin security group rule create $MANILA_SERVICE_SECGROUP --protocol tcp --dst-port 2049
     fi
-    if ! openstack security group rule list $MANILA_SERVICE_SECGROUP | grep -q " udp .* 2049 "; then
-        openstack security group rule create $MANILA_SERVICE_SECGROUP --protocol udp --dst-port 2049
+    if ! openstack --os-cloud devstack-admin security group rule list $MANILA_SERVICE_SECGROUP | grep -q " udp .* 2049 "; then
+        openstack --os-cloud devstack-admin security group rule create $MANILA_SERVICE_SECGROUP --protocol udp --dst-port 2049
     fi
-    if ! openstack security group rule list $MANILA_SERVICE_SECGROUP | grep -q " udp .* 445 "; then
-        openstack security group rule create $MANILA_SERVICE_SECGROUP --protocol udp --dst-port 445
+    if ! openstack --os-cloud devstack-admin security group rule list $MANILA_SERVICE_SECGROUP | grep -q " udp .* 445 "; then
+        openstack --os-cloud devstack-admin security group rule create $MANILA_SERVICE_SECGROUP --protocol udp --dst-port 445
     fi
-    if ! openstack security group rule list $MANILA_SERVICE_SECGROUP | grep -q " tcp .* 445 "; then
-        openstack security group rule create $MANILA_SERVICE_SECGROUP --protocol tcp --dst-port 445
+    if ! openstack --os-cloud devstack-admin security group rule list $MANILA_SERVICE_SECGROUP | grep -q " tcp .* 445 "; then
+        openstack --os-cloud devstack-admin security group rule create $MANILA_SERVICE_SECGROUP --protocol tcp --dst-port 445
     fi
-    if ! openstack security group rule list $MANILA_SERVICE_SECGROUP | grep -q " tcp .* 139 "; then
-        openstack security group rule create $MANILA_SERVICE_SECGROUP --protocol tcp --dst-port 137:139
+    if ! openstack --os-cloud devstack-admin security group rule list $MANILA_SERVICE_SECGROUP | grep -q " tcp .* 139 "; then
+        openstack --os-cloud devstack-admin security group rule create $MANILA_SERVICE_SECGROUP --protocol tcp --dst-port 137:139
     fi
-    if ! openstack security group rule list $MANILA_SERVICE_SECGROUP | grep -q " udp .* 139 "; then
-        openstack security group rule create $MANILA_SERVICE_SECGROUP --protocol udp --dst-port 137:139
+    if ! openstack --os-cloud devstack-admin security group rule list $MANILA_SERVICE_SECGROUP | grep -q " udp .* 139 "; then
+        openstack --os-cloud devstack-admin security group rule create $MANILA_SERVICE_SECGROUP --protocol udp --dst-port 137:139
     fi
 
     # List secgroup rules
-    openstack security group rule list $MANILA_SERVICE_SECGROUP
+    openstack --os-cloud devstack-admin security group rule list $MANILA_SERVICE_SECGROUP
 }
 
 # create_manila_accounts - Set up common required manila accounts
@@ -513,13 +516,22 @@ function create_manila_accounts {
 
 # create_default_share_group_type - create share group type that will be set as default.
 function create_default_share_group_type {
-    local type_exists=$( manila share-group-type-list | grep " $MANILA_DEFAULT_SHARE_GROUP_TYPE " )
+
+    # NOTE(gouthamr): manilaclient's shell doesn't support cloud profiles;
+    # OSC is the best approach here: https://review.opendev.org/805064, but,
+    # we need a temporary workaround to use legacy credentials while we wait
+    # for OSC support
+    # TODO(gouthamr): Remove workaround when we replace the commands below
+    # with OSC equivalents
+
+    local type_exists=$( openstack --os-cloud $OS_CLOUD share group type list | grep " $MANILA_DEFAULT_SHARE_GROUP_TYPE " )
     if [[ -z $type_exists ]]; then
-        manila share-group-type-create $MANILA_DEFAULT_SHARE_GROUP_TYPE $MANILA_DEFAULT_SHARE_TYPE
+        openstack --os-cloud $OS_CLOUD share group type create $MANILA_DEFAULT_SHARE_GROUP_TYPE $MANILA_DEFAULT_SHARE_TYPE
     fi
     if [[ $MANILA_DEFAULT_SHARE_GROUP_TYPE_SPECS ]]; then
-        manila share-group-type-key $MANILA_DEFAULT_SHARE_GROUP_TYPE set $MANILA_DEFAULT_SHARE_GROUP_TYPE_SPECS
+        openstack --os-cloud $OS_CLOUD share group type set $MANILA_DEFAULT_SHARE_GROUP_TYPE --group-specs $MANILA_DEFAULT_SHARE_GROUP_TYPE_SPECS
     fi
+
 }
 
 # create_default_share_type - create share type that will be set as default
@@ -530,33 +542,31 @@ function create_default_share_type {
     enabled_backends=(${MANILA_ENABLED_BACKENDS//,/ })
     driver_handles_share_servers=$(iniget $MANILA_CONF ${enabled_backends[0]} driver_handles_share_servers)
 
-    local type_exists=$( manila type-list | grep " $MANILA_DEFAULT_SHARE_TYPE " )
+    local type_exists=$( openstack --os-cloud $OS_CLOUD share type list | grep " $MANILA_DEFAULT_SHARE_TYPE " )
     if [[ -z $type_exists ]]; then
         local command_args="$MANILA_DEFAULT_SHARE_TYPE $driver_handles_share_servers"
-        #if is_driver_enabled $MANILA_CONTAINER_DRIVER; then
-        #    # TODO(aovchinnikov): Remove this condition when Container driver supports
-        #    # snapshots
-        #    command_args="$command_args --snapshot_support false"
-        #fi
-        manila type-create $command_args
-    fi
-    if [[ $MANILA_DEFAULT_SHARE_TYPE_EXTRA_SPECS ]]; then
-        manila type-key $MANILA_DEFAULT_SHARE_TYPE set $MANILA_DEFAULT_SHARE_TYPE_EXTRA_SPECS
+        if [[ $MANILA_DEFAULT_SHARE_TYPE_EXTRA_SPECS ]]; then
+            command_args="$command_args --extra-specs $MANILA_DEFAULT_SHARE_TYPE_EXTRA_SPECS"
+        fi
+        openstack --os-cloud $OS_CLOUD share type create $command_args
     fi
+
 }
 
 # create_custom_share_types - create share types suitable for both possible
 # driver modes with names "dhss_true" and "dhss_false".
 function create_custom_share_types {
-    manila type-create dhss_true True
+    local command_args="dhss_true True"
     if [[ $MANILA_DHSS_TRUE_SHARE_TYPE_EXTRA_SPECS ]]; then
-        manila type-key dhss_true set $MANILA_DHSS_TRUE_SHARE_TYPE_EXTRA_SPECS
+        command_args="$command_args --extra-specs $MANILA_DHSS_TRUE_SHARE_TYPE_EXTRA_SPECS"
     fi
+    openstack --os-cloud $OS_CLOUD share type create $command_args
 
-    manila type-create dhss_false False
+    command_args="dhss_false False"
     if [[ $MANILA_DHSS_FALSE_SHARE_TYPE_EXTRA_SPECS ]]; then
-        manila type-key dhss_false set $MANILA_DHSS_FALSE_SHARE_TYPE_EXTRA_SPECS
+        command_args="$command_args --extra-specs $MANILA_DHSS_FALSE_SHARE_TYPE_EXTRA_SPECS"
     fi
+    openstack --os-cloud $OS_CLOUD share type create $command_args
 }
 
 # configure_backing_file - Set up backing file for LVM
@@ -771,9 +781,6 @@ function install_manila {
             fi
             check_nfs_kernel_service_state_ubuntu
         elif [ "$SHARE_DRIVER" == $MANILA_CONTAINER_DRIVER ]; then
-            # Remove workaround for https://launchpad.net/bugs/1876820 when
-            # container driver stops using "brctl"
-            install_package bridge-utils
             if is_ubuntu; then
                 echo "Installing docker...."
                 install_docker_ubuntu
@@ -914,15 +921,6 @@ function stop_manila {
     done
 }
 
-function install_manila_tempest_plugin {
-    MANILA_TEMPEST_PLUGIN_REPO=${MANILA_TEMPEST_PLUGIN_REPO:-${GIT_BASE}/openstack/manila-tempest-plugin}
-    MANILA_TEMPEST_PLUGIN_BRANCH=${MANILA_TEMPEST_PLUGIN_BRANCH:-master}
-    MANILA_TEMPEST_PLUGIN_DIR=$DEST/manila-tempest-plugin
-
-    git_clone $MANILA_TEMPEST_PLUGIN_REPO $MANILA_TEMPEST_PLUGIN_DIR $MANILA_TEMPEST_PLUGIN_BRANCH
-    setup_develop $MANILA_TEMPEST_PLUGIN_DIR
-}
-
 # update_tempest - Function used for updating Tempest config if Tempest service enabled
 function update_tempest {
     if is_service_enabled tempest; then
@@ -930,7 +928,7 @@ function update_tempest {
         if [[ "$(trueorfalse False MANILA_SETUP_IPV6)" == "True" ]]; then
             # The public network was created by us, so set it explicitly in
             # tempest.conf
-            public_net_id=$(openstack network list --name $PUBLIC_NETWORK_NAME -f value -c ID )
+            public_net_id=$(openstack --os-cloud devstack-admin network list --name $PUBLIC_NETWORK_NAME -f value -c ID )
             iniset $TEMPEST_CONFIG network public_network_id $public_net_id
         fi
 
@@ -955,11 +953,23 @@ function update_tempest {
         iniset $TEMPEST_CONFIG identity alt_password $ADMIN_PASSWORD
         iniset $TEMPEST_CONFIG identity alt_tenant_name ${ALT_TENANT_NAME:-"alt_demo"}
         iniset $TEMPEST_CONFIG identity alt_domain_name $ADMIN_DOMAIN_NAME
+        iniset $TEMPEST_CONFIG enforce_scope manila "$MANILA_ENFORCE_SCOPE"
 
-        # Max API micro-version for tempest tests
-        iniset $TEMPEST_CONFIG share min_api_microversion 2.0
-        iniset $TEMPEST_CONFIG share max_api_microversion 2.63
-
+        # If testing a stable branch, we need to ensure we're testing with supported
+        # API micro-versions; so set the versions from code if we're not testing the
+        # master branch. If we're testing master, we'll allow manila-tempest-plugin
+        # (which is branchless) tell us what versions it wants to test.
+        if [[ "$TARGET_BRANCH" != "master" ]]; then
+            # Grab the supported API micro-versions from the code
+            _DEFAULT_MIN_VERSION=$(openstack --os-cloud devstack versions show --service sharev2 -c 'Min Microversion' --status CURRENT -f value)
+            _DEFAULT_MAX_VERSION=$(openstack --os-cloud devstack versions show --service sharev2 -c 'Max Microversion' --status CURRENT -f value)
+            # Override the *_api_microversion tempest options if present
+            MANILA_TEMPEST_MIN_API_MICROVERSION=${MANILA_TEMPEST_MIN_API_MICROVERSION:-$_DEFAULT_MIN_VERSION}
+            MANILA_TEMPEST_MAX_API_MICROVERSION=${MANILA_TEMPEST_MAX_API_MICROVERSION:-$_DEFAULT_MAX_VERSION}
+            # Set these options in tempest.conf
+            iniset $TEMPEST_CONFIG share min_api_microversion $MANILA_TEMPEST_MIN_API_MICROVERSION
+            iniset $TEMPEST_CONFIG share max_api_microversion $MANILA_TEMPEST_MAX_API_MICROVERSION
+        fi
     fi
 }
 
@@ -1076,26 +1086,26 @@ function setup_ipv6 {
     sudo ovs-vsctl set Bridge $PUBLIC_BRIDGE other_config:disable-in-band=true
 
     # Create address scopes and subnet pools
-    openstack address scope create --share --ip-version 4 scope-v4
-    openstack address scope create --share --ip-version 6 scope-v6
-    openstack subnet pool create $SUBNETPOOL_NAME_V4 --default-prefix-length $SUBNETPOOL_SIZE_V4 --pool-prefix $SUBNETPOOL_PREFIX_V4 --address-scope scope-v4 --default --share
-    openstack subnet pool create $SUBNETPOOL_NAME_V6 --default-prefix-length $SUBNETPOOL_SIZE_V6 --pool-prefix $SUBNETPOOL_PREFIX_V6 --address-scope scope-v6 --default --share
+    openstack --os-cloud devstack-admin address scope create --share --ip-version 4 scope-v4
+    openstack --os-cloud devstack-admin address scope create --share --ip-version 6 scope-v6
+    openstack --os-cloud devstack-admin subnet pool create $SUBNETPOOL_NAME_V4 --default-prefix-length $SUBNETPOOL_SIZE_V4 --pool-prefix $SUBNETPOOL_PREFIX_V4 --address-scope scope-v4 --default --share
+    openstack --os-cloud devstack-admin subnet pool create $SUBNETPOOL_NAME_V6 --default-prefix-length $SUBNETPOOL_SIZE_V6 --pool-prefix $SUBNETPOOL_PREFIX_V6 --address-scope scope-v6 --default --share
 
     # Create example private network and router
-    openstack router create $Q_ROUTER_NAME
-    openstack network create $PRIVATE_NETWORK_NAME
-    openstack subnet create --ip-version 6 --use-default-subnet-pool --ipv6-address-mode $IPV6_ADDRESS_MODE --ipv6-ra-mode $IPV6_RA_MODE --network $PRIVATE_NETWORK_NAME $IPV6_PRIVATE_SUBNET_NAME
-    openstack subnet create --ip-version 4 --use-default-subnet-pool --network $PRIVATE_NETWORK_NAME $PRIVATE_SUBNET_NAME
-    openstack router add subnet $Q_ROUTER_NAME $IPV6_PRIVATE_SUBNET_NAME
-    openstack router add subnet $Q_ROUTER_NAME $PRIVATE_SUBNET_NAME
+    openstack --os-cloud devstack-admin router create $Q_ROUTER_NAME
+    openstack --os-cloud devstack-admin network create $PRIVATE_NETWORK_NAME
+    openstack --os-cloud devstack-admin subnet create --ip-version 6 --use-default-subnet-pool --ipv6-address-mode $IPV6_ADDRESS_MODE --ipv6-ra-mode $IPV6_RA_MODE --network $PRIVATE_NETWORK_NAME $IPV6_PRIVATE_SUBNET_NAME
+    openstack --os-cloud devstack-admin subnet create --ip-version 4 --use-default-subnet-pool --network $PRIVATE_NETWORK_NAME $PRIVATE_SUBNET_NAME
+    openstack --os-cloud devstack-admin router add subnet $Q_ROUTER_NAME $IPV6_PRIVATE_SUBNET_NAME
+    openstack --os-cloud devstack-admin router add subnet $Q_ROUTER_NAME $PRIVATE_SUBNET_NAME
 
     # Create public network
-    openstack network create $PUBLIC_NETWORK_NAME --external --default --provider-network-type flat --provider-physical-network $PUBLIC_PHYSICAL_NETWORK
-    local public_gateway_ipv6=$(openstack subnet create $IPV6_PUBLIC_SUBNET_NAME --ip-version 6 --network $PUBLIC_NETWORK_NAME --subnet-pool $SUBNETPOOL_NAME_V6 --no-dhcp -c gateway_ip -f value)
-    local public_gateway_ipv4=$(openstack subnet create $PUBLIC_SUBNET_NAME --ip-version 4 --network $PUBLIC_NETWORK_NAME --subnet-range $FLOATING_RANGE --no-dhcp -c gateway_ip -f value)
+    openstack --os-cloud devstack-admin network create $PUBLIC_NETWORK_NAME --external --default --provider-network-type flat --provider-physical-network $PUBLIC_PHYSICAL_NETWORK
+    local public_gateway_ipv6=$(openstack --os-cloud devstack-admin subnet create $IPV6_PUBLIC_SUBNET_NAME --ip-version 6 --network $PUBLIC_NETWORK_NAME --subnet-pool $SUBNETPOOL_NAME_V6 --no-dhcp -c gateway_ip -f value)
+    local public_gateway_ipv4=$(openstack --os-cloud devstack-admin subnet create $PUBLIC_SUBNET_NAME --ip-version 4 --network $PUBLIC_NETWORK_NAME --subnet-range $FLOATING_RANGE --no-dhcp -c gateway_ip -f value)
 
     # Set router to use public network
-    openstack router set --external-gateway $PUBLIC_NETWORK_NAME $Q_ROUTER_NAME
+    openstack --os-cloud devstack-admin router set --external-gateway $PUBLIC_NETWORK_NAME $Q_ROUTER_NAME
 
     # Configure interfaces due to NEUTRON_CREATE_INITIAL_NETWORKS=False
     local ipv4_cidr_len=${FLOATING_RANGE#*/}
@@ -1202,11 +1212,11 @@ function setup_ipv6 {
 }
 
 function setup_bgp_for_ipv6 {
-    public_gateway_ipv6=$(openstack subnet show ipv6-public-subnet -c gateway_ip -f value)
-    neutron bgp-speaker-create --ip-version 6 --local-as 100 bgpspeaker
-    neutron bgp-speaker-network-add bgpspeaker $PUBLIC_NETWORK_NAME
-    neutron bgp-peer-create --peer-ip $public_gateway_ipv6 --remote-as 200 bgppeer
-    neutron bgp-speaker-peer-add bgpspeaker bgppeer
+    public_gateway_ipv6=$(openstack --os-cloud devstack-admin subnet show ipv6-public-subnet -c gateway_ip -f value)
+    openstack --os-cloud devstack-admin bgp speaker create --ip-version 6 --local-as 100 bgpspeaker
+    openstack --os-cloud devstack-admin bgp speaker add network bgpspeaker $PUBLIC_NETWORK_NAME
+    openstack --os-cloud devstack-admin bgp peer create --peer-ip $public_gateway_ipv6 --remote-as 200 bgppeer
+    openstack --os-cloud devstack-admin bgp speaker add peer bgpspeaker bgppeer
 }
 
 # Main dispatcher
@@ -1307,17 +1317,6 @@ elif [[ "$1" == "stack" && "$2" == "test-config" ]]; then
     fi
     ###########################################################################
 
-
-    if [ $(trueorfalse False MANILA_INSTALL_TEMPEST_PLUGIN_SYSTEMWIDE) == True ]; then
-        echo_summary "Fetching and installing manila-tempest-plugin system-wide"
-        install_manila_tempest_plugin
-        export DEPRECATED_TEXT="$DEPRECATED_TEXT\nInstalling
-        manila-tempest-plugin can be done with the help of its own DevStack
-        plugin by adding: \n\n\t'enable_plugin manila-tempest-plugin
-        https://opendev.org/openstack/manila-tempest-plugin'.\n\nManila's
-        DevStack plugin will stop installing it automatically."
-    fi
-
     echo_summary "Update Tempest config"
     update_tempest
 
