@@ -16,12 +16,11 @@
 """The shares api."""
 
 import ast
+from http import client as http_client
 
 from oslo_log import log
 from oslo_utils import strutils
 from oslo_utils import uuidutils
-import six
-from six.moves import http_client
 import webob
 from webob import exc
 
@@ -91,9 +90,9 @@ class ShareMixin(object):
         except exception.NotFound:
             raise exc.HTTPNotFound()
         except exception.InvalidShare as e:
-            raise exc.HTTPForbidden(explanation=six.text_type(e))
+            raise exc.HTTPForbidden(explanation=e.message)
         except exception.Conflict as e:
-            raise exc.HTTPConflict(explanation=six.text_type(e))
+            raise exc.HTTPConflict(explanation=e.message)
 
         return webob.Response(status_int=http_client.ACCEPTED)
 
@@ -136,6 +135,11 @@ class ShareMixin(object):
                 'with_count', search_opts)
             search_opts.pop('with_count')
 
+        if 'is_soft_deleted' in search_opts:
+            is_soft_deleted = utils.get_bool_from_api_params(
+                'is_soft_deleted', search_opts)
+            search_opts['is_soft_deleted'] = is_soft_deleted
+
         # Deserialize dicts
         if 'metadata' in search_opts:
             search_opts['metadata'] = ast.literal_eval(search_opts['metadata'])
@@ -164,12 +168,16 @@ class ShareMixin(object):
         common.remove_invalid_options(
             context, search_opts, self._get_share_search_options())
 
-        shares = self.share_api.get_all(
-            context, search_opts=search_opts, sort_key=sort_key,
-            sort_dir=sort_dir)
         total_count = None
         if show_count:
-            total_count = len(shares)
+            count, shares = self.share_api.get_all_with_count(
+                context, search_opts=search_opts, sort_key=sort_key,
+                sort_dir=sort_dir)
+            total_count = count
+        else:
+            shares = self.share_api.get_all(
+                context, search_opts=search_opts, sort_key=sort_key,
+                sort_dir=sort_dir)
 
         if is_detail:
             shares = self._view_builder.detail_list(req, shares, total_count)
@@ -189,8 +197,7 @@ class ShareMixin(object):
             'is_public', 'metadata', 'extra_specs', 'sort_key', 'sort_dir',
             'share_group_id', 'share_group_snapshot_id', 'export_location_id',
             'export_location_path', 'display_name~', 'display_description~',
-            'display_description', 'limit', 'offset'
-        )
+            'display_description', 'limit', 'offset', 'is_soft_deleted')
 
     @wsgi.Controller.authorize
     def update(self, req, id, body):
@@ -216,6 +223,11 @@ class ShareMixin(object):
         except exception.NotFound:
             raise exc.HTTPNotFound()
 
+        if share.get('is_soft_deleted'):
+            msg = _("Share '%s cannot be updated, "
+                    "since it has been soft deleted.") % share['id']
+            raise exc.HTTPForbidden(explanation=msg)
+
         update_dict = common.validate_public_share_policy(
             context, update_dict, api='update')
 
@@ -232,7 +244,8 @@ class ShareMixin(object):
     @wsgi.Controller.authorize('create')
     def _create(self, req, body,
                 check_create_share_from_snapshot_support=False,
-                check_availability_zones_extra_spec=False):
+                check_availability_zones_extra_spec=False,
+                scheduler_hints=None):
         """Creates a new share."""
         context = req.environ['manila.context']
 
@@ -264,27 +277,30 @@ class ShareMixin(object):
         availability_zone = share.get('availability_zone')
         if availability_zone:
             try:
-                availability_zone_id = db.availability_zone_get(
-                    context, availability_zone).id
+                availability_zone_db = db.availability_zone_get(
+                    context, availability_zone)
+                availability_zone_id = availability_zone_db.id
+                availability_zone = availability_zone_db.name
             except exception.AvailabilityZoneNotFound as e:
-                raise exc.HTTPNotFound(explanation=six.text_type(e))
+                raise exc.HTTPNotFound(explanation=e.message)
 
         share_group_id = share.get('share_group_id')
         if share_group_id:
             try:
                 share_group = db.share_group_get(context, share_group_id)
             except exception.ShareGroupNotFound as e:
-                raise exc.HTTPNotFound(explanation=six.text_type(e))
+                raise exc.HTTPNotFound(explanation=e.message)
             sg_az_id = share_group['availability_zone_id']
             if availability_zone and availability_zone_id != sg_az_id:
                 msg = _("Share cannot have AZ ('%(s_az)s') different than "
                         "share group's one (%(sg_az)s).") % {
                             's_az': availability_zone_id, 'sg_az': sg_az_id}
                 raise exception.InvalidInput(msg)
-            availability_zone_id = sg_az_id
+            availability_zone = db.availability_zone_get(
+                context, sg_az_id).name
 
         kwargs = {
-            'availability_zone': availability_zone_id,
+            'availability_zone': availability_zone,
             'metadata': share.get('metadata'),
             'is_public': share.get('is_public', False),
             'share_group_id': share_group_id,
@@ -330,19 +346,26 @@ class ShareMixin(object):
 
         if share_network_id:
             try:
-                self.share_api.get_share_network(
+                share_network = self.share_api.get_share_network(
                     context,
                     share_network_id)
             except exception.ShareNetworkNotFound as e:
                 raise exc.HTTPNotFound(explanation=e.msg)
-            kwargs['share_network_id'] = share_network_id
+
+            common.check_share_network_is_active(share_network)
+
             if availability_zone_id:
-                if not db.share_network_subnet_get_by_availability_zone_id(
+                subnets = (
+                    db.share_network_subnets_get_all_by_availability_zone_id(
                         context, share_network_id,
-                        availability_zone_id=availability_zone_id):
+                        availability_zone_id=availability_zone_id))
+                if not subnets:
                     msg = _("A share network subnet was not found for the "
                             "requested availability zone.")
                     raise exc.HTTPBadRequest(explanation=msg)
+                kwargs['az_request_multiple_subnet_support_map'] = {
+                    availability_zone_id: len(subnets) > 1,
+                }
 
         display_name = share.get('display_name')
         display_description = share.get('display_description')
@@ -402,6 +425,11 @@ class ShareMixin(object):
 
         if share_type:
             kwargs['share_type'] = share_type
+        if share_network_id:
+            kwargs['share_network_id'] = share_network_id
+
+        kwargs['scheduler_hints'] = scheduler_hints
+
         new_share = self.share_api.create(context,
                                           share_proto,
                                           size,
@@ -430,6 +458,15 @@ class ShareMixin(object):
             access_data.pop('metadata', None)
         share = self.share_api.get(context, id)
 
+        if share.get('is_soft_deleted'):
+            msg = _("Cannot allow access for share '%s' "
+                    "since it has been soft deleted.") % id
+            raise exc.HTTPForbidden(explanation=msg)
+        share_network_id = share.get('share_network_id')
+        if share_network_id:
+            share_network = db.share_network_get(context, share_network_id)
+            common.check_share_network_is_active(share_network)
+
         if (not allow_on_error_status and
                 self._any_instance_has_errored_rules(share)):
             msg = _("Access rules cannot be added while the share or any of "
@@ -471,13 +508,26 @@ class ShareMixin(object):
         access_id = body.get(
             'deny_access', body.get('os-deny_access'))['access_id']
 
+        share = self.share_api.get(context, id)
+
+        if share.get('is_soft_deleted'):
+            msg = _("Cannot deny access for share '%s' "
+                    "since it has been soft deleted.") % id
+            raise exc.HTTPForbidden(explanation=msg)
+
+        share_network_id = share.get('share_network_id', None)
+
+        if share_network_id:
+            share_network = db.share_network_get(context, share_network_id)
+            common.check_share_network_is_active(share_network)
+
         try:
             access = self.share_api.access_get(context, access_id)
             if access.share_id != id:
                 raise exception.NotFound()
             share = self.share_api.get(context, id)
         except exception.NotFound as error:
-            raise webob.exc.HTTPNotFound(explanation=six.text_type(error))
+            raise webob.exc.HTTPNotFound(explanation=error.message)
         self.share_api.deny_access(context, share, access)
         return webob.Response(status_int=http_client.ACCEPTED)
 
@@ -493,40 +543,75 @@ class ShareMixin(object):
     def _extend(self, req, id, body):
         """Extend size of a share."""
         context = req.environ['manila.context']
-        share, size = self._get_valid_resize_parameters(
+        share, size, force = self._get_valid_extend_parameters(
             context, id, body, 'os-extend')
 
+        if share.get('is_soft_deleted'):
+            msg = _("Cannot extend share '%s' "
+                    "since it has been soft deleted.") % id
+            raise exc.HTTPForbidden(explanation=msg)
+
         try:
-            self.share_api.extend(context, share, size)
+            self.share_api.extend(context, share, size, force=force)
         except (exception.InvalidInput, exception.InvalidShare) as e:
-            raise webob.exc.HTTPBadRequest(explanation=six.text_type(e))
+            raise webob.exc.HTTPBadRequest(explanation=str(e))
         except exception.ShareSizeExceedsAvailableQuota as e:
-            raise webob.exc.HTTPForbidden(explanation=six.text_type(e))
+            raise webob.exc.HTTPForbidden(explanation=e.message)
 
         return webob.Response(status_int=http_client.ACCEPTED)
 
     def _shrink(self, req, id, body):
         """Shrink size of a share."""
         context = req.environ['manila.context']
-        share, size = self._get_valid_resize_parameters(
+        share, size = self._get_valid_shrink_parameters(
             context, id, body, 'os-shrink')
 
+        if share.get('is_soft_deleted'):
+            msg = _("Cannot shrink share '%s' "
+                    "since it has been soft deleted.") % id
+            raise exc.HTTPForbidden(explanation=msg)
+
         try:
             self.share_api.shrink(context, share, size)
         except (exception.InvalidInput, exception.InvalidShare) as e:
-            raise webob.exc.HTTPBadRequest(explanation=six.text_type(e))
+            raise webob.exc.HTTPBadRequest(explanation=str(e))
 
         return webob.Response(status_int=http_client.ACCEPTED)
 
-    def _get_valid_resize_parameters(self, context, id, body, action):
+    def _get_valid_extend_parameters(self, context, id, body, action):
         try:
             share = self.share_api.get(context, id)
         except exception.NotFound as e:
-            raise webob.exc.HTTPNotFound(explanation=six.text_type(e))
+            raise webob.exc.HTTPNotFound(explanation=e.message)
 
         try:
-            size = int(body.get(action,
-                                body.get(action.split('os-')[-1]))['new_size'])
+            size = int(body.get(action, body.get('extend'))['new_size'])
+        except (KeyError, ValueError, TypeError):
+            msg = _("New share size must be specified as an integer.")
+            raise webob.exc.HTTPBadRequest(explanation=msg)
+
+        # force is True means share extend will extend directly, is False
+        # means will go through scheduler. Default value is False,
+        try:
+            force = strutils.bool_from_string(body.get(
+                action, body.get('extend'))['force'], strict=True)
+        except KeyError:
+            force = False
+        except (ValueError, TypeError):
+            msg = (_('Invalid boolean force : %(value)s') %
+                   {'value': body.get('extend')['force']})
+            raise webob.exc.HTTPBadRequest(explanation=msg)
+
+        return share, size, force
+
+    def _get_valid_shrink_parameters(self, context, id, body, action):
+        try:
+            share = self.share_api.get(context, id)
+        except exception.NotFound as e:
+            raise webob.exc.HTTPNotFound(explanation=e.message)
+
+        try:
+            size = int(body.get(action, body.get('shrink'))['new_size'])
         except (KeyError, ValueError, TypeError):
             msg = _("New share size must be specified as an integer.")
             raise webob.exc.HTTPBadRequest(explanation=msg)
