@@ -26,6 +26,7 @@ from manila.api import common
 from manila.api.openstack import api_version_request as api_version
 from manila.api.openstack import wsgi
 from manila.api.v1 import share_snapshots
+from manila.api.v2 import metadata
 from manila.api.views import share_snapshots as snapshot_views
 from manila.common import constants
 from manila.db import api as db_api
@@ -37,7 +38,8 @@ LOG = log.getLogger(__name__)
 
 
 class ShareSnapshotsController(share_snapshots.ShareSnapshotMixin,
-                               wsgi.Controller, wsgi.AdminActionsMixin):
+                               wsgi.Controller, metadata.MetadataController,
+                               wsgi.AdminActionsMixin):
     """The Share Snapshots API V2 controller for the OpenStack API."""
 
     resource_name = 'share_snapshot'
@@ -123,6 +125,12 @@ class ShareSnapshotsController(share_snapshots.ShareSnapshotMixin,
             'display_name': name,
             'display_description': description,
         }
+        if req.api_version_request >= api_version.APIVersionRequest("2.73"):
+            if snapshot_data.get('metadata'):
+                metadata = snapshot_data.get('metadata')
+                snapshot.update({
+                    'metadata': metadata,
+                })
 
         try:
             share_ref = self.share_api.get(context, share_id)
@@ -174,9 +182,6 @@ class ShareSnapshotsController(share_snapshots.ShareSnapshotMixin,
             if not data.get(parameter):
                 msg = _("Required parameter %s is empty.") % parameter
                 raise exc_response(explanation=msg)
-            if not isinstance(data[parameter], str):
-                msg = _("Parameter %s must be a string.") % parameter
-                raise exc_response(explanation=msg)
 
     def _check_if_share_share_network_is_active(self, context, snapshot):
         share_network_id = snapshot['share'].get('share_network_id')
@@ -342,6 +347,37 @@ class ShareSnapshotsController(share_snapshots.ShareSnapshotMixin,
             req.GET.pop('description', None)
         return self._get_snapshots(req, is_detail=True)
 
+    @wsgi.Controller.api_version("2.73")
+    @wsgi.Controller.authorize("get_metadata")
+    def index_metadata(self, req, resource_id):
+        """Returns the list of metadata for a given share snapshot."""
+        return self._index_metadata(req, resource_id)
+
+    @wsgi.Controller.api_version("2.73")
+    @wsgi.Controller.authorize("update_metadata")
+    def create_metadata(self, req, resource_id, body):
+        return self._create_metadata(req, resource_id, body)
+
+    @wsgi.Controller.api_version("2.73")
+    @wsgi.Controller.authorize("update_metadata")
+    def update_all_metadata(self, req, resource_id, body):
+        return self._update_all_metadata(req, resource_id, body)
+
+    @wsgi.Controller.api_version("2.73")
+    @wsgi.Controller.authorize("update_metadata")
+    def update_metadata_item(self, req, resource_id, body, key):
+        return self._update_metadata_item(req, resource_id, body, key)
+
+    @wsgi.Controller.api_version("2.73")
+    @wsgi.Controller.authorize("get_metadata")
+    def show_metadata(self, req, resource_id, key):
+        return self._show_metadata(req, resource_id, key)
+
+    @wsgi.Controller.api_version("2.73")
+    @wsgi.Controller.authorize("delete_metadata")
+    def delete_metadata(self, req, resource_id, key):
+        return self._delete_metadata(req, resource_id, key)
+
 
 def create_resource():
     return wsgi.Resource(ShareSnapshotsController())
