@@ -389,9 +389,9 @@ def share_update(context, share_id, values):
     return IMPL.share_update(context, share_id, values)
 
 
-def share_get(context, share_id):
+def share_get(context, share_id, **kwargs):
     """Get share by id."""
-    return IMPL.share_get(context, share_id)
+    return IMPL.share_get(context, share_id, **kwargs)
 
 
 def share_get_all(context, filters=None, sort_key=None, sort_dir=None):
@@ -401,13 +401,28 @@ def share_get_all(context, filters=None, sort_key=None, sort_dir=None):
     )
 
 
+def share_get_all_with_count(context, filters=None, sort_key=None,
+                             sort_dir=None):
+    """Get all shares."""
+    return IMPL.share_get_all_with_count(
+        context, filters=filters, sort_key=sort_key, sort_dir=sort_dir)
+
+
 def share_get_all_by_project(context, project_id, filters=None,
                              is_public=False, sort_key=None, sort_dir=None):
     """Returns all shares with given project ID."""
     return IMPL.share_get_all_by_project(
         context, project_id, filters=filters, is_public=is_public,
-        sort_key=sort_key, sort_dir=sort_dir,
-    )
+        sort_key=sort_key, sort_dir=sort_dir)
+
+
+def share_get_all_by_project_with_count(
+        context, project_id, filters=None, is_public=False, sort_key=None,
+        sort_dir=None,):
+    """Returns all shares with given project ID."""
+    return IMPL.share_get_all_by_project_with_count(
+        context, project_id, filters=filters, is_public=is_public,
+        sort_key=sort_key, sort_dir=sort_dir)
 
 
 def share_get_all_by_share_group_id(context, share_group_id,
@@ -419,13 +434,47 @@ def share_get_all_by_share_group_id(context, share_group_id,
         sort_key=sort_key, sort_dir=sort_dir)
 
 
+def share_get_all_by_share_group_id_with_count(context, share_group_id,
+                                               filters=None, sort_key=None,
+                                               sort_dir=None):
+    """Returns all shares with given project ID and share group id."""
+    return IMPL.share_get_all_by_share_group_id_with_count(
+        context, share_group_id, filters=filters, sort_key=sort_key,
+        sort_dir=sort_dir)
+
+
 def share_get_all_by_share_server(context, share_server_id, filters=None,
                                   sort_key=None, sort_dir=None):
     """Returns all shares with given share server ID."""
     return IMPL.share_get_all_by_share_server(
         context, share_server_id, filters=filters, sort_key=sort_key,
-        sort_dir=sort_dir,
-    )
+        sort_dir=sort_dir)
+
+
+def get_shares_in_recycle_bin_by_share_server(
+        context, share_server_id, filters=None,
+        sort_key=None, sort_dir=None):
+    """Returns all shares in recycle bin with given share server ID."""
+    return IMPL.get_shares_in_recycle_bin_by_share_server(
+        context, share_server_id, filters=filters, sort_key=sort_key,
+        sort_dir=sort_dir)
+
+
+def share_get_all_by_share_server_with_count(
+        context, share_server_id, filters=None, sort_key=None, sort_dir=None):
+    """Returns all shares with given share server ID."""
+    return IMPL.share_get_all_by_share_server_with_count(
+        context, share_server_id, filters=filters, sort_key=sort_key,
+        sort_dir=sort_dir)
+
+
+def get_shares_in_recycle_bin_by_network(
+        context, share_network_id, filters=None,
+        sort_key=None, sort_dir=None):
+    """Returns all shares in recycle bin with given share network ID."""
+    return IMPL.get_shares_in_recycle_bin_by_network(
+        context, share_network_id, filters=filters, sort_key=sort_key,
+        sort_dir=sort_dir)
 
 
 def share_delete(context, share_id):
@@ -433,6 +482,15 @@ def share_delete(context, share_id):
     return IMPL.share_delete(context, share_id)
 
 
+def share_soft_delete(context, share_id):
+    """Soft delete share."""
+    return IMPL.share_soft_delete(context, share_id)
+
+
+def share_restore(context, share_id):
+    """Restore share."""
+    return IMPL.share_restore(context, share_id)
+
 ###################
 
 
@@ -568,26 +626,27 @@ def share_snapshot_create(context, values):
     return IMPL.share_snapshot_create(context, values)
 
 
-def share_snapshot_get(context, snapshot_id):
+def share_snapshot_get(context, snapshot_id, project_only=True):
     """Get a snapshot or raise if it does not exist."""
-    return IMPL.share_snapshot_get(context, snapshot_id)
+    return IMPL.share_snapshot_get(context, snapshot_id,
+                                   project_only=project_only)
 
 
-def share_snapshot_get_all(context, filters=None, sort_key=None,
-                           sort_dir=None):
+def share_snapshot_get_all(context, filters=None, limit=None, offset=None,
+                           sort_key=None, sort_dir=None):
     """Get all snapshots."""
     return IMPL.share_snapshot_get_all(
-        context, filters=filters, sort_key=sort_key, sort_dir=sort_dir,
-    )
+        context, filters=filters, limit=limit, offset=offset,
+        sort_key=sort_key, sort_dir=sort_dir)
 
 
 def share_snapshot_get_all_by_project(context, project_id, filters=None,
-                                      sort_key=None, sort_dir=None):
+                                      limit=None, offset=None, sort_key=None,
+                                      sort_dir=None):
     """Get all snapshots belonging to a project."""
     return IMPL.share_snapshot_get_all_by_project(
-        context, project_id, filters=filters, sort_key=sort_key,
-        sort_dir=sort_dir,
-    )
+        context, project_id, filters=filters, limit=limit, offset=offset,
+        sort_key=sort_key, sort_dir=sort_dir)
 
 
 def share_snapshot_get_all_for_share(context, share_id, filters=None,
@@ -703,7 +762,42 @@ def share_snapshot_instance_export_location_delete(context, el_id):
     return IMPL.share_snapshot_instance_export_location_delete(context, el_id)
 
 
+####################
+
+def share_snapshot_metadata_get(context, share_snapshot_id, **kwargs):
+    """Get all metadata for a share snapshot."""
+    return IMPL.share_snapshot_metadata_get(context,
+                                            share_snapshot_id,
+                                            **kwargs)
+
+
+def share_snapshot_metadata_get_item(context, share_snapshot_id, key):
+    """Get metadata item for a share snapshot."""
+    return IMPL.share_snapshot_metadata_get_item(context,
+                                                 share_snapshot_id, key)
+
+
+def share_snapshot_metadata_delete(context, share_snapshot_id, key):
+    """Delete the given metadata item."""
+    IMPL.share_snapshot_metadata_delete(context, share_snapshot_id, key)
+
+
+def share_snapshot_metadata_update(context, share_snapshot_id,
+                                   metadata, delete):
+    """Update metadata if it exists, otherwise create it."""
+    return IMPL.share_snapshot_metadata_update(context, share_snapshot_id,
+                                               metadata, delete)
+
+
+def share_snapshot_metadata_update_item(context, share_snapshot_id,
+                                        metadata):
+    """Update metadata item if it exists, otherwise create it."""
+    return IMPL.share_snapshot_metadata_update_item(context,
+                                                    share_snapshot_id,
+                                                    metadata)
 ###################
+
+
 def security_service_create(context, values):
     """Create security service DB record."""
     return IMPL.security_service_create(context, values)
@@ -719,9 +813,9 @@ def security_service_update(context, id, values):
     return IMPL.security_service_update(context, id, values)
 
 
-def security_service_get(context, id):
+def security_service_get(context, id, **kwargs):
     """Get security service DB record."""
-    return IMPL.security_service_get(context, id)
+    return IMPL.security_service_get(context, id, **kwargs)
 
 
 def security_service_get_all(context):
@@ -734,22 +828,36 @@ def security_service_get_all_by_project(context, project_id):
     return IMPL.security_service_get_all_by_project(context, project_id)
 
 
+def security_service_get_all_by_share_network(context, share_network_id):
+    """Get all security service DB records for the given share network."""
+    return IMPL.security_service_get_all_by_share_network(context,
+                                                          share_network_id)
+
+
 ####################
-
-
 def share_metadata_get(context, share_id):
     """Get all metadata for a share."""
     return IMPL.share_metadata_get(context, share_id)
 
 
+def share_metadata_get_item(context, share_id, key):
+    """Get metadata item for given key and for a given share.."""
+    return IMPL.share_metadata_get_item(context, share_id, key)
+
+
 def share_metadata_delete(context, share_id, key):
     """Delete the given metadata item."""
-    IMPL.share_metadata_delete(context, share_id, key)
+    return IMPL.share_metadata_delete(context, share_id, key)
 
 
 def share_metadata_update(context, share, metadata, delete):
     """Update metadata if it exists, otherwise create it."""
-    IMPL.share_metadata_update(context, share, metadata, delete)
+    return IMPL.share_metadata_update(context, share, metadata, delete)
+
+
+def share_metadata_update_item(context, share_id, item):
+    """update meta item containing key and value for given share."""
+    return IMPL.share_metadata_update_item(context, share_id, item)
 
 
 ###################
@@ -837,6 +945,11 @@ def share_network_get(context, id):
     return IMPL.share_network_get(context, id)
 
 
+def share_network_get_all_by_filter(context, filters=None):
+    """Get all share network DB records for the given filter."""
+    return IMPL.share_network_get_all_by_filter(context, filters=filters)
+
+
 def share_network_get_all(context):
     """Get all share network DB records."""
     return IMPL.share_network_get_all(context)
@@ -854,17 +967,34 @@ def share_network_get_all_by_security_service(context, security_service_id):
 
 
 def share_network_add_security_service(context, id, security_service_id):
+    """Associate a security service with a share network."""
     return IMPL.share_network_add_security_service(context,
                                                    id,
                                                    security_service_id)
 
 
 def share_network_remove_security_service(context, id, security_service_id):
+    """Dissociate a security service from a share network."""
     return IMPL.share_network_remove_security_service(context,
                                                       id,
                                                       security_service_id)
 
 
+def share_network_security_service_association_get(
+        context, share_network_id, security_service_id):
+    """Get given share network and security service association."""
+    return IMPL.share_network_security_service_association_get(
+        context, share_network_id, security_service_id)
+
+
+def share_network_update_security_service(context, id,
+                                          current_security_service_id,
+                                          new_security_service_id):
+    """Update a security service association with a share network."""
+    return IMPL.share_network_update_security_service(
+        context, id, current_security_service_id, new_security_service_id)
+
+
 def count_share_networks(context, project_id, user_id=None,
                          share_type_id=None, session=None):
     return IMPL.count_share_networks(
@@ -896,29 +1026,45 @@ def share_network_subnet_get(context, network_subnet_id, session=None):
                                          session=session)
 
 
+def share_network_subnet_get_all_with_same_az(context, network_subnet_id,
+                                              session=None):
+    """Get requested az share network subnets DB record."""
+    return IMPL.share_network_subnet_get_all_with_same_az(
+        context, network_subnet_id, session=session)
+
+
 def share_network_subnet_get_all(context):
     """Get all share network subnet DB record."""
     return IMPL.share_network_subnet_get_all(context)
 
 
-def share_network_subnet_get_by_availability_zone_id(context, share_network_id,
-                                                     availability_zone_id):
-    """Get a share network subnet DB record.
+def share_network_subnets_get_all_by_availability_zone_id(
+        context, share_network_id, availability_zone_id,
+        fallback_to_default=True):
+    """Get the share network subnets DB record in a given AZ.
 
-    This method returns a subnet DB record for a given share network id and
-    an availability zone. If the 'availability_zone_id' is 'None', a record may
-    be returned and it will represent the default share network subnet.
-    Be aware that if there is no subnet for a specific availability zone id,
-    this method will return the default share network subnet, if it exists.
+    This method returns list of subnets DB record for a given share network id
+    and an availability zone. If the 'availability_zone_id' is 'None', a
+    record may be returned and it will represent the default share network
+    subnets. If there is no subnet for a specific availability zone id and
+    "fallback_to_default" is True, this method will return the default share
+    network subnets, if it exists.
     """
-    return IMPL.share_network_subnet_get_by_availability_zone_id(
-        context, share_network_id, availability_zone_id)
+    return IMPL.share_network_subnets_get_all_by_availability_zone_id(
+        context, share_network_id, availability_zone_id,
+        fallback_to_default=fallback_to_default)
 
 
-def share_network_subnet_get_default_subnet(context, share_network_id):
-    """Get the default share network subnet DB record."""
-    return IMPL.share_network_subnet_get_default_subnet(context,
-                                                        share_network_id)
+def share_network_subnet_get_default_subnets(context, share_network_id):
+    """Get the default share network subnets DB records."""
+    return IMPL.share_network_subnet_get_default_subnets(context,
+                                                         share_network_id)
+
+
+def share_network_subnet_get_all_by_share_server_id(context, share_server_id):
+    """Get the subnets that are being used by the share server."""
+    return IMPL.share_network_subnet_get_all_by_share_server_id(
+        context, share_server_id)
 
 
 ##################
@@ -947,10 +1093,12 @@ def network_allocation_get(context, id, session=None, read_deleted=None):
 
 
 def network_allocations_get_for_share_server(context, share_server_id,
-                                             session=None, label=None):
+                                             session=None, label=None,
+                                             subnet_id=None):
     """Get network allocations for share server."""
     return IMPL.network_allocations_get_for_share_server(
-        context, share_server_id, label=label, session=session)
+        context, share_server_id, label=label, session=session,
+        subnet_id=subnet_id)
 
 
 def network_allocations_get_by_ip_address(context, ip_address):
@@ -995,6 +1143,14 @@ def share_server_get_all_by_host_and_share_subnet_valid(context, host,
         context, host, share_subnet_id, session=session)
 
 
+def share_server_get_all_by_host_and_share_subnet(context, host,
+                                                  share_subnet_id,
+                                                  session=None):
+    """Get share server DB records by host and share net."""
+    return IMPL.share_server_get_all_by_host_and_share_subnet(
+        context, host, share_subnet_id, session=session)
+
+
 def share_server_get_all(context):
     """Get all share server DB records."""
     return IMPL.share_server_get_all(context)
@@ -1016,12 +1172,28 @@ def share_server_get_all_unused_deletable(context, host, updated_before):
                                                       updated_before)
 
 
+def get_all_expired_shares(context):
+    """Get all expired share DB records."""
+    return IMPL.get_all_expired_shares(context)
+
+
 def share_server_backend_details_set(context, share_server_id, server_details):
     """Create DB record with backend details."""
     return IMPL.share_server_backend_details_set(context, share_server_id,
                                                  server_details)
 
 
+def share_server_backend_details_delete(context, share_server_id):
+    """Delete backend details DB records for a share server."""
+    return IMPL.share_server_backend_details_delete(context, share_server_id)
+
+
+def share_servers_update(context, share_server_ids, values):
+    """Updates values of a bunch of share servers at once."""
+    return IMPL.share_servers_update(
+        context, share_server_ids, values)
+
+
 ##################
 
 
@@ -1483,3 +1655,22 @@ def backend_info_update(context, host, value=None,
     """Update hash info for host."""
     return IMPL.backend_info_update(context, host=host, value=value,
                                     delete_existing=delete_existing)
+
+####################
+
+
+def async_operation_data_get(context, entity_id, key=None, default=None):
+    """Get one, list or all key-value pairs for given entity_id."""
+    return IMPL.async_operation_data_get(context, entity_id, key, default)
+
+
+def async_operation_data_update(context, entity_id, details,
+                                delete_existing=False):
+    """Update key-value pairs for given entity_id."""
+    return IMPL.async_operation_data_update(context, entity_id, details,
+                                            delete_existing)
+
+
+def async_operation_data_delete(context, entity_id, key=None):
+    """Remove one, list or all key-value pairs for given entity_id."""
+    return IMPL.async_operation_data_delete(context, entity_id, key)
