@@ -315,6 +315,8 @@ class Share(BASE, ManilaBase):
 
     source_share_group_snapshot_member_id = Column(String(36), nullable=True)
     task_state = Column(String(255))
+    is_soft_deleted = Column(Boolean, default=False)
+    scheduled_to_be_deleted_at = Column(DateTime)
     instances = orm.relationship(
         "ShareInstance",
         lazy='subquery',
@@ -734,6 +736,24 @@ class ShareSnapshot(BASE, ManilaBase):
                              'ShareSnapshot.deleted == "False")')
 
 
+class ShareSnapshotMetadata(BASE, ManilaBase):
+    """Represents a metadata key/value pair for a snapshot."""
+    __tablename__ = 'share_snapshot_metadata'
+    id = Column(Integer, primary_key=True)
+    key = Column(String(255), nullable=False)
+    value = Column(String(1023), nullable=False)
+    deleted = Column(String(36), default='False')
+    share_snapshot_id = Column(String(36), ForeignKey(
+        'share_snapshots.id'), nullable=False)
+
+    share_snapshot = orm.relationship(
+        ShareSnapshot, backref="share_snapshot_metadata",
+        foreign_keys=share_snapshot_id,
+        primaryjoin='and_('
+        'ShareSnapshotMetadata.share_snapshot_id == ShareSnapshot.id,'
+        'ShareSnapshotMetadata.deleted == "False")')
+
+
 class ShareSnapshotInstance(BASE, ManilaBase):
     """Represents a snapshot of a share."""
     __tablename__ = 'share_snapshot_instances'
@@ -805,6 +825,7 @@ class ShareSnapshotInstance(BASE, ManilaBase):
         ),
         viewonly=True,
         join_depth=2,
+        sync_backref=False,
     )
     share_group_snapshot = orm.relationship(
         "ShareGroupSnapshot",
@@ -815,6 +836,7 @@ class ShareSnapshotInstance(BASE, ManilaBase):
                      'ShareSnapshotInstance.share_group_snapshot_id'),
         viewonly=True,
         join_depth=2,
+        sync_backref=False,
     )
 
 
@@ -920,6 +942,10 @@ class ShareNetwork(BASE, ManilaBase):
     user_id = Column(String(255), nullable=False)
     name = Column(String(255), nullable=True)
     description = Column(String(255), nullable=True)
+    status = Column(Enum(
+        constants.STATUS_NETWORK_ACTIVE, constants.STATUS_NETWORK_ERROR,
+        constants.STATUS_NETWORK_CHANGE),
+        default=constants.STATUS_NETWORK_ACTIVE)
     security_services = orm.relationship(
         "SecurityService",
         secondary="share_network_security_service_association",
@@ -935,7 +961,7 @@ class ShareNetwork(BASE, ManilaBase):
         'SecurityService.deleted == "False")')
     share_instances = orm.relationship(
         "ShareInstance",
-        backref='share_network',
+        backref=orm.backref('share_network'),
         primaryjoin='and_('
                     'ShareNetwork.id == ShareInstance.share_network_id,'
                     'ShareInstance.deleted == "False")')
@@ -947,6 +973,29 @@ class ShareNetwork(BASE, ManilaBase):
                     '(ShareNetwork.id == ShareNetworkSubnet.share_network_id,'
                     'ShareNetworkSubnet.deleted == "False")')
 
+    @property
+    def security_service_update_support(self):
+        share_servers_support_updating = []
+        for network_subnet in self.share_network_subnets:
+            for server in network_subnet['share_servers']:
+                share_servers_support_updating.append(
+                    server['security_service_update_support'])
+        # NOTE(carloss): all share servers within this share network must
+        # support updating security services in order to have this property
+        # set to True.
+        return all(share_servers_support_updating)
+
+    @property
+    def network_allocation_update_support(self):
+        share_servers_support_updating = []
+        for network_subnet in self.share_network_subnets:
+            for server in network_subnet['share_servers']:
+                share_servers_support_updating.append(
+                    server['network_allocation_update_support'])
+        # NOTE(felipe_rodrigues): all share servers within this share network
+        # must support updating in order to have this property set to True.
+        return all(share_servers_support_updating)
+
 
 class ShareNetworkSubnet(BASE, ManilaBase):
     """Represents a share network subnet used by some resources."""
@@ -970,11 +1019,19 @@ class ShareNetworkSubnet(BASE, ManilaBase):
         String(36), ForeignKey('availability_zones.id'), nullable=True)
 
     share_servers = orm.relationship(
-        "ShareServer", backref='share_network_subnet',
+        "ShareServer",
+        secondary="share_server_share_network_subnet_mappings",
+        backref="share_network_subnets",
         lazy='immediate',
-        primaryjoin='and_(ShareNetworkSubnet.id '
-                    '== ShareServer.share_network_subnet_id,'
-                    'ShareServer.deleted == "False")')
+        primaryjoin="and_(ShareNetworkSubnet.id == "
+                    "%(cls_name)s.share_network_subnet_id, "
+                    "%(cls_name)s.deleted == 0)" % {
+                        "cls_name": "ShareServerShareNetworkSubnetMapping"},
+        secondaryjoin='and_('
+                      'ShareServer.id == '
+                      'ShareServerShareNetworkSubnetMapping.share_server_id,'
+                      'ShareServerShareNetworkSubnetMapping.deleted == 0)'
+    )
 
     _availability_zone = orm.relationship(
         "AvailabilityZone",
@@ -1004,15 +1061,16 @@ class ShareServer(BASE, ManilaBase):
     __tablename__ = 'share_servers'
     id = Column(String(36), primary_key=True, nullable=False)
     deleted = Column(String(36), default='False')
-    share_network_subnet_id = Column(
-        String(36), ForeignKey('share_network_subnets.id'),
-        nullable=True)
     host = Column(String(255), nullable=False)
     is_auto_deletable = Column(Boolean, default=True)
     identifier = Column(String(255), nullable=True)
     task_state = Column(String(255), nullable=True)
     source_share_server_id = Column(String(36), ForeignKey('share_servers.id'),
                                     nullable=True)
+    security_service_update_support = Column(
+        Boolean, nullable=False, default=False)
+    network_allocation_update_support = Column(
+        Boolean, nullable=False, default=False)
     status = Column(Enum(
         constants.STATUS_INACTIVE, constants.STATUS_ACTIVE,
         constants.STATUS_ERROR, constants.STATUS_DELETING,
@@ -1020,7 +1078,8 @@ class ShareServer(BASE, ManilaBase):
         constants.STATUS_MANAGING, constants.STATUS_UNMANAGING,
         constants.STATUS_UNMANAGE_ERROR, constants.STATUS_MANAGE_ERROR,
         constants.STATUS_SERVER_MIGRATING,
-        constants.STATUS_SERVER_MIGRATING_TO),
+        constants.STATUS_SERVER_MIGRATING_TO,
+        constants.STATUS_SERVER_NETWORK_CHANGE),
         default=constants.STATUS_INACTIVE)
     network_allocations = orm.relationship(
         "NetworkAllocation",
@@ -1048,12 +1107,31 @@ class ShareServer(BASE, ManilaBase):
                     'ShareServerBackendDetails.share_server_id, '
                     'ShareServerBackendDetails.deleted == "False")')
 
+    _share_network_subnet_ids = orm.relationship(
+        "ShareServerShareNetworkSubnetMapping",
+        lazy='immediate',
+        viewonly=True,
+        primaryjoin='and_('
+                    'ShareServer.id == '
+                    'ShareServerShareNetworkSubnetMapping.share_server_id,'
+                    'ShareServerShareNetworkSubnetMapping.deleted == 0)')
+
     @property
     def backend_details(self):
         return {model['key']: model['value']
                 for model in self._backend_details}
 
-    _extra_keys = ['backend_details']
+    @property
+    def share_network_subnet_ids(self):
+        return [model['share_network_subnet_id']
+                for model in self._share_network_subnet_ids]
+
+    @property
+    def share_network_id(self):
+        return (self.share_network_subnets[0]['share_network_id']
+                if self.share_network_subnets else None)
+
+    _extra_keys = ['backend_details', 'share_network_subnet_ids']
 
 
 class ShareServerBackendDetails(BASE, ManilaBase):
@@ -1067,6 +1145,16 @@ class ShareServerBackendDetails(BASE, ManilaBase):
                              nullable=False)
 
 
+class ShareServerShareNetworkSubnetMapping(BASE, ManilaBase):
+    """Represents the Share Server and Share Network Subnet mapping."""
+    __tablename__ = 'share_server_share_network_subnet_mappings'
+    id = Column(Integer, primary_key=True)
+    share_server_id = Column(
+        String(36), ForeignKey('share_servers.id'), nullable=False)
+    share_network_subnet_id = Column(
+        String(36), ForeignKey('share_network_subnets.id'), nullable=False)
+
+
 class ShareNetworkSecurityServiceAssociation(BASE, ManilaBase):
     """Association table between compute_zones and compute_nodes tables."""
 
@@ -1098,6 +1186,10 @@ class NetworkAllocation(BASE, ManilaBase):
     share_server_id = Column(String(36), ForeignKey('share_servers.id'),
                              nullable=False)
 
+    # NOTE(felipe_rodrigues): admin allocation does not have subnet.
+    share_network_subnet_id = Column(
+        String(36), ForeignKey('share_network_subnets.id'), nullable=True)
+
 
 class DriverPrivateData(BASE, ManilaBase):
     """Represents a private data as key-value pairs for a driver."""
@@ -1309,6 +1401,14 @@ class BackendInfo(BASE, ManilaBase):
     info_hash = Column(String(255))
 
 
+class AsynchronousOperationData(BASE, ManilaBase):
+    """Represents data as key-value pairs for asynchronous operations."""
+    __tablename__ = 'async_operation_data'
+    entity_uuid = Column(String(36), nullable=False, primary_key=True)
+    key = Column(String(255), nullable=False, primary_key=True)
+    value = Column(String(1023), nullable=False)
+
+
 def register_models():
     """Register Models and create metadata.
 
