@@ -26,7 +26,6 @@ import re
 from oslo_concurrency import processutils
 from oslo_config import cfg
 from oslo_log import log
-import six
 import webob.exc
 
 from manila.i18n import _
@@ -82,7 +81,7 @@ class ManilaException(Exception):
                 pass
         for k, v in self.kwargs.items():
             if isinstance(v, Exception):
-                self.kwargs[k] = six.text_type(v)
+                self.kwargs[k] = str(v)
 
         if not message:
             try:
@@ -101,7 +100,7 @@ class ManilaException(Exception):
                     # at least get the core message out if something happened
                     message = self.message
         elif isinstance(message, Exception):
-            message = six.text_type(message)
+            message = str(message)
 
         if re.match(r'.*[^\.]\.\.$', message):
             message = message[:-1]
@@ -175,7 +174,7 @@ class InvalidParameterValue(Invalid):
 
 
 class InvalidUUID(Invalid):
-    message = _("Expected a uuid but received %(uuid)s.")
+    message = _("%(uuid)s is not a valid uuid.")
 
 
 class InvalidDriverMode(Invalid):
@@ -233,6 +232,11 @@ class ShareNetworkSubnetNotFound(NotFound):
                 " found.")
 
 
+class ShareNetworkSubnetNotFoundByShareServer(NotFound):
+    message = _("Share network subnet could not be found by "
+                "%(share_server_id)s.")
+
+
 class ShareServerNotFound(NotFound):
     message = _("Share server %(share_server_id)s could not be found.")
 
@@ -242,6 +246,15 @@ class ShareServerNotFoundByFilters(ShareServerNotFound):
                 "filters: %(filters_description)s.")
 
 
+class AllocationsNotFoundForShareServer(NotFound):
+    message = _("No allocations found for the share server "
+                "%(share_server_id)s on the subnet.")
+
+
+class InvalidShareNetwork(Invalid):
+    message = _("Invalid share network: %(reason)s")
+
+
 class ShareServerInUse(InUse):
     message = _("Share server %(share_server_id)s is in use.")
 
@@ -424,6 +437,12 @@ class SnapshotSizeExceedsAvailableQuota(QuotaError):
         "gigabytes quota.")
 
 
+class ShareSizeExceedsLimit(QuotaError):
+    message = _(
+        "Requested share size %(size)d is larger than "
+        "maximum allowed limit %(limit)d.")
+
+
 class ShareLimitExceeded(QuotaError):
     message = _(
         "Maximum number of shares allowed (%(allowed)d) either per "
@@ -520,6 +539,10 @@ class InvalidShareAccessLevel(Invalid):
     message = _("Invalid or unsupported share access level: %(level)s.")
 
 
+class InvalidShareAccessType(Invalid):
+    message = _("Invalid or unsupported share access type: %(type)s.")
+
+
 class ShareBackendException(ManilaException):
     message = _("Share backend error: %(msg)s.")
 
@@ -532,6 +555,10 @@ class ShareNotFound(NotFound):
     message = _("Share %(share_id)s could not be found.")
 
 
+class ShareInstanceNotFound(NotFound):
+    message = _("Share instance %(share_instance_id)s could not be found.")
+
+
 class ShareSnapshotNotFound(NotFound):
     message = _("Snapshot %(snapshot_id)s could not be found.")
 
@@ -571,7 +598,7 @@ class UnmanageInvalidShareSnapshot(InvalidShareSnapshot):
                 "invalid share snapshot: %(reason)s.")
 
 
-class ShareMetadataNotFound(NotFound):
+class MetadataItemNotFound(NotFound):
     message = _("Metadata item is not found.")
 
 
@@ -587,6 +614,10 @@ class SecurityServiceNotFound(NotFound):
     message = _("Security service %(security_service_id)s could not be found.")
 
 
+class InvalidSecurityService(Invalid):
+    message = _("Invalid security service: %(reason)s")
+
+
 class ShareNetworkSecurityServiceAssociationError(ManilaException):
     message = _("Failed to associate share network %(share_network_id)s"
                 " and security service %(security_service_id)s: %(reason)s.")
@@ -597,6 +628,10 @@ class ShareNetworkSecurityServiceDissociationError(ManilaException):
                 " and security service %(security_service_id)s: %(reason)s.")
 
 
+class SecurityServiceFailedAuth(ManilaException):
+    message = _("Failed to authenticate user against security service.")
+
+
 class InvalidVolume(Invalid):
     message = _("Invalid volume.")
 
@@ -771,6 +806,11 @@ class NetAppException(ManilaException):
     message = _("Exception due to NetApp failure.")
 
 
+class NetAppBusyAggregateForFlexGroupException(ManilaException):
+    message = _("Exception due to an aggregate being busy while trying to "
+                "provision the FlexGroup.")
+
+
 class VserverNotFound(NetAppException):
     message = _("Vserver %(vserver)s not found.")
 
@@ -1009,3 +1049,81 @@ class InfortrendCLIException(ShareBackendException):
 
 class InfortrendNASException(ShareBackendException):
     message = _("Infortrend NAS exception: %(err)s")
+
+
+# Zadara storage driver
+class ZadaraUnknownCmd(ShareBackendException):
+    message = _("Unknown or unsupported command %(cmd)s")
+
+
+class ZadaraSessionRequestException(ShareBackendException):
+    message = _("%(msg)s")
+
+
+class ZadaraBadHTTPResponseStatus(ShareBackendException):
+    message = _("Bad HTTP response status %(status)s")
+
+
+class ZadaraFailedCmdWithDump(ShareBackendException):
+    message = _("Operation failed with status=%(status)s. Full dump: %(data)s")
+
+
+class ZadaraVPSANoActiveController(ShareBackendException):
+    message = _("Unable to find any active VPSA controller")
+
+
+class ZadaraServerCreateFailure(ShareBackendException):
+    message = _("Unable to create server object for initiator %(name)s")
+
+
+class ZadaraAttachmentsNotFound(ShareBackendException):
+    message = _("Failed to retrieve attachments for volume %(name)s")
+
+
+class ZadaraManilaInvalidAccessKey(ShareBackendException):
+    message = _("Invalid VPSA access key")
+
+
+class ZadaraVPSAVolumeShareFailed(ShareBackendException):
+    message = _("Failed to create VPSA backend share. Error: %(error)s")
+
+
+class ZadaraInvalidShareAccessType(ShareBackendException):
+    message = _("Only ip access type allowed for the Zadara manila share.")
+
+
+class ZadaraShareNotFound(ShareBackendException):
+    message = _("Share %(name)s could not be found.")
+
+
+class ZadaraExtendShareFailed(ShareBackendException):
+    message = _("Failed to extend VPSA backend share. Error: %(error)s")
+
+
+class ZadaraInvalidProtocol(ShareBackendException):
+    message = _("The type of protocol %(protocol_type)s for Zadara "
+                "manila driver is not supported. Only NFS or CIFS "
+                "protocol is supported.")
+
+
+class ZadaraShareNotValid(ShareBackendException):
+    message = _("Share %(name)s is not valid.")
+
+
+class ZadaraVPSASnapshotCreateFailed(ShareBackendException):
+    message = _("Failed to create VPSA share %(name)s snapshot. "
+                "Error: %(error)s")
+
+
+class ZadaraVPSASnapshotManageFailed(ShareBackendException):
+    message = _("Failed to manage VPSA share snapshot with id %(snap_id)s. "
+                "Error: %(error)s")
+
+
+class ZadaraServerNotFound(NotFound):
+    message = _("Unable to find server object for initiator %(name)s")
+
+
+# Macrosan Storage driver
+class MacrosanBackendExeption(ShareBackendException):
+    message = _("Macrosan backend exception: %(reason)s")
