@@ -15,7 +15,6 @@
 #    under the License.
 
 import ipaddress
-import six
 import socket
 
 from oslo_config import cfg
@@ -36,8 +35,7 @@ neutron_network_plugin_opts = [
         'neutron_physical_net_name',
         help="The name of the physical network to determine which net segment "
              "is used. This opt is optional and will only be used for "
-             "networks configured with multiple segments.",
-        deprecated_group='DEFAULT'),
+             "networks configured with multiple segments."),
 ]
 
 neutron_single_network_plugin_opts = [
@@ -45,15 +43,13 @@ neutron_single_network_plugin_opts = [
         'neutron_net_id',
         help="Default Neutron network that will be used for share server "
              "creation. This opt is used only with "
-             "class 'NeutronSingleNetworkPlugin'.",
-        deprecated_group='DEFAULT'),
+             "class 'NeutronSingleNetworkPlugin'."),
     cfg.StrOpt(
         'neutron_subnet_id',
         help="Default Neutron subnet that will be used for share server "
              "creation. Should be assigned to network defined in opt "
              "'neutron_net_id'. This opt is used only with "
-             "class 'NeutronSingleNetworkPlugin'.",
-        deprecated_group='DEFAULT'),
+             "class 'NeutronSingleNetworkPlugin'."),
 ]
 
 neutron_bind_network_plugin_opts = [
@@ -125,9 +121,16 @@ class NeutronNetworkPlugin(network.NetworkBaseAPI):
                                                 **self._neutron_api_kwargs)
         return self._neutron_api
 
-    def _store_neutron_net_info(self, context, share_network_subnet):
-        self._save_neutron_network_data(context, share_network_subnet)
-        self._save_neutron_subnet_data(context, share_network_subnet)
+    def include_network_info(self, share_network_subnet):
+        """Includes share-network-subnet with plugin specific data."""
+        self._store_neutron_net_info(None, share_network_subnet, save_db=False)
+
+    def _store_neutron_net_info(self, context, share_network_subnet,
+                                save_db=True):
+        self._save_neutron_network_data(context, share_network_subnet,
+                                        save_db=save_db)
+        self._save_neutron_subnet_data(context, share_network_subnet,
+                                       save_db=save_db)
 
     def allocate_network(self, context, share_server, share_network=None,
                          share_network_subnet=None, **kwargs):
@@ -189,7 +192,7 @@ class NeutronNetworkPlugin(network.NetworkBaseAPI):
             remaining_allocations, port_list)
 
         LOG.debug("Found matching allocations in Neutron:"
-                  " %s", six.text_type(selected_ports))
+                  " %s", selected_ports)
 
         for selected_port in selected_ports:
             port_dict = {
@@ -206,6 +209,11 @@ class NeutronNetworkPlugin(network.NetworkBaseAPI):
                 'cidr': share_network_subnet['cidr'],
                 'mtu': share_network_subnet['mtu'],
             }
+            # NOTE(felipe_rodrigues): admin plugin does not have any Manila
+            # share net subnet, its data is from manila configuration file.
+            if self.label != 'admin':
+                port_dict['share_network_subnet_id'] = (
+                    share_network_subnet['id'])
 
             # There should not be existing allocations with the same port_id.
             try:
@@ -275,7 +283,7 @@ class NeutronNetworkPlugin(network.NetworkBaseAPI):
 
         for ip in fixed_ips:
             try:
-                address = ipaddress.ip_address(six.text_type(ip['ip_address']))
+                address = ipaddress.ip_address(str(ip['ip_address']))
                 if address.version == ip_version:
                     return ip['ip_address']
             except ValueError:
@@ -336,6 +344,12 @@ class NeutronNetworkPlugin(network.NetworkBaseAPI):
             'cidr': share_network_subnet['cidr'],
             'mtu': share_network_subnet['mtu'],
         }
+        # NOTE(felipe_rodrigues): admin plugin does not have any Manila
+        # share net subnet, its data is from manila configuration file.
+        if self.label != 'admin':
+            port_dict['share_network_subnet_id'] = (
+                share_network_subnet['id'])
+
         return self.db.network_allocation_create(context, port_dict)
 
     def _delete_port(self, context, port):
@@ -358,7 +372,8 @@ class NeutronNetworkPlugin(network.NetworkBaseAPI):
                 share_network_subnet['neutron_net_id'])
         return 'segments' in net_info
 
-    def _save_neutron_network_data(self, context, share_network_subnet):
+    def _save_neutron_network_data(self, context, share_network_subnet,
+                                   save_db=True):
         net_info = self.neutron_api.get_network(
             share_network_subnet['neutron_net_id'])
         segmentation_id = None
@@ -383,21 +398,22 @@ class NeutronNetworkPlugin(network.NetworkBaseAPI):
                        "(found: %s)." % (phy, phy_nets))
                 raise exception.NetworkBadConfigurationException(reason=msg)
         else:
-            network_type = net_info['provider:network_type']
-            segmentation_id = net_info['provider:segmentation_id']
+            network_type = net_info.get('provider:network_type')
+            segmentation_id = net_info.get('provider:segmentation_id')
 
         provider_nw_dict = {
             'network_type': network_type,
             'segmentation_id': segmentation_id,
-            'mtu': net_info['mtu'],
+            'mtu': net_info.get('mtu'),
         }
         share_network_subnet.update(provider_nw_dict)
 
-        if self.label != 'admin':
+        if self.label != 'admin' and save_db:
             self.db.share_network_subnet_update(
                 context, share_network_subnet['id'], provider_nw_dict)
 
-    def _save_neutron_subnet_data(self, context, share_network_subnet):
+    def _save_neutron_subnet_data(self, context, share_network_subnet,
+                                  save_db=True):
         subnet_info = self.neutron_api.get_subnet(
             share_network_subnet['neutron_subnet_id'])
 
@@ -408,7 +424,7 @@ class NeutronNetworkPlugin(network.NetworkBaseAPI):
         }
         share_network_subnet.update(subnet_values)
 
-        if self.label != 'admin':
+        if self.label != 'admin' and save_db:
             self.db.share_network_subnet_update(
                 context, share_network_subnet['id'], subnet_values)
 
@@ -535,7 +551,7 @@ class NeutronBindNetworkPlugin(NeutronNetworkPlugin):
             self._wait_for_ports_bind(ports, share_server)
             return ports
 
-    @utils.retry(exception.NetworkBindException, retries=20)
+    @utils.retry(retry_param=exception.NetworkBindException, retries=20)
     def _wait_for_ports_bind(self, ports, share_server):
         inactive_ports = []
         for port in ports:
@@ -580,7 +596,8 @@ class NeutronBindNetworkPlugin(NeutronNetworkPlugin):
                 "local_link_information": local_links}
         return arguments
 
-    def _save_neutron_network_data(self, context, share_network_subnet):
+    def _save_neutron_network_data(self, context, share_network_subnet,
+                                   save_db=True):
         """Store the Neutron network info.
 
         In case of dynamic multi segments the segment is determined while
@@ -593,12 +610,14 @@ class NeutronBindNetworkPlugin(NeutronNetworkPlugin):
         if self._is_neutron_multi_segment(share_network_subnet):
             # In case of dynamic multi segment the segment is determined while
             # binding the port, only mtu is known and already needed
-            self._save_neutron_network_mtu(context, share_network_subnet)
+            self._save_neutron_network_mtu(context, share_network_subnet,
+                                           save_db=save_db)
             return
         super(NeutronBindNetworkPlugin, self)._save_neutron_network_data(
-            context, share_network_subnet)
+            context, share_network_subnet, save_db=save_db)
 
-    def _save_neutron_network_mtu(self, context, share_network_subnet):
+    def _save_neutron_network_mtu(self, context, share_network_subnet,
+                                  save_db=True):
         """Store the Neutron network mtu.
 
         In case of dynamic multi segments only the mtu needs storing before
@@ -612,7 +631,7 @@ class NeutronBindNetworkPlugin(NeutronNetworkPlugin):
         }
         share_network_subnet.update(mtu_dict)
 
-        if self.label != 'admin':
+        if self.label != 'admin' and save_db:
             self.db.share_network_subnet_update(
                 context, share_network_subnet['id'], mtu_dict)
 
