@@ -54,22 +54,14 @@ SUPPORTED_NETWORK_TYPES = (None, 'flat', 'vlan')
 UNITY_OPTS = [
     cfg.StrOpt('unity_server_meta_pool',
                required=True,
-               deprecated_name='emc_nas_server_pool',
                help='Pool to persist the meta-data of NAS server.'),
     cfg.ListOpt('unity_share_data_pools',
-                deprecated_name='emc_nas_pool_names',
                 help='Comma separated list of pools that can be used to '
                      'persist share data.'),
     cfg.ListOpt('unity_ethernet_ports',
-                deprecated_name='emc_interface_ports',
                 help='Comma separated list of ports that can be used for '
                      'share server interfaces. Members of the list '
                      'can be Unix-style glob expressions.'),
-    cfg.StrOpt('emc_nas_server_container',
-               deprecated_for_removal=True,
-               deprecated_reason='Unity driver supports nas server auto load '
-                                 'balance.',
-               help='Storage processor to host the NAS server. Obsolete.'),
     cfg.StrOpt('unity_share_server',
                help='NAS server used for creating share when driver '
                     'is in DHSS=False mode. It is required when '
@@ -100,6 +92,8 @@ class UnityStorageConnection(driver.StorageConnection):
         self.pool_set = None
         self.nas_server_pool = None
         self.reserved_percentage = None
+        self.reserved_snapshot_percentage = None
+        self.reserved_share_extend_percentage = None
         self.max_over_subscription_ratio = None
         self.port_ids_conf = None
         self.unity_share_server = None
@@ -115,6 +109,10 @@ class UnityStorageConnection(driver.StorageConnection):
 
         # props from super class.
         self.driver_handles_share_servers = (True, False)
+        self.dhss_mandatory_security_service_association = {
+            'nfs': None,
+            'cifs': ['active_directory', ]
+        }
 
     def connect(self, emc_share_driver, context):
         """Connect to Unity storage."""
@@ -133,6 +131,16 @@ class UnityStorageConnection(driver.StorageConnection):
         if self.reserved_percentage is None:
             self.reserved_percentage = 0
 
+        self.reserved_snapshot_percentage = config.safe_get(
+            'reserved_share_from_snapshot_percentage')
+        if self.reserved_snapshot_percentage is None:
+            self.reserved_snapshot_percentage = self.reserved_percentage
+
+        self.reserved_share_extend_percentage = config.safe_get(
+            'reserved_share_extend_percentage')
+        if self.reserved_share_extend_percentage is None:
+            self.reserved_share_extend_percentage = self.reserved_percentage
+
         self.max_over_subscription_ratio = config.safe_get(
             'max_over_subscription_ratio')
         self.port_ids_conf = config.safe_get('unity_ethernet_ports')
@@ -589,6 +597,10 @@ class UnityStorageConnection(driver.StorageConnection):
                         enas_utils.bytes_to_gb(pool.size_subscribed),
                     'qos': False,
                     'reserved_percentage': self.reserved_percentage,
+                    'reserved_snapshot_percentage':
+                        self.reserved_snapshot_percentage,
+                    'reserved_share_extend_percentage':
+                        self.reserved_share_extend_percentage,
                     'max_over_subscription_ratio':
                         self.max_over_subscription_ratio,
                 }
