@@ -21,11 +21,11 @@ import xml.etree.cElementTree as etree
 
 from oslo_config import cfg
 from oslo_log import log
-import six
 
 from manila import exception
 from manila.i18n import _
 from manila.share.drivers.ganesha import utils as ganesha_utils
+from manila import utils
 
 LOG = log.getLogger(__name__)
 
@@ -33,13 +33,11 @@ LOG = log.getLogger(__name__)
 glusterfs_common_opts = [
     cfg.StrOpt('glusterfs_server_password',
                secret=True,
-               deprecated_name='glusterfs_native_server_password',
                help='Remote GlusterFS server node\'s login password. '
                     'This is not required if '
                     '\'glusterfs_path_to_private_key\' is '
                     'configured.'),
     cfg.StrOpt('glusterfs_path_to_private_key',
-               deprecated_name='glusterfs_native_path_to_private_key',
                help='Path of Manila host\'s private SSH key file.'),
 ]
 
@@ -315,6 +313,7 @@ class GlusterManager(object):
                 'volume': self.volume, 'option': option, 'value': value})
 
     @_check_volume_presence
+    @utils.retry(retry_param=exception.GlusterfsException)
     def set_vol_option(self, option, value, ignore_failure=False):
         value = {True: self.GLUSTERFS_TRUE_VALUES[0],
                  False: self.GLUSTERFS_FALSE_VALUES[0]}.get(value, value)
@@ -361,7 +360,7 @@ class GlusterManager(object):
                 "%(server)s, minimum requirement: %(minvers)s") % {
                 'server': self.host,
                 'version': '.'.join(vers),
-                'minvers': '.'.join(six.text_type(c) for c in minvers)})
+                'minvers': '.'.join(str(c) for c in minvers)})
 
 
 def numreduct(vers):
