@@ -18,12 +18,12 @@ from oslo_log import log
 from oslo_utils import strutils
 from oslo_utils import units
 import paramiko
-import six
 
+import os
 import time
 
 from manila import exception
-from manila.i18n import _, _LE, _LW
+from manila.i18n import _
 from manila import utils as mutils
 
 LOG = log.getLogger(__name__)
@@ -38,7 +38,7 @@ class HNASSSHBackend(object):
         self.password = hnas_password
         self.priv_key = ssh_private_key
         self.admin_ip0 = cluster_admin_ip0
-        self.evs_id = six.text_type(evs_id)
+        self.evs_id = str(evs_id)
         self.fs_name = fs_name
         self.evs_ip = evs_ip
         self.sshpool = None
@@ -54,111 +54,196 @@ class HNASSSHBackend(object):
         dedupe = True if dedupe is enabled on filesystem.
         """
         command = ['df', '-a', '-f', self.fs_name]
-        output, err = self._execute(command)
+        try:
+            output, err = self._execute(command)
+
+        except processutils.ProcessExecutionError:
+            msg = _("Could not get HNAS backend stats.")
+            LOG.exception(msg)
+            raise exception.HNASBackendException(msg=msg)
 
         line = output.split('\n')
         fs = Filesystem(line[3])
         available_space = fs.size - fs.used
         return fs.size, available_space, fs.dedupe
 
-    def nfs_export_add(self, share_id):
-        path = '/shares/' + share_id
+    def nfs_export_add(self, share_id, snapshot_id=None):
+        if snapshot_id is not None:
+            path = os.path.join('/snapshots', share_id, snapshot_id)
+            name = os.path.join('/snapshots', snapshot_id)
+        else:
+            path = name = os.path.join('/shares', share_id)
+
         command = ['nfs-export', 'add', '-S', 'disable', '-c', '127.0.0.1',
-                   path, self.fs_name, path]
+                   name, self.fs_name, path]
         try:
             self._execute(command)
         except processutils.ProcessExecutionError:
-            msg = _("Could not create NFS export %s.") % share_id
+            msg = _("Could not create NFS export %s.") % name
             LOG.exception(msg)
             raise exception.HNASBackendException(msg=msg)
 
-    def nfs_export_del(self, share_id):
-        path = '/shares/' + share_id
-        command = ['nfs-export', 'del', path]
+    def nfs_export_del(self, share_id=None, snapshot_id=None):
+        if share_id is not None:
+            name = os.path.join('/shares', share_id)
+        elif snapshot_id is not None:
+            name = os.path.join('/snapshots', snapshot_id)
+        else:
+            msg = _("NFS export not specified to delete.")
+            raise exception.HNASBackendException(msg=msg)
+
+        command = ['nfs-export', 'del', name]
         try:
             self._execute(command)
         except processutils.ProcessExecutionError as e:
             if 'does not exist' in e.stderr:
-                LOG.warning(_LW("Export %s does not exist on "
-                                "backend anymore."), path)
+                LOG.warning("Export %s does not exist on "
+                            "backend anymore.", name)
             else:
-                msg = six.text_type(e)
+                msg = _("Could not delete NFS export %s.") % name
                 LOG.exception(msg)
                 raise exception.HNASBackendException(msg=msg)
 
-    def cifs_share_add(self, share_id):
-        path = r'\\shares\\' + share_id
+    def cifs_share_add(self, share_id, snapshot_id=None):
+        if snapshot_id is not None:
+            path = r'\\snapshots\\' + share_id + r'\\' + snapshot_id
+            name = snapshot_id
+        else:
+            path = r'\\shares\\' + share_id
+            name = share_id
         command = ['cifs-share', 'add', '-S', 'disable', '--enable-abe',
-                   '--nodefaultsaa', share_id, self.fs_name, path]
+                   '--nodefaultsaa', name, self.fs_name, path]
         try:
             self._execute(command)
         except processutils.ProcessExecutionError:
-            msg = _("Could not create CIFS share %s.") % share_id
+            msg = _("Could not create CIFS share %s.") % name
             LOG.exception(msg)
             raise exception.HNASBackendException(msg=msg)
 
-    def cifs_share_del(self, share_id):
+    def cifs_share_del(self, name):
         command = ['cifs-share', 'del', '--target-label', self.fs_name,
-                   share_id]
+                   name]
         try:
             self._execute(command)
         except processutils.ProcessExecutionError as e:
             if e.exit_code == 1:
-                LOG.warning(_LW("CIFS share %s does not exist on "
-                                "backend anymore."), share_id)
+                LOG.warning("CIFS share %s does not exist on "
+                            "backend anymore.", name)
             else:
-                msg = six.text_type(e)
+                msg = _("Could not delete CIFS share %s.") % name
                 LOG.exception(msg)
                 raise exception.HNASBackendException(msg=msg)
 
     def get_nfs_host_list(self, share_id):
-        export = self._get_share_export(share_id)
+        export = self._get_export(share_id)
         return export[0].export_configuration
 
-    def update_nfs_access_rule(self, share_id, host_list):
+    def update_nfs_access_rule(self, host_list, share_id=None,
+                               snapshot_id=None):
+        if share_id is not None:
+            name = os.path.join('/shares', share_id)
+        elif snapshot_id is not None:
+            name = os.path.join('/snapshots', snapshot_id)
+        else:
+            msg = _("No share/snapshot provided to update NFS rules.")
+            raise exception.HNASBackendException(msg=msg)
+
         command = ['nfs-export', 'mod', '-c']
 
         if len(host_list) == 0:
             command.append('127.0.0.1')
         else:
-            string_command = '"' + six.text_type(host_list[0])
+            string_command = '"' + str(host_list[0])
 
             for i in range(1, len(host_list)):
-                string_command += ',' + (six.text_type(host_list[i]))
+                string_command += ',' + (str(host_list[i]))
             string_command += '"'
             command.append(string_command)
 
-        path = '/shares/' + share_id
-        command.append(path)
-        self._execute(command)
+        command.append(name)
+        try:
+            self._execute(command)
+        except processutils.ProcessExecutionError:
+            msg = _("Could not update access rules for NFS export %s.") % name
+            LOG.exception(msg)
+            raise exception.HNASBackendException(msg=msg)
 
-    def cifs_allow_access(self, hnas_share_id, user, permission):
+    def cifs_allow_access(self, name, user, permission, is_snapshot=False):
         command = ['cifs-saa', 'add', '--target-label', self.fs_name,
-                   hnas_share_id, user, permission]
+                   name, user, permission]
+
         try:
             self._execute(command)
         except processutils.ProcessExecutionError as e:
             if 'already listed as a user' in e.stderr:
-                LOG.debug('User %(user)s already allowed to access share '
-                          '%(share)s.', {'user': user, 'share': hnas_share_id})
+                if is_snapshot:
+                    LOG.debug('User %(user)s already allowed to access '
+                              'snapshot %(snapshot)s.', {
+                                  'user': user,
+                                  'snapshot': name,
+                              })
+                else:
+                    self._update_cifs_rule(name, user, permission)
             else:
-                msg = six.text_type(e)
-                LOG.exception(msg)
-                raise exception.InvalidShareAccess(reason=msg)
+                entity_type = "share"
+                if is_snapshot:
+                    entity_type = "snapshot"
 
-    def cifs_deny_access(self, hnas_share_id, user):
+                msg = _("Could not add access of user %(user)s to "
+                        "%(entity_type)s %(name)s.") % {
+                            'user': user,
+                            'name': name,
+                            'entity_type': entity_type,
+                    }
+                LOG.exception(msg)
+                raise exception.HNASBackendException(msg=msg)
+
+    def _update_cifs_rule(self, name, user, permission):
+        LOG.debug('User %(user)s already allowed to access '
+                  'share %(share)s. Updating access level...', {
+                      'user': user,
+                      'share': name,
+                  })
+
+        command = ['cifs-saa', 'change', '--target-label', self.fs_name,
+                   name, user, permission]
+        try:
+            self._execute(command)
+        except processutils.ProcessExecutionError:
+            msg = _("Could not update access of user %(user)s to "
+                    "share %(share)s.") % {
+                        'user': user,
+                        'share': name,
+                }
+            LOG.exception(msg)
+            raise exception.HNASBackendException(msg=msg)
+
+    def cifs_deny_access(self, name, user, is_snapshot=False):
         command = ['cifs-saa', 'delete', '--target-label', self.fs_name,
-                   hnas_share_id, user]
+                   name, user]
+
+        entity_type = "share"
+        if is_snapshot:
+            entity_type = "snapshot"
+
         try:
             self._execute(command)
         except processutils.ProcessExecutionError as e:
             if ('not listed as a user' in e.stderr or
                     'Could not delete user/group' in e.stderr):
-                LOG.warning(_LW('User %(user)s already not allowed to access '
-                                'share %(share)s.'),
-                            {'user': user, 'share': hnas_share_id})
+                LOG.warning('User %(user)s already not allowed to access '
+                            '%(entity_type)s %(name)s.', {
+                                'entity_type': entity_type,
+                                'user': user,
+                                'name': name
+                            })
             else:
-                msg = six.text_type(e)
+                msg = _("Could not delete access of user %(user)s to "
+                        "%(entity_type)s %(name)s.") % {
+                    'user': user,
+                    'name': name,
+                    'entity_type': entity_type,
+                    }
                 LOG.exception(msg)
                 raise exception.HNASBackendException(msg=msg)
 
@@ -173,7 +258,7 @@ class HNASSSHBackend(object):
                           'added.', {'share': hnas_share_id})
                 return []
             else:
-                msg = six.text_type(e)
+                msg = _("Could not list access of share %s.") % hnas_share_id
                 LOG.exception(msg)
                 raise exception.HNASBackendException(msg=msg)
 
@@ -189,10 +274,12 @@ class HNASSSHBackend(object):
         except processutils.ProcessExecutionError as e:
             if ('Cannot find any clonable files in the source directory' in
                     e.stderr):
-                msg = _("Source path %s is empty") % src_path
+                msg = _("Source path %s is empty.") % src_path
+                LOG.debug(msg)
                 raise exception.HNASNothingToCloneException(msg=msg)
             else:
-                msg = six.text_type(e)
+                msg = _("Could not submit tree clone job to clone from %(src)s"
+                        " to %(dest)s.") % {'src': src_path, 'dest': dest_path}
                 LOG.exception(msg)
                 raise exception.HNASBackendException(msg=msg)
 
@@ -224,10 +311,10 @@ class HNASSSHBackend(object):
                     if now > deadline:
                         command = ['tree-clone-job-abort', job_id]
                         self._execute(command)
-                        LOG.error(_LE("Timeout in snapshot creation from "
-                                      "source path %s.") % src_path)
-                        msg = (_("Share snapshot of source path %s "
-                                 "was not created.") % src_path)
+                        LOG.error("Timeout in snapshot creation from "
+                                  "source path %s.", src_path)
+                        msg = _("Share snapshot of source path %s "
+                                "was not created.") % src_path
                         raise exception.HNASBackendException(msg=msg)
                     else:
                         time.sleep(job_rechecks ** 2)
@@ -239,15 +326,15 @@ class HNASSSHBackend(object):
                 job_status.files_missing) == ("Job was completed",
                                               "Success", '0', '0'):
 
-                LOG.debug("Snapshot of source path %(src)s to destination"
+                LOG.debug("Snapshot of source path %(src)s to destination "
                           "path %(dest)s created successfully.",
                           {'src': src_path,
                            'dest': dest_path})
             else:
-                LOG.error(_LE('Error creating snapshot of source path %s.'),
+                LOG.error('Error creating snapshot of source path %s.',
                           src_path)
-                msg = (_('Snapshot of source path %s was not created.') %
-                       src_path)
+                msg = _('Snapshot of source path %s was not '
+                        'created.') % src_path
                 raise exception.HNASBackendException(msg=msg)
 
     def tree_delete(self, path):
@@ -257,25 +344,73 @@ class HNASSSHBackend(object):
             self._execute(command)
         except processutils.ProcessExecutionError as e:
             if 'Source path: Cannot access' in e.stderr:
-                LOG.warning(_LW("Attempted to delete path %s "
-                                "but it does not exist."), path)
+                LOG.warning("Attempted to delete path %s "
+                            "but it does not exist.", path)
             else:
-                msg = six.text_type(e)
+                msg = _("Could not submit tree delete job to delete path "
+                        "%s.") % path
                 LOG.exception(msg)
-                raise
+                raise exception.HNASBackendException(msg=msg)
 
+    @mutils.retry(retry_param=exception.HNASSSCContextChange, wait_random=True,
+                  retries=5)
     def create_directory(self, dest_path):
         self._locked_selectfs('create', dest_path)
+        if not self.check_directory(dest_path):
+            msg = _("Command to create directory %(path)s was run in another "
+                    "filesystem instead of %(fs)s.") % {
+                'path': dest_path,
+                'fs': self.fs_name,
+            }
+            LOG.warning(msg)
+            raise exception.HNASSSCContextChange(msg=msg)
 
+    @mutils.retry(retry_param=exception.HNASSSCContextChange, wait_random=True,
+                  retries=5)
     def delete_directory(self, path):
-        self._locked_selectfs('delete', path)
+        try:
+            self._locked_selectfs('delete', path)
+        except exception.HNASDirectoryNotEmpty:
+            pass
+        else:
+            if self.check_directory(path):
+                msg = _("Command to delete empty directory %(path)s was run in"
+                        " another filesystem instead of %(fs)s.") % {
+                            'path': path,
+                            'fs': self.fs_name,
+                    }
+                LOG.debug(msg)
+                raise exception.HNASSSCContextChange(msg=msg)
+
+    @mutils.retry(retry_param=exception.HNASSSCIsBusy, wait_random=True,
+                  retries=5)
+    def check_directory(self, path):
+        command = ['path-to-object-number', '-f', self.fs_name, path]
+
+        try:
+            self._execute(command)
+        except processutils.ProcessExecutionError as e:
+            if 'path-to-object-number is currently running' in e.stdout:
+                msg = (_("SSC command path-to-object-number for path %s "
+                         "is currently busy.") % path)
+                raise exception.HNASSSCIsBusy(msg=msg)
+            if 'Unable to locate component:' in e.stdout:
+                LOG.debug("Cannot find %(path)s: %(out)s",
+                          {'path': path, 'out': e.stdout})
+                return False
+            else:
+                msg = _("Could not check if path %s exists.") % path
+                LOG.exception(msg)
+                raise exception.HNASBackendException(msg=msg)
+        return True
 
     def check_fs_mounted(self):
         command = ['df', '-a', '-f', self.fs_name]
         output, err = self._execute(command)
         if "not found" in output:
-            msg = (_("Filesystem %s does not exist or it is not available "
-                     "in the current EVS context.") % self.fs_name)
+            msg = _("Filesystem %s does not exist or it is not available "
+                    "in the current EVS context.") % self.fs_name
+            LOG.error(msg)
             raise exception.HNASItemNotFoundException(msg=msg)
         else:
             line = output.split('\n')
@@ -288,16 +423,21 @@ class HNASSSHBackend(object):
             self._execute(command)
         except processutils.ProcessExecutionError as e:
             if 'file system is already mounted' not in e.stderr:
-                msg = six.text_type(e)
+                msg = _("Failed to mount filesystem %s.") % self.fs_name
                 LOG.exception(msg)
-                raise
+                raise exception.HNASBackendException(msg=msg)
 
     def vvol_create(self, vvol_name):
         # create a virtual-volume inside directory
         path = '/shares/' + vvol_name
         command = ['virtual-volume', 'add', '--ensure', self.fs_name,
                    vvol_name, path]
-        self._execute(command)
+        try:
+            self._execute(command)
+        except processutils.ProcessExecutionError:
+            msg = _("Failed to create vvol %s.") % vvol_name
+            LOG.exception(msg)
+            raise exception.HNASBackendException(msg=msg)
 
     def vvol_delete(self, vvol_name):
         path = '/shares/' + vvol_name
@@ -308,52 +448,71 @@ class HNASSSHBackend(object):
             self._execute(command)
         except processutils.ProcessExecutionError as e:
             if 'Source path: Cannot access' in e.stderr:
-                LOG.debug("Share %(shr)s does not exist.",
-                          {'shr': vvol_name})
+                LOG.warning("Share %s does not exist.", vvol_name)
             else:
-                msg = six.text_type(e)
+                msg = _("Failed to delete vvol %s.") % vvol_name
                 LOG.exception(msg)
-                raise e
+                raise exception.HNASBackendException(msg=msg)
 
     def quota_add(self, vvol_name, vvol_quota):
-        str_quota = six.text_type(vvol_quota) + 'G'
+        str_quota = str(vvol_quota) + 'G'
         command = ['quota', 'add', '--usage-limit',
                    str_quota, '--usage-hard-limit',
                    'yes', self.fs_name, vvol_name]
-        self._execute(command)
+        try:
+            self._execute(command)
+        except processutils.ProcessExecutionError:
+            msg = _("Failed to add %(quota)s quota to vvol "
+                    "%(vvol)s.") % {'quota': str_quota, 'vvol': vvol_name}
+            LOG.exception(msg)
+            raise exception.HNASBackendException(msg=msg)
 
     def modify_quota(self, vvol_name, new_size):
-        str_quota = six.text_type(new_size) + 'G'
+        str_quota = str(new_size) + 'G'
         command = ['quota', 'mod', '--usage-limit', str_quota,
                    self.fs_name, vvol_name]
-        self._execute(command)
+        try:
+            self._execute(command)
+        except processutils.ProcessExecutionError:
+            msg = _("Failed to update quota of vvol %(vvol)s to "
+                    "%(quota)s.") % {'quota': str_quota, 'vvol': vvol_name}
+            LOG.exception(msg)
+            raise exception.HNASBackendException(msg=msg)
 
     def check_vvol(self, vvol_name):
         command = ['virtual-volume', 'list', '--verbose', self.fs_name,
                    vvol_name]
         try:
             self._execute(command)
-        except processutils.ProcessExecutionError as e:
-            msg = six.text_type(e)
+        except processutils.ProcessExecutionError:
+            msg = _("Virtual volume %s does not exist.") % vvol_name
             LOG.exception(msg)
-            msg = (_("Virtual volume %s does not exist.") % vvol_name)
             raise exception.HNASItemNotFoundException(msg=msg)
 
     def check_quota(self, vvol_name):
         command = ['quota', 'list', '--verbose', self.fs_name, vvol_name]
-        output, err = self._execute(command)
+        try:
+            output, err = self._execute(command)
+
+        except processutils.ProcessExecutionError:
+            msg = _("Could not check quota of vvol %s.") % vvol_name
+            LOG.exception(msg)
+            raise exception.HNASBackendException(msg=msg)
 
         if 'No quotas matching specified filter criteria' in output:
-            msg = (_("Virtual volume %s does not have any quota.") % vvol_name)
+            msg = _("Virtual volume %s does not have any"
+                    " quota.") % vvol_name
+            LOG.error(msg)
             raise exception.HNASItemNotFoundException(msg=msg)
 
-    def check_export(self, vvol_name):
-        export = self._get_share_export(vvol_name)
+    def check_export(self, vvol_name, is_snapshot=False):
+        export = self._get_export(vvol_name, is_snapshot=is_snapshot)
         if (vvol_name in export[0].export_name and
                 self.fs_name in export[0].file_system_label):
             return
         else:
             msg = _("Export %s does not exist.") % export[0].export_name
+            LOG.error(msg)
             raise exception.HNASItemNotFoundException(msg=msg)
 
     def check_cifs(self, vvol_name):
@@ -366,6 +525,7 @@ class HNASSSHBackend(object):
                     "configured filesystem "
                     "%(fs)s.") % {'share': vvol_name,
                                   'fs': self.fs_name}
+            LOG.error(msg)
             raise exception.HNASItemNotFoundException(msg=msg)
 
     def is_cifs_in_use(self, vvol_name):
@@ -384,9 +544,13 @@ class HNASSSHBackend(object):
                 msg = _("CIFS share %(share)s was not found in EVS "
                         "%(evs_id)s") % {'share': vvol_name,
                                          'evs_id': self.evs_id}
+                LOG.exception(msg)
                 raise exception.HNASItemNotFoundException(msg=msg)
             else:
-                raise
+                msg = _("Could not list CIFS shares by vvol name "
+                        "%s.") % vvol_name
+                LOG.exception(msg)
+                raise exception.HNASBackendException(msg=msg)
 
         return output
 
@@ -404,8 +568,9 @@ class HNASSSHBackend(object):
         elif quota.limit_unit == 'GB':
             return quota.limit
         else:
-            msg = (_("Share %s does not support quota values "
-                     "below 1G.") % share_id)
+            msg = _("Share %s does not support quota values "
+                    "below 1G.") % share_id
+            LOG.error(msg)
             raise exception.HNASBackendException(msg=msg)
 
     def get_share_usage(self, share_id):
@@ -415,27 +580,37 @@ class HNASSSHBackend(object):
         quota = Quota(output)
 
         if quota.usage is None:
-            msg = (_("Virtual volume %s does not have any quota.") % share_id)
+            msg = _("Virtual volume %s does not have any quota.") % share_id
+            LOG.error(msg)
             raise exception.HNASItemNotFoundException(msg=msg)
         else:
-            bytes_usage = strutils.string_to_bytes(six.text_type(quota.usage) +
+            bytes_usage = strutils.string_to_bytes(str(quota.usage) +
                                                    quota.usage_unit)
             return bytes_usage / units.Gi
 
-    def _get_share_export(self, share_id):
-        share_id = '/shares/' + share_id
-        command = ['nfs-export', 'list ', share_id]
+    def _get_export(self, name, is_snapshot=False):
+        if is_snapshot:
+            name = '/snapshots/' + name
+        else:
+            name = '/shares/' + name
+
+        command = ['nfs-export', 'list ', name]
         export_list = []
         try:
             output, err = self._execute(command)
         except processutils.ProcessExecutionError as e:
             if 'does not exist' in e.stderr:
-                msg = _("Export %(share)s was not found in EVS "
-                        "%(evs_id)s") % {'share': share_id,
-                                         'evs_id': self.evs_id}
+                msg = _("Export %(name)s was not found in EVS "
+                        "%(evs_id)s.") % {
+                            'name': name,
+                            'evs_id': self.evs_id,
+                }
+                LOG.exception(msg)
                 raise exception.HNASItemNotFoundException(msg=msg)
             else:
-                raise
+                msg = _("Could not list NFS exports by name %s.") % name
+                LOG.exception(msg)
+                raise exception.HNASBackendException(msg=msg)
         items = output.split('Export name')
 
         if items[0][0] == '\n':
@@ -445,13 +620,13 @@ class HNASSSHBackend(object):
             export_list.append(Export(items[i]))
         return export_list
 
-    @mutils.retry(exception=exception.HNASConnException, wait_random=True)
+    @mutils.retry(retry_param=exception.HNASConnException, wait_random=True)
     def _execute(self, commands):
         command = ['ssc', '127.0.0.1']
         if self.admin_ip0 is not None:
             command = ['ssc', '--smuauth', self.admin_ip0]
 
-        command = command + ['console-context', '--evs', self.evs_id]
+        command += ['console-context', '--evs', self.evs_id]
         commands = command + commands
 
         mutils.check_ssh_injection(commands)
@@ -470,22 +645,26 @@ class HNASSSHBackend(object):
                 out, err = processutils.ssh_execute(ssh, commands,
                                                     check_exit_code=True)
                 LOG.debug("Command %(cmd)s result: out = %(out)s - err = "
-                          "%(err)s.", {'cmd': commands,
-                                       'out': out, 'err': err})
+                          "%(err)s.", {
+                              'cmd': commands,
+                              'out': out,
+                              'err': err,
+                          })
                 return out, err
             except processutils.ProcessExecutionError as e:
                 if 'Failed to establish SSC connection' in e.stderr:
-                    LOG.debug("SSC connection error!")
                     msg = _("Failed to establish SSC connection.")
+                    LOG.debug(msg)
                     raise exception.HNASConnException(msg=msg)
                 else:
-                    LOG.debug("Command %(cmd)s result: out = %(out)s - err = "
-                              "%(err)s - exit = %(exit)s.", {'cmd': e.cmd,
-                                                             'out': e.stdout,
-                                                             'err': e.stderr,
-                                                             'exit':
-                                                             e.exit_code})
-                    LOG.error(_LE("Error running SSH command."))
+                    LOG.debug("Error running SSH command. "
+                              "Command %(cmd)s result: out = %(out)s - err = "
+                              "%(err)s - exit = %(exit)s.", {
+                                  'cmd': e.cmd,
+                                  'out': e.stdout,
+                                  'err': e.stderr,
+                                  'exit': e.exit_code,
+                              })
                     raise
 
     @mutils.synchronized("hitachi_hnas_select_fs", external=True)
@@ -494,7 +673,18 @@ class HNASSSHBackend(object):
             command = ['selectfs', self.fs_name, '\n',
                        'ssc', '127.0.0.1', 'console-context', '--evs',
                        self.evs_id, 'mkdir', '-p', path]
-            self._execute(command)
+            try:
+                self._execute(command)
+            except processutils.ProcessExecutionError as e:
+                if "Current file system invalid: VolumeNotFound" in e.stderr:
+                    msg = _("Command to create directory %s failed due to "
+                            "context change.") % path
+                    LOG.debug(msg)
+                    raise exception.HNASSSCContextChange(msg=msg)
+                else:
+                    msg = _("Failed to create directory %s.") % path
+                    LOG.exception(msg)
+                    raise exception.HNASBackendException(msg=msg)
 
         if op == 'delete':
             command = ['selectfs', self.fs_name, '\n',
@@ -504,15 +694,21 @@ class HNASSSHBackend(object):
                 self._execute(command)
             except processutils.ProcessExecutionError as e:
                 if 'DirectoryNotEmpty' in e.stderr:
-                    LOG.debug("Share %(path)s has more snapshots.",
-                              {'path': path})
-                elif 'NotFound' in e.stderr:
-                    LOG.warning(_LW("Attempted to delete path %s but it does "
-                                    "not exist."), path)
+                    msg = _("Share %s has more snapshots.") % path
+                    LOG.debug(msg)
+                    raise exception.HNASDirectoryNotEmpty(msg=msg)
+                elif 'cannot remove' in e.stderr and 'NotFound' in e.stderr:
+                    LOG.warning("Attempted to delete path %s but it does "
+                                "not exist.", path)
+                elif 'Current file system invalid: VolumeNotFound' in e.stderr:
+                    msg = _("Command to delete empty directory %s failed due "
+                            "to context change.") % path
+                    LOG.debug(msg)
+                    raise exception.HNASSSCContextChange(msg=msg)
                 else:
-                    msg = six.text_type(e)
+                    msg = _("Failed to delete directory %s.") % path
                     LOG.exception(msg)
-                    raise
+                    raise exception.HNASBackendException(msg=msg)
 
 
 class Export(object):
