@@ -26,7 +26,6 @@ from oslo_serialization import jsonutils
 from oslo_utils import excutils
 from oslo_utils import strutils
 from oslo_utils import units
-import six
 
 from manila.common import constants as common_constants
 from manila.data import utils as data_utils
@@ -325,6 +324,8 @@ class V3StorageConnection(driver.HuaweiBase):
                     allocated_capacity_gb=capacity['CONSUMEDCAPACITY'],
                     qos=self._get_qos_capability(),
                     reserved_percentage=0,
+                    reserved_snapshot_percentage=0,
+                    reserved_share_extend_percentage=0,
                     thin_provisioning=[True, False],
                     dedupe=[True, False],
                     compression=[True, False],
@@ -383,7 +384,7 @@ class V3StorageConnection(driver.HuaweiBase):
         return share
 
     def create_share_from_snapshot(self, share, snapshot,
-                                   share_server=None):
+                                   share_server=None, parent_share=None):
         """Create a share from snapshot."""
         share_fs_id = self.helper.get_fsid_by_name(snapshot['share_name'])
         if not share_fs_id:
@@ -585,7 +586,7 @@ class V3StorageConnection(driver.HuaweiBase):
             message = (_("Failed to unmount share %(share)s. "
                          "Reason: %(reason)s.")
                        % {'share': share['name'],
-                          'reason': six.text_type(err)})
+                          'reason': str(err)})
             raise exception.ShareUmountException(reason=message)
 
     def mount_share_to_host(self, share, access):
@@ -610,7 +611,7 @@ class V3StorageConnection(driver.HuaweiBase):
             message = (_('Bad response from mount share: %(share)s. '
                          'Reason: %(reason)s.')
                        % {'share': share['name'],
-                          'reason': six.text_type(err)})
+                          'reason': str(err)})
             raise exception.ShareMountException(reason=message)
 
     def get_network_allocations_number(self):
@@ -1409,10 +1410,10 @@ class V3StorageConnection(driver.HuaweiBase):
         interval = wait_interval
         backoff_rate = 1
 
-        @utils.retry(exception.InvalidShare,
-                     interval,
-                     retries,
-                     backoff_rate)
+        @utils.retry(retry_param=exception.InvalidShare,
+                     interval=interval,
+                     retries=retries,
+                     backoff_rate=backoff_rate)
         def _check_AD_status():
             ad = self.helper.get_AD_config()
             if ad['DOMAINSTATUS'] != expected_status:
