@@ -21,6 +21,7 @@ place to ensure re usability and better management of configuration options.
 """
 
 from oslo_config import cfg
+from oslo_config import types
 
 netapp_proxy_opts = [
     cfg.StrOpt('netapp_storage_family',
@@ -31,7 +32,6 @@ netapp_proxy_opts = [
 
 netapp_connection_opts = [
     cfg.HostAddressOpt('netapp_server_hostname',
-                       deprecated_name='netapp_nas_server_hostname',
                        help='The hostname (or IP address) for the storage '
                             'system.'),
     cfg.PortOpt('netapp_server_port',
@@ -41,19 +41,24 @@ netapp_connection_opts = [
 
 netapp_transport_opts = [
     cfg.StrOpt('netapp_transport_type',
-               deprecated_name='netapp_nas_transport_type',
                default='http',
                help=('The transport protocol used when communicating with '
                      'the storage system or proxy server. Valid values are '
-                     'http or https.')), ]
+                     'http or https.')),
+    cfg.StrOpt('netapp_ssl_cert_path',
+               help=("The path to a CA_BUNDLE file or directory with "
+                     "certificates of trusted CA. If set to a directory, it "
+                     "must have been processed using the c_rehash utility "
+                     "supplied with OpenSSL. If not informed, it will use the "
+                     "Mozilla's carefully curated collection of Root "
+                     "Certificates for validating the trustworthiness of SSL "
+                     "certificates.")), ]
 
 netapp_basicauth_opts = [
     cfg.StrOpt('netapp_login',
-               deprecated_name='netapp_nas_login',
                help=('Administrative user account name used to access the '
                      'storage system.')),
     cfg.StrOpt('netapp_password',
-               deprecated_name='netapp_nas_password',
                help=('Password for the administrative user account '
                      'specified in the netapp_login option.'),
                secret=True), ]
@@ -66,7 +71,6 @@ netapp_provisioning_opts = [
                      'option only applies when the option '
                      'driver_handles_share_servers is set to True. '),
     cfg.StrOpt('netapp_volume_name_template',
-               deprecated_name='netapp_nas_volume_name_template',
                help='NetApp volume name template.',
                default='share_%(share_id)s'),
     cfg.StrOpt('netapp_vserver_name_template',
@@ -93,7 +97,6 @@ netapp_provisioning_opts = [
                     'This option only applies when the option '
                     'driver_handles_share_servers is set to True.'),
     cfg.StrOpt('netapp_root_volume',
-               deprecated_name='netapp_root_volume_name',
                default='root',
                help='Root volume name.'),
     cfg.IntOpt('netapp_volume_snapshot_reserve_percent',
@@ -115,7 +118,65 @@ netapp_provisioning_opts = [
     cfg.StrOpt('netapp_snapmirror_policy_name_svm_template',
                help='NetApp SnapMirror policy name template for Storage '
                     'Virtual Machines (Vservers).',
-               default='snapmirror_policy_%(share_server_id)s'), ]
+               default='snapmirror_policy_%(share_server_id)s'),
+    cfg.ListOpt('netapp_fpolicy_default_file_operations',
+                help='NetApp FPolicy file operations to apply to a FPolicy '
+                     'event, when not provided by the user using '
+                     '"netapp:fpolicy_file_operations" extra-spec.',
+                default=['create', 'write', 'rename']),
+    cfg.StrOpt('netapp_fpolicy_policy_name_template',
+               help='NetApp FPolicy policy name template.',
+               default='fpolicy_policy_%(share_id)s'),
+    cfg.StrOpt('netapp_fpolicy_event_name_template',
+               help='NetApp FPolicy policy name template.',
+               default='fpolicy_event_%(protocol)s_%(share_id)s'),
+    cfg.IntOpt('netapp_cached_aggregates_status_lifetime',
+               min=0,
+               default=60,
+               help='The maximum time in seconds that the cached aggregates '
+                    'status will be considered valid. Trying to read the '
+                    'expired cache leads to refreshing it.'),
+    cfg.BoolOpt('netapp_enable_flexgroup',
+                default=False,
+                help='Specify if the FlexGroup pool is enabled. When it is '
+                     'enabled, the driver will report a single pool '
+                     'representing all aggregates (ONTAP chooses on which the '
+                     'share will be allocated). If you want to Manila control '
+                     'the aggregate selection, you can configure its custom '
+                     'FlexGroup pools through netapp_flexgroup_pools option. '
+                     'The FlexGroup placement is done either by ONTAP or '
+                     'Manila, not both.'),
+    cfg.MultiOpt('netapp_flexgroup_pools',
+                 item_type=types.Dict(value_type=types.String()),
+                 default={},
+                 help="Multi opt of dict to represent the FlexGroup pools. "
+                      "A FlexGroup pool is configured with its name and its "
+                      "list of aggregates. Specify this option as many times "
+                      "as you have FlexGroup pools. Each entry takes the "
+                      "dict config form: "
+                      "netapp_flexgroup_pools = "
+                      "<pool_name>: <aggr_name1> <aggr_name2> .."),
+    cfg.BoolOpt('netapp_flexgroup_pool_only',
+                default=False,
+                help='Specify if the FlexVol pools must not be reported when '
+                     'the netapp_enable_flexgroup is enabled.'),
+    cfg.IntOpt('netapp_flexgroup_volume_online_timeout',
+               min=60,
+               default=360,  # Default to six minutes
+               help='Sets time in seconds to wait for a FlexGroup volume '
+                    'create to complete and go online.'),
+    cfg.IntOpt('netapp_flexgroup_aggregate_not_busy_timeout',
+               min=60,
+               default=360,  # Default to six minutes
+               help='Provisioning FlexGroup share requires that all of its '
+                    'aggregates to not be busy deploying another volume. So, '
+                    'sets time in seconds to retry to create the FlexGroup '
+                    'share.'),
+    cfg.IntOpt('netapp_delete_busy_flexgroup_snapshot_timeout',
+               min=60,
+               default=360,  # Default to six minutes
+               help='Sets time in seconds to wait for a FlexGroup snapshot '
+                    'to not be busy with clones after splitting them.'), ]
 
 netapp_cluster_opts = [
     cfg.StrOpt('netapp_vserver',
@@ -154,6 +215,12 @@ netapp_data_motion_opts = [
                default=3600,  # One Hour
                help='The maximum time in seconds to wait for a snapmirror '
                     'release when breaking snapmirror relationships.'),
+    cfg.IntOpt('netapp_snapmirror_last_transfer_size_limit',
+               min=512,
+               default=1024,  # One MB
+               help='This option set the last transfer size limit (in KB) '
+                    'of snapmirror to decide whether replica is in sync or '
+                    'out of sync.'),
     cfg.IntOpt('netapp_volume_move_cutover_timeout',
                min=0,
                default=3600,  # One Hour,
@@ -191,6 +258,11 @@ netapp_data_motion_opts = [
                help='The maximum time in seconds that a share server '
                     'migration waits for a vserver to change its internal '
                     'states.'),
+    cfg.IntOpt('netapp_mount_replica_timeout',
+               min=0,
+               default=3600,  # One Hour
+               help='The maximum time in seconds to wait for mounting '
+                    'a replica.'),
 ]
 
 CONF = cfg.CONF
