@@ -74,9 +74,14 @@ class QnapShareDriver(driver.ShareDriver):
         1.0.5 - Fix bug #1773761, when user tries to manage share, the size
                 of managed share should not be changed.
         1.0.6 - Add support for QES fw 2.1.0.
+        1.0.7 - Add support for QES fw on TDS series NAS model.
+        1.0.8 - Fix bug, driver should not manage snapshot which does not
+                exist in NAS.
+                Fix bug, driver should create share from snapshot with
+                specified size.
     """
 
-    DRIVER_VERSION = '1.0.6'
+    DRIVER_VERSION = '1.0.8'
 
     def __init__(self, *args, **kwargs):
         """Initialize QnapShareDriver."""
@@ -131,10 +136,10 @@ class QnapShareDriver(driver.ShareDriver):
         model_type = matches.group(1)
 
         ts_model_types = (
-            "TS", "SS", "IS", "TVS", "TDS", "TBS"
+            "TS", "SS", "IS", "TVS", "TBS"
         )
         tes_model_types = (
-            "TES",
+            "TES", "TDS"
         )
         es_model_types = (
             "ES",
@@ -254,6 +259,12 @@ class QnapShareDriver(driver.ShareDriver):
         reserved_percentage = self.configuration.safe_get(
             'reserved_share_percentage')
 
+        reserved_snapshot_percentage = self.configuration.safe_get(
+            'reserved_share_from_snapshot_percentage') or reserved_percentage
+
+        reserved_shr_extend_percentage = self.configuration.safe_get(
+            'reserved_share_extend_percentage') or reserved_percentage
+
         # single pool now, need support multiple pools in the future
         single_pool = {
             "pool_name": self.configuration.qnap_poolname,
@@ -261,6 +272,8 @@ class QnapShareDriver(driver.ShareDriver):
             "free_capacity_gb": free_capacity_gb,
             "allocated_capacity_gb": alloc_capacity_gb,
             "reserved_percentage": reserved_percentage,
+            "reserved_snapshot_percentage": reserved_snapshot_percentage,
+            "reserved_share_extend_percentage": reserved_shr_extend_percentage,
             "qos": False,
             "dedupe": [True, False],
             "compression": [True, False],
@@ -281,7 +294,7 @@ class QnapShareDriver(driver.ShareDriver):
         }
         super(QnapShareDriver, self)._update_share_stats(data)
 
-    @utils.retry(exception=exception.ShareBackendException,
+    @utils.retry(retry_param=exception.ShareBackendException,
                  interval=3,
                  retries=5)
     @utils.synchronized('qnap-create_share')
@@ -360,7 +373,7 @@ class QnapShareDriver(driver.ShareDriver):
                                        self.configuration.qnap_share_ip,
                                        volID)
 
-    @utils.retry(exception=exception.ShareBackendException,
+    @utils.retry(retry_param=exception.ShareBackendException,
                  interval=5, retries=5, backoff_rate=1)
     def _get_share_info(self, share_name):
         share = self.api_executor.get_share_info(
@@ -436,7 +449,7 @@ class QnapShareDriver(driver.ShareDriver):
         }
         self.api_executor.edit_share(share_dict)
 
-    @utils.retry(exception=exception.ShareBackendException,
+    @utils.retry(retry_param=exception.ShareBackendException,
                  interval=3,
                  retries=5)
     @utils.synchronized('qnap-create_snapshot')
@@ -509,12 +522,12 @@ class QnapShareDriver(driver.ShareDriver):
         self.api_executor.delete_snapshot_api(snapshot_id)
         self.private_storage.delete(snapshot['id'])
 
-    @utils.retry(exception=exception.ShareBackendException,
+    @utils.retry(retry_param=exception.ShareBackendException,
                  interval=3,
                  retries=5)
     @utils.synchronized('qnap-create_share_from_snapshot')
     def create_share_from_snapshot(self, context, share, snapshot,
-                                   share_server=None):
+                                   share_server=None, parent_share=None):
         """Create a share from a snapshot."""
         LOG.debug('Entering create_share_from_snapshot. The source '
                   'snapshot=%(snap)s. The created share=%(share)s',
@@ -537,7 +550,8 @@ class QnapShareDriver(driver.ShareDriver):
             msg = _("Failed to create an unused share name.")
             raise exception.ShareBackendException(msg=msg)
 
-        self.api_executor.clone_snapshot(snapshot_id, create_share_name)
+        self.api_executor.clone_snapshot(snapshot_id,
+                                         create_share_name, share['size'])
 
         create_volID = ""
         created_share = self.api_executor.get_share_info(
@@ -550,10 +564,6 @@ class QnapShareDriver(driver.ShareDriver):
             msg = _("Failed to clone a snapshot in time.")
             raise exception.ShareBackendException(msg=msg)
 
-        snap_share = self.share_api.get(
-            context, snapshot['share_instance']['share_id'])
-        LOG.debug('snap_share[size]: %s', snap_share['size'])
-
         thin_provision = self.private_storage.get(
             snapshot['share_instance_id'], 'thin_provision')
         compression = self.private_storage.get(
@@ -571,19 +581,6 @@ class QnapShareDriver(driver.ShareDriver):
                    'deduplication': deduplication,
                    'ssd_cache': ssd_cache})
 
-        if (share['size'] > snap_share['size']):
-            share_dict = {
-                'sharename': create_share_name,
-                'old_sharename': create_share_name,
-                'new_size': share['size'],
-                'thin_provision': thin_provision == 'True',
-                'compression': compression == 'True',
-                'deduplication': deduplication == 'True',
-                'ssd_cache': ssd_cache == 'True',
-                'share_proto': share['share_proto']
-            }
-            self.api_executor.edit_share(share_dict)
-
         # Use private_storage to record volume ID and Name created in the NAS.
         _metadata = {
             'volID': create_volID,
@@ -668,8 +665,8 @@ class QnapShareDriver(driver.ShareDriver):
         access_level = access['access_level']
         access_to = access['access_to']
         LOG.debug('share_proto: %(share_proto)s '
-                  'access_type: %(access_type)s'
-                  'access_level: %(access_level)s'
+                  'access_type: %(access_type)s '
+                  'access_level: %(access_level)s '
                   'access_to: %(access_to)s',
                   {'share_proto': share_proto,
                    'access_type': access_type,
@@ -725,8 +722,8 @@ class QnapShareDriver(driver.ShareDriver):
         access_level = access['access_level']
         access_to = access['access_to']
         LOG.debug('share_proto: %(share_proto)s '
-                  'access_type: %(access_type)s'
-                  'access_level: %(access_level)s'
+                  'access_type: %(access_type)s '
+                  'access_level: %(access_level)s '
                   'access_to: %(access_to)s',
                   {'share_proto': share_proto,
                    'access_type': access_type,
@@ -782,7 +779,7 @@ class QnapShareDriver(driver.ShareDriver):
         """Manages a share that exists on backend."""
         if share['share_proto'].lower() == 'nfs':
             # 10.0.0.1:/share/example
-            LOG.info("Share %(shr_path)s will be managed with ID"
+            LOG.info("Share %(shr_path)s will be managed with ID "
                      "%(shr_id)s.",
                      {'shr_path': share['export_locations'][0]['path'],
                       'shr_id': share['id']})
@@ -892,18 +889,19 @@ class QnapShareDriver(driver.ShareDriver):
         if existing_share is None:
             msg = _("The share id %s was not found on backend.") % volID
             LOG.error(msg)
-            raise exception.ShareNotFound(reason=msg)
+            raise exception.ShareNotFound(msg)
 
         snapshot_id = snapshot.get('provider_location')
         snapshot_id_info = snapshot_id.split('@')
 
         if len(snapshot_id_info) == 2:
             share_name = snapshot_id_info[0]
+            snapshot_name = snapshot_id_info[1]
         else:
             msg = _("Incorrect provider_location format. It should have the "
                     "following format: share_name@snapshot_name.")
             LOG.error(msg)
-            raise exception.InvalidParameterValue(reason=msg)
+            raise exception.InvalidParameterValue(msg)
 
         if share_name != existing_share.find('vol_label').text:
             msg = (_("The assigned share %(share_name)s was not matched "
@@ -911,12 +909,26 @@ class QnapShareDriver(driver.ShareDriver):
                    {'share_name': share_name,
                     'vol_label': existing_share.find('vol_label').text})
             LOG.error(msg)
-            raise exception.ShareNotFound(reason=msg)
+            raise exception.ShareNotFound(msg)
+
+        check_snapshot = self.api_executor.get_snapshot_info(
+            volID=volID, snapshot_name=snapshot_name)
+        if check_snapshot is None:
+            msg = (_("The snapshot %(snapshot_name)s was not "
+                     "found on backend.") %
+                   {'snapshot_name': snapshot_name})
+            LOG.error(msg)
+            raise exception.InvalidParameterValue(err=msg)
 
         _metadata = {
             'snapshot_id': snapshot_id,
         }
         self.private_storage.update(snapshot['id'], _metadata)
+        parent_size = check_snapshot.find('parent_size')
+        snap_size_gb = None
+        if parent_size is not None:
+            snap_size_gb = math.ceil(float(parent_size.text) / units.Gi)
+        return {'size': snap_size_gb}
 
     def unmanage_snapshot(self, snapshot):
         """Remove the specified snapshot from Manila management."""
