@@ -26,13 +26,13 @@ from oslo_config import cfg
 from oslo_log import log
 from oslo_utils import importutils
 from oslo_utils import netutils
-import six
 
 from manila.common import constants as const
 from manila import compute
 from manila import context
 from manila import exception
 from manila.i18n import _
+from manila import image
 from manila.network.linux import ip_lib
 from manila.network.neutron import api as neutron
 from manila import utils
@@ -48,7 +48,7 @@ share_servers_handling_mode_opts = [
              "creation. Only used if driver_handles_share_servers=True."),
     cfg.StrOpt(
         "service_instance_name_template",
-        default="manila_service_instance_%s",
+        default="%s",
         help="Name of service instance. "
              "Only used if driver_handles_share_servers=True."),
     cfg.StrOpt(
@@ -67,9 +67,9 @@ share_servers_handling_mode_opts = [
         help="Security group name, that will be used for "
              "service instance creation. "
              "Only used if driver_handles_share_servers=True."),
-    cfg.IntOpt(
+    cfg.StrOpt(
         "service_instance_flavor_id",
-        default=100,
+        default="100",
         help="ID of flavor, that will be used for service instance "
              "creation. Only used if driver_handles_share_servers=True."),
     cfg.StrOpt(
@@ -93,8 +93,18 @@ share_servers_handling_mode_opts = [
     cfg.StrOpt(
         "interface_driver",
         default="manila.network.linux.interface.OVSInterfaceDriver",
-        help="Vif driver. Used only with Neutron and "
-             "if driver_handles_share_servers=True."),
+        help="Module path to the Virtual Interface (VIF) driver class. This "
+             "option is used only by drivers operating in "
+             "`driver_handles_share_servers=True` mode that provision "
+             "OpenStack compute instances as share servers. This option is "
+             "only supported with Neutron networking. "
+             "Drivers provided in tree work with Linux Bridge "
+             "(manila.network.linux.interface.BridgeInterfaceDriver) and OVS "
+             "(manila.network.linux.interface.OVSInterfaceDriver). If the "
+             "manila-share service is running on a host that is connected to "
+             "the administrator network, a no-op driver "
+             "(manila.network.linux.interface.NoopInterfaceDriver) may "
+             "be used."),
     cfg.BoolOpt(
         "connect_share_server_to_tenant_network",
         default=False,
@@ -212,6 +222,7 @@ class ServiceInstanceManager(object):
         self.admin_context = context.get_admin_context()
         self._execute = utils.execute
 
+        self.image_api = image.API()
         self.compute_api = compute.API()
 
         self.path_to_private_key = self.get_config_option(
@@ -219,6 +230,9 @@ class ServiceInstanceManager(object):
         self.max_time_to_build_instance = self.get_config_option(
             "max_time_to_build_instance")
 
+        self.availability_zone = self.get_config_option(
+            'backend_availability_zone') or CONF.storage_availability_zone
+
         if self.get_config_option("driver_handles_share_servers"):
             self.path_to_public_key = self.get_config_option(
                 "path_to_public_key")
@@ -291,7 +305,7 @@ class ServiceInstanceManager(object):
 
     def _get_service_instance_name(self, share_server_id):
         """Returns service vms name."""
-        if self.driver_config:
+        if self.driver_config and self.driver_config.config_group:
             # Make service instance name unique for multibackend installation
             name = "%s_%s" % (self.driver_config.config_group, share_server_id)
         else:
@@ -305,7 +319,7 @@ class ServiceInstanceManager(object):
             msg = _("Failed to get service instance IP address. "
                     "Service network name is '%(net_name)s' "
                     "and provided data are '%(data)s'.")
-            msg = msg % {'net_name': net_name, 'data': six.text_type(server)}
+            msg = msg % {'net_name': net_name, 'data': str(server)}
             raise exception.ServiceInstanceException(msg)
         return net_ips[0]
 
@@ -411,7 +425,11 @@ class ServiceInstanceManager(object):
         t = time.time()
         while time.time() - t < self.max_time_to_build_instance:
             try:
-                self.compute_api.server_get(context, server_id)
+                inst = self.compute_api.server_get(context, server_id)
+                if inst.get("status").lower() == "soft_deleted":
+                    LOG.debug("Service instance '%s' was soft-deleted "
+                              "successfully.", server_id)
+                    break
             except exception.InstanceNotFound:
                 LOG.debug("Service instance '%s' was deleted "
                           "successfully.", server_id)
@@ -431,7 +449,8 @@ class ServiceInstanceManager(object):
         :returns: dict with service instance details
         :raises: exception.ServiceInstanceException
         """
-        instance_name = network_info['server_id']
+        instance_name = self._get_service_instance_name(
+            network_info['server_id'])
         server = self._create_service_instance(
             context, instance_name, network_info)
         instance_details = self._get_new_instance_details(server)
@@ -512,19 +531,18 @@ class ServiceInstanceManager(object):
     def _get_service_image(self, context):
         """Returns ID of service image for service vm creating."""
         service_image_name = self.get_config_option("service_image_name")
-        images = [image.id for image in self.compute_api.image_list(context)
+        images = [image.id for image in self.image_api.image_list(context)
                   if image.name == service_image_name
                   and image.status == 'active']
-        if len(images) == 1:
-            return images[0]
-        elif not images:
+        if not images:
             raise exception.ServiceInstanceException(
                 _("Image with name '%s' was not found or is not in "
                   "'active' state.") % service_image_name)
-        else:
+        if len(images) != 1:
             raise exception.ServiceInstanceException(
-                _("Found more than one image by name '%s'.") %
+                _("Multiple 'active' state images found with name '%s'!") %
                 service_image_name)
+        return images[0]
 
     def _create_service_instance(self, context, instance_name, network_info):
         """Creates service vm and sets up networking for it."""
@@ -564,7 +582,7 @@ class ServiceInstanceManager(object):
                 flavor=self.get_config_option("service_instance_flavor_id"),
                 key_name=key_name,
                 nics=network_data['nics'],
-                availability_zone=CONF.storage_availability_zone,
+                availability_zone=self.availability_zone,
                 **create_kwargs)
 
             fail_safe_data['instance_id'] = service_instance['id']
@@ -706,10 +724,10 @@ class ServiceInstanceManager(object):
                                        soft_reboot)
 
 
-@six.add_metaclass(abc.ABCMeta)
-class BaseNetworkhelper(object):
+class BaseNetworkhelper(metaclass=abc.ABCMeta):
 
-    @abc.abstractproperty
+    @property
+    @abc.abstractmethod
     def NAME(self):
         """Returns code name of network helper."""
 
@@ -830,7 +848,8 @@ class NeutronNetworkHelper(BaseNetworkhelper):
 
         if router_id and subnet_id:
             ports = self.neutron_api.list_ports(
-                fields=['fixed_ips', 'device_id', 'device_owner'])
+                fields=['device_id', 'device_owner'],
+                fixed_ips=['subnet_id=%s' % subnet_id])
             # NOTE(vponomaryov): iterate ports to get to know whether current
             # subnet is used or not. We will not remove it from router if it
             # is used.
@@ -840,12 +859,10 @@ class NeutronNetworkHelper(BaseNetworkhelper):
                 # we know that it is VM. We continue only if both are 'True'.
                 if (port['device_id'] and
                         port['device_owner'].startswith('compute:')):
-                    for fixed_ip in port['fixed_ips']:
-                        if fixed_ip['subnet_id'] == subnet_id:
-                            # NOTE(vponomaryov): There are other share servers
-                            # exist that use this subnet. So, do not remove it
-                            # from router.
-                            return
+                    # NOTE(vponomaryov): There are other share servers
+                    # exist that use this subnet. So, do not remove it
+                    # from router.
+                    return
             try:
                 # NOTE(vponomaryov): there is no other share servers or
                 # some VMs that use this subnet. So, remove it from router.
@@ -876,7 +893,8 @@ class NeutronNetworkHelper(BaseNetworkhelper):
                 network_data['service_subnet'] = (
                     self.neutron_api.subnet_create(
                         self.admin_project_id, self.service_network_id,
-                        subnet_name, self._get_cidr_for_subnet()))
+                        subnet_name, self._get_cidr_for_subnet(),
+                        self.connect_share_server_to_tenant_network))
 
         network_data['ports'] = []
 
@@ -936,7 +954,7 @@ class NeutronNetworkHelper(BaseNetworkhelper):
             self.get_config_option("service_network_cidr"))
         division_mask = self.get_config_option("service_network_division_mask")
         for subnet in serv_cidr.subnet(division_mask):
-            cidr = six.text_type(subnet.cidr)
+            cidr = str(subnet.cidr)
             if cidr not in used_cidrs:
                 return cidr
         else:
@@ -949,6 +967,8 @@ class NeutronNetworkHelper(BaseNetworkhelper):
         and setting up required network devices.
         """
         if self.use_service_network:
+            LOG.debug("Plugging service instance into service network %s.",
+                      self.service_network_id)
             port = self._get_service_port(
                 self.service_network_id, None, 'manila-share')
             port = self._add_fixed_ips_to_service_port(port)
@@ -957,62 +977,37 @@ class NeutronNetworkHelper(BaseNetworkhelper):
             self._plug_interface_in_host(interface_name, device, port)
 
         if self.use_admin_port:
+            LOG.debug("Plugging service instance into admin network %s.",
+                      self.admin_network_id)
             port = self._get_service_port(
                 self.admin_network_id, self.admin_subnet_id,
                 'manila-admin-share')
             interface_name = self.vif_driver.get_device_name(port)
             device = ip_lib.IPDevice(interface_name)
-            for fixed_ip in port['fixed_ips']:
-                subnet = self.neutron_api.get_subnet(fixed_ip['subnet_id'])
-                device.route.clear_outdated_routes(subnet['cidr'])
-            self._plug_interface_in_host(interface_name, device, port)
+            self._plug_interface_in_host(interface_name, device, port,
+                                         clear_outdated_routes=True)
 
     @utils.synchronized("service_instance_plug_interface_in_host",
                         external=True)
-    def _plug_interface_in_host(self, interface_name, device, port):
+    def _plug_interface_in_host(self, interface_name, device, port,
+                                clear_outdated_routes=False):
 
+        LOG.debug("Plug interface into host - interface_name: %s, "
+                  "device: %s, port: %s", interface_name, device, port)
         self.vif_driver.plug(interface_name, port['id'], port['mac_address'])
+        cidrs_to_clear = []
         ip_cidrs = []
         for fixed_ip in port['fixed_ips']:
             subnet = self.neutron_api.get_subnet(fixed_ip['subnet_id'])
+            if clear_outdated_routes:
+                cidrs_to_clear.append(subnet['cidr'])
+
             net = netaddr.IPNetwork(subnet['cidr'])
             ip_cidr = '%s/%s' % (fixed_ip['ip_address'], net.prefixlen)
             ip_cidrs.append(ip_cidr)
 
-        self.vif_driver.init_l3(interface_name, ip_cidrs)
-
-        # ensure that interface is first in the list
-        device.route.pullup_route(interface_name)
-
-        # here we are checking for garbage devices from removed service port
-        self._remove_outdated_interfaces(device)
-
-    def _remove_outdated_interfaces(self, device):
-        """Finds and removes unused network device."""
-        device_cidr_set = self._get_set_of_device_cidrs(device)
-        for dev in ip_lib.IPWrapper().get_devices():
-            if dev.name != device.name and dev.name[:3] == device.name[:3]:
-                cidr_set = self._get_set_of_device_cidrs(dev)
-                if device_cidr_set & cidr_set:
-                    self.vif_driver.unplug(dev.name)
-
-    def _get_set_of_device_cidrs(self, device):
-        cidrs = set()
-        addr_list = []
-        try:
-            # NOTE(ganso): I could call ip_lib.device_exists here, but since
-            # this is a concurrency problem, it would not fix the problem.
-            addr_list = device.addr.list()
-        except Exception as e:
-            if 'does not exist' in six.text_type(e):
-                LOG.warning(
-                    "Device %s does not exist anymore.", device.name)
-            else:
-                raise
-        for addr in addr_list:
-            if addr['ip_version'] == 4:
-                cidrs.add(six.text_type(netaddr.IPNetwork(addr['cidr']).cidr))
-        return cidrs
+        self.vif_driver.init_l3(interface_name, ip_cidrs,
+                                clear_cidrs=cidrs_to_clear)
 
     @utils.synchronized("service_instance_get_service_port", external=True)
     def _get_service_port(self, network_id, subnet_id, device_id):
