@@ -17,11 +17,10 @@
 Tests dealing with HTTP rate-limiting.
 """
 import ddt
+import http.client as http_client
+import io
 
 from oslo_serialization import jsonutils
-import six
-from six import moves
-from six.moves import http_client
 import webob
 
 from manila.api.openstack import api_version_request as api_version
@@ -39,7 +38,8 @@ TEST_LIMITS = [
     limits.Limit("PUT", "*", "", 10, limits.PER_MINUTE),
     limits.Limit("PUT", "/shares", "^/shares", 5, limits.PER_MINUTE),
 ]
-SHARE_REPLICAS_LIMIT_MICROVERSION = "2.53"
+SHARE_REPLICAS_LIMIT_MICROVERSION = "2.58"
+SHARE_GROUP_QUOTA_MICROVERSION = "2.40"
 
 
 class BaseLimitTestSuite(test.TestCase):
@@ -130,6 +130,12 @@ class LimitsControllerTest(BaseLimitTestSuite):
             },
         }
 
+        if microversion == SHARE_GROUP_QUOTA_MICROVERSION:
+            self.absolute_limits['limit']['share_groups'] = 20
+            self.absolute_limits['limit']['share_group_snapshots'] = 20
+            self.absolute_limits['in_use']['share_groups'] = 3
+            self.absolute_limits['in_use']['share_group_snapshots'] = 3
+
         if microversion == SHARE_REPLICAS_LIMIT_MICROVERSION:
             self.absolute_limits['limit']['share_replicas'] = 20
             self.absolute_limits['limit']['replica_gigabytes'] = 20
@@ -190,6 +196,12 @@ class LimitsControllerTest(BaseLimitTestSuite):
                 },
             },
         }
+        if microversion == SHARE_GROUP_QUOTA_MICROVERSION:
+            expected['limits']['absolute']["maxTotalShareGroups"] = 20
+            expected['limits']['absolute']["totalShareGroupsUsed"] = 3
+            expected['limits']['absolute']["maxTotalShareGroupSnapshots"] = 20
+            expected['limits']['absolute']["totalShareGroupSnapshots"] = 3
+
         if microversion == SHARE_REPLICAS_LIMIT_MICROVERSION:
             expected['limits']['absolute']["maxTotalShareReplicas"] = 20
             expected['limits']['absolute']["totalShareReplicasUsed"] = 3
@@ -382,7 +394,7 @@ class ParseLimitsTest(BaseLimitTestSuite):
                 '(POST, /bar*, /bar.*, 5, second);'
                 '(Say, /derp*, /derp.*, 1, day)')
         except ValueError as e:
-            assert False, six.text_type(e)
+            assert False, str(e)
 
         # Make sure the number of returned limits are correct
         self.assertEqual(4, len(lim))
@@ -420,7 +432,7 @@ class LimiterTest(BaseLimitTestSuite):
 
     def _check(self, num, verb, url, username=None):
         """Check and yield results from checks."""
-        for x in moves.range(num):
+        for x in range(num):
             yield self.limiter.check_for_delay(verb, url, username)[0]
 
     def _check_sum(self, num, verb, url, username=None):
@@ -569,7 +581,7 @@ class WsgiLimiterTest(BaseLimitTestSuite):
 
     def _request_data(self, verb, path):
         """Get data describing a limit request verb/path."""
-        return six.b(jsonutils.dumps({"verb": verb, "path": path}))
+        return jsonutils.dumps({"verb": verb, "path": path}).encode("utf-8")
 
     def _request(self, verb, url, username=None):
         """Send request.
@@ -635,7 +647,7 @@ class FakeHttplibSocket(object):
 
     def __init__(self, response_string):
         """Initialize new `FakeHttplibSocket`."""
-        self._buffer = six.BytesIO(six.b(response_string))
+        self._buffer = io.BytesIO(response_string.encode("utf-8"))
 
     def makefile(self, _mode, _other=None):
         """Returns the socket's internal buffer."""
@@ -664,7 +676,7 @@ class FakeHttplibConnection(object):
         req.method = method
         req.headers = headers
         req.host = self.host
-        req.body = six.b(body)
+        req.body = body.encode("utf-8")
 
         resp = str(req.get_response(self.app))
         resp = "HTTP/1.0 %s" % resp
@@ -748,8 +760,9 @@ class WsgiLimiterProxyTest(BaseLimitTestSuite):
         delay, error = self.proxy.check_for_delay("GET", "/delayed")
         error = error.strip()
 
-        expected = ("60.00", six.b("403 Forbidden\n\nOnly 1 GET request(s) "
-                                   "can be made to /delayed every minute."))
+        expected = ("60.00", (
+            "403 Forbidden\n\nOnly 1 GET request(s) can be made to /delayed "
+            "every minute.").encode("utf-8"))
 
         self.assertEqual(expected, (delay, error))
 
@@ -833,7 +846,7 @@ class LimitsViewBuilderTest(test.TestCase):
         output = self.view_builder.build(request,
                                          self.rate_limits,
                                          self.absolute_limits)
-        self.assertDictMatch(expected_limits, output)
+        self.assertDictEqual(expected_limits, output)
 
     def test_build_limits_empty_limits(self):
         request = fakes.HTTPRequest.blank('/')
@@ -843,4 +856,4 @@ class LimitsViewBuilderTest(test.TestCase):
 
         output = self.view_builder.build(request, rate_limits, abs_limits)
 
-        self.assertDictMatch(expected_limits, output)
+        self.assertDictEqual(expected_limits, output)
