@@ -175,8 +175,10 @@ def fake_snapshot_instance(base_snapshot=None, as_primitive=False, **kwargs):
 
 
 def expected_snapshot(version=None, id='fake_snapshot_id', **kwargs):
-    self_link = 'http://localhost/v1/fake/snapshots/%s' % id
-    bookmark_link = 'http://localhost/fake/snapshots/%s' % id
+    api_major_version = 'v2' if version and version.startswith('2.') else 'v1'
+    self_link = 'http://localhost/share/%s/fake/snapshots/%s' % (
+        api_major_version, id)
+    bookmark_link = 'http://localhost/share/fake/snapshots/%s' % id
     snapshot = {
         'id': id,
         'share_id': 'fakeshareid',
@@ -205,7 +207,11 @@ def expected_snapshot(version=None, id='fake_snapshot_id', **kwargs):
             'user_id': 'fakesnapuser',
             'project_id': 'fakesnapproject',
         })
-
+    if version and (api_version.APIVersionRequest(version)
+                    >= api_version.APIVersionRequest('2.73')):
+        snapshot.update({
+            'metadata': {}
+        })
     snapshot.update(kwargs)
     return {'snapshot': snapshot}
 
@@ -303,7 +309,6 @@ def fake_share_server_get():
         'status': constants.STATUS_ACTIVE,
         'updated_at': None,
         'host': 'fake_host',
-        'share_network_subnet_id': 'fake_sn_id',
         'share_network_name': 'fake_sn_name',
         'project_id': 'fake_project_id',
         'id': 'fake_share_server_id',
