@@ -14,7 +14,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
+from unittest import mock
+
 from neutronclient.common import exceptions as neutron_client_exc
 from neutronclient.v2_0 import client as clientv20
 from oslo_config import cfg
@@ -89,6 +90,7 @@ class NeutronclientTestCase(test.TestCase):
         fake_context = 'fake_context'
         data = {
             'neutron': {
+                'url': 'http://localhost:9696',
                 'endpoint_type': 'foo_endpoint_type',
                 'region_name': 'foo_region_name',
             }
@@ -101,7 +103,6 @@ class NeutronclientTestCase(test.TestCase):
 
         mock_client_loader.assert_called_once_with(
             client_class=neutron_api.clientv20.Client,
-            exception_module=neutron_api.neutron_client_exc,
             cfg_group=neutron_api.NEUTRON_GROUP
         )
         mock_client_loader.return_value.get_client.assert_called_once_with(
@@ -109,12 +110,14 @@ class NeutronclientTestCase(test.TestCase):
             fake_context,
             endpoint_type=data['neutron']['endpoint_type'],
             region_name=data['neutron']['region_name'],
+            endpoint_override=data['neutron']['url'],
         )
 
     def test_with_auth_obj(self):
         fake_context = 'fake_context'
         data = {
             'neutron': {
+                'url': 'http://localhost:9696',
                 'endpoint_type': 'foo_endpoint_type',
                 'region_name': 'foo_region_name',
             }
@@ -132,6 +135,7 @@ class NeutronclientTestCase(test.TestCase):
             fake_context,
             endpoint_type=data['neutron']['endpoint_type'],
             region_name=data['neutron']['region_name'],
+            endpoint_override=data['neutron']['url'],
         )
 
 
