@@ -46,6 +46,8 @@ SERVICE_STATES_NO_POOLS = {
     'host1': dict(share_backend_name='AAA',
                   total_capacity_gb=512, free_capacity_gb=200,
                   timestamp=None, reserved_percentage=0,
+                  reserved_snapshot_percentage=0,
+                  reserved_share_extend_percentage=0,
                   provisioned_capacity_gb=312,
                   max_over_subscription_ratio=1.0,
                   thin_provisioning=False,
@@ -57,6 +59,8 @@ SERVICE_STATES_NO_POOLS = {
     'host2@back1': dict(share_backend_name='BBB',
                         total_capacity_gb=256, free_capacity_gb=100,
                         timestamp=None, reserved_percentage=0,
+                        reserved_snapshot_percentage=0,
+                        reserved_share_extend_percentage=0,
                         provisioned_capacity_gb=400,
                         max_over_subscription_ratio=2.0,
                         thin_provisioning=True,
@@ -68,6 +72,8 @@ SERVICE_STATES_NO_POOLS = {
     'host2@back2': dict(share_backend_name='CCC',
                         total_capacity_gb=10000, free_capacity_gb=700,
                         timestamp=None, reserved_percentage=0,
+                        reserved_snapshot_percentage=0,
+                        reserved_share_extend_percentage=0,
                         provisioned_capacity_gb=50000,
                         max_over_subscription_ratio=20.0,
                         thin_provisioning=True,
@@ -103,6 +109,8 @@ SHARE_SERVICES_WITH_POOLS = [
 SHARE_SERVICE_STATES_WITH_POOLS = {
     'host1@AAA': dict(share_backend_name='AAA',
                       timestamp=None, reserved_percentage=0,
+                      reserved_snapshot_percentage=0,
+                      reserved_share_extend_percentage=0,
                       driver_handles_share_servers=False,
                       snapshot_support=True,
                       create_share_from_snapshot_support=True,
@@ -112,11 +120,15 @@ SHARE_SERVICE_STATES_WITH_POOLS = {
                                   total_capacity_gb=51,
                                   free_capacity_gb=41,
                                   reserved_percentage=0,
+                                  reserved_snapshot_percentage=0,
+                                  reserved_share_extend_percentage=0,
                                   provisioned_capacity_gb=10,
                                   max_over_subscription_ratio=1.0,
                                   thin_provisioning=False)]),
     'host2@BBB': dict(share_backend_name='BBB',
                       timestamp=None, reserved_percentage=0,
+                      reserved_snapshot_percentage=0,
+                      reserved_share_extend_percentage=0,
                       driver_handles_share_servers=False,
                       snapshot_support=True,
                       create_share_from_snapshot_support=True,
@@ -126,11 +138,15 @@ SHARE_SERVICE_STATES_WITH_POOLS = {
                                   total_capacity_gb=52,
                                   free_capacity_gb=42,
                                   reserved_percentage=0,
+                                  reserved_snapshot_percentage=0,
+                                  reserved_share_extend_percentage=0,
                                   provisioned_capacity_gb=60,
                                   max_over_subscription_ratio=2.0,
                                   thin_provisioning=True)]),
     'host3@CCC': dict(share_backend_name='CCC',
                       timestamp=None, reserved_percentage=0,
+                      reserved_snapshot_percentage=0,
+                      reserved_share_extend_percentage=0,
                       driver_handles_share_servers=False,
                       snapshot_support=True,
                       create_share_from_snapshot_support=True,
@@ -140,11 +156,15 @@ SHARE_SERVICE_STATES_WITH_POOLS = {
                                   total_capacity_gb=53,
                                   free_capacity_gb=43,
                                   reserved_percentage=0,
+                                  reserved_snapshot_percentage=0,
+                                  reserved_share_extend_percentage=0,
                                   provisioned_capacity_gb=100,
                                   max_over_subscription_ratio=20.0,
                                   thin_provisioning=True)]),
     'host4@DDD': dict(share_backend_name='DDD',
                       timestamp=None, reserved_percentage=0,
+                      reserved_snapshot_percentage=0,
+                      reserved_share_extend_percentage=0,
                       driver_handles_share_servers=False,
                       snapshot_support=True,
                       create_share_from_snapshot_support=True,
@@ -154,6 +174,8 @@ SHARE_SERVICE_STATES_WITH_POOLS = {
                                   total_capacity_gb=541,
                                   free_capacity_gb=441,
                                   reserved_percentage=0,
+                                  reserved_snapshot_percentage=0,
+                                  reserved_share_extend_percentage=0,
                                   provisioned_capacity_gb=800,
                                   max_over_subscription_ratio=2.0,
                                   thin_provisioning=True),
@@ -161,11 +183,15 @@ SHARE_SERVICE_STATES_WITH_POOLS = {
                                   total_capacity_gb=542,
                                   free_capacity_gb=442,
                                   reserved_percentage=0,
+                                  reserved_snapshot_percentage=0,
+                                  reserved_share_extend_percentage=0,
                                   provisioned_capacity_gb=2000,
                                   max_over_subscription_ratio=10.0,
                                   thin_provisioning=True)]),
     'host5@EEE': dict(share_backend_name='EEE',
                       timestamp=None, reserved_percentage=0,
+                      reserved_snapshot_percentage=0,
+                      reserved_share_extend_percentage=0,
                       driver_handles_share_servers=False,
                       snapshot_support=True,
                       create_share_from_snapshot_support=True,
@@ -175,6 +201,8 @@ SHARE_SERVICE_STATES_WITH_POOLS = {
                                   total_capacity_gb=551,
                                   free_capacity_gb=451,
                                   reserved_percentage=0,
+                                  reserved_snapshot_percentage=0,
+                                  reserved_share_extend_percentage=0,
                                   provisioned_capacity_gb=100,
                                   max_over_subscription_ratio=1.0,
                                   thin_provisioning=False),
@@ -182,11 +210,15 @@ SHARE_SERVICE_STATES_WITH_POOLS = {
                                   total_capacity_gb=552,
                                   free_capacity_gb=452,
                                   reserved_percentage=0,
+                                  reserved_snapshot_percentage=0,
+                                  reserved_share_extend_percentage=0,
                                   provisioned_capacity_gb=100,
                                   max_over_subscription_ratio=1.0,
                                   thin_provisioning=False)]),
     'host6@FFF': dict(share_backend_name='FFF',
                       timestamp=None, reserved_percentage=0,
+                      reserved_snapshot_percentage=0,
+                      reserved_share_extend_percentage=0,
                       driver_handles_share_servers=False,
                       snapshot_support=True,
                       create_share_from_snapshot_support=True,
@@ -196,6 +228,8 @@ SHARE_SERVICE_STATES_WITH_POOLS = {
                                   total_capacity_gb='unknown',
                                   free_capacity_gb='unknown',
                                   reserved_percentage=0,
+                                  reserved_snapshot_percentage=0,
+                                  reserved_share_extend_percentage=0,
                                   provisioned_capacity_gb=100,
                                   max_over_subscription_ratio=1.0,
                                   thin_provisioning=False),
@@ -203,6 +237,8 @@ SHARE_SERVICE_STATES_WITH_POOLS = {
                                   total_capacity_gb='unknown',
                                   free_capacity_gb='unknown',
                                   reserved_percentage=0,
+                                  reserved_snapshot_percentage=0,
+                                  reserved_share_extend_percentage=0,
                                   provisioned_capacity_gb=100,
                                   max_over_subscription_ratio=1.0,
                                   thin_provisioning=False)]),
@@ -225,11 +261,14 @@ class FakeHostManager(host_manager.HostManager):
                       'allocated_capacity_gb': 0,
                       'thin_provisioning': False,
                       'reserved_percentage': 10,
+                      'reserved_snapshot_percentage': 5,
+                      'reserved_share_extend_percentage': 15,
                       'timestamp': None,
                       'snapshot_support': True,
                       'create_share_from_snapshot_support': True,
                       'replication_type': 'writable',
                       'replication_domain': 'endor',
+                      'storage_protocol': 'NFS_CIFS',
                       },
             'host2': {'total_capacity_gb': 2048,
                       'free_capacity_gb': 300,
@@ -238,11 +277,14 @@ class FakeHostManager(host_manager.HostManager):
                       'max_over_subscription_ratio': 2.0,
                       'thin_provisioning': True,
                       'reserved_percentage': 10,
+                      'reserved_snapshot_percentage': 5,
+                      'reserved_share_extend_percentage': 15,
                       'timestamp': None,
                       'snapshot_support': True,
                       'create_share_from_snapshot_support': True,
                       'replication_type': 'readable',
                       'replication_domain': 'kashyyyk',
+                      'storage_protocol': 'NFS_CIFS',
                       },
             'host3': {'total_capacity_gb': 512,
                       'free_capacity_gb': 256,
@@ -251,9 +293,12 @@ class FakeHostManager(host_manager.HostManager):
                       'max_over_subscription_ratio': 2.0,
                       'thin_provisioning': [False],
                       'reserved_percentage': 0,
+                      'reserved_snapshot_percentage': 0,
+                      'reserved_share_extend_percentage': 0,
                       'snapshot_support': True,
                       'create_share_from_snapshot_support': True,
                       'timestamp': None,
+                      'storage_protocol': 'NFS_CIFS',
                       },
             'host4': {'total_capacity_gb': 2048,
                       'free_capacity_gb': 200,
@@ -262,11 +307,14 @@ class FakeHostManager(host_manager.HostManager):
                       'max_over_subscription_ratio': 1.0,
                       'thin_provisioning': [True],
                       'reserved_percentage': 5,
+                      'reserved_snapshot_percentage': 2,
+                      'reserved_share_extend_percentage': 5,
                       'timestamp': None,
                       'snapshot_support': True,
                       'create_share_from_snapshot_support': True,
                       'replication_type': 'dr',
                       'replication_domain': 'naboo',
+                      'storage_protocol': 'NFS_CIFS',
                       },
             'host5': {'total_capacity_gb': 2048,
                       'free_capacity_gb': 500,
@@ -275,19 +323,25 @@ class FakeHostManager(host_manager.HostManager):
                       'max_over_subscription_ratio': 1.5,
                       'thin_provisioning': [True, False],
                       'reserved_percentage': 5,
+                      'reserved_snapshot_percentage': 2,
+                      'reserved_share_extend_percentage': 5,
                       'timestamp': None,
                       'snapshot_support': True,
                       'create_share_from_snapshot_support': True,
                       'replication_type': None,
+                      'storage_protocol': 'NFS_CIFS',
                       },
             'host6': {'total_capacity_gb': 'unknown',
                       'free_capacity_gb': 'unknown',
                       'allocated_capacity_gb': 1548,
                       'thin_provisioning': False,
                       'reserved_percentage': 5,
+                      'reserved_snapshot_percentage': 2,
+                      'reserved_share_extend_percentage': 5,
                       'snapshot_support': True,
                       'create_share_from_snapshot_support': True,
                       'timestamp': None,
+                      'storage_protocol': 'GLUSTERFS',
                       },
         }
 
