@@ -107,7 +107,7 @@ class HostManagerTestCase(test.TestCase):
 
     def test_update_service_capabilities_for_shares(self):
         service_states = self.host_manager.service_states
-        self.assertDictMatch(service_states, {})
+        self.assertDictEqual(service_states, {})
         host1_share_capabs = dict(free_capacity_gb=4321, timestamp=1)
         host2_share_capabs = dict(free_capacity_gb=5432, timestamp=1)
         host3_share_capabs = dict(free_capacity_gb=6543, timestamp=1)
@@ -135,7 +135,7 @@ class HostManagerTestCase(test.TestCase):
             'host2': host2_share_capabs,
             'host3': host3_share_capabs,
         }
-        self.assertDictMatch(service_states, expected)
+        self.assertDictEqual(service_states, expected)
 
     def test_get_all_host_states_share(self):
         fake_context = context.RequestContext('user', 'project')
@@ -197,6 +197,8 @@ class HostManagerTestCase(test.TestCase):
                         'driver_version': None,
                         'total_capacity_gb': 512,
                         'reserved_percentage': 0,
+                        'reserved_snapshot_percentage': 0,
+                        'reserved_share_extend_percentage': 0,
                         'provisioned_capacity_gb': 312,
                         'max_over_subscription_ratio': 1.0,
                         'thin_provisioning': False,
@@ -213,6 +215,8 @@ class HostManagerTestCase(test.TestCase):
                         'replication_domain': None,
                         'sg_consistent_snapshot_support': None,
                         'security_service_update_support': False,
+                        'network_allocation_update_support': False,
+                        'share_server_multiple_subnet_support': False,
                     },
                 }, {
                     'name': 'host2@back1#BBB',
@@ -226,6 +230,8 @@ class HostManagerTestCase(test.TestCase):
                         'driver_version': None,
                         'total_capacity_gb': 256,
                         'reserved_percentage': 0,
+                        'reserved_snapshot_percentage': 0,
+                        'reserved_share_extend_percentage': 0,
                         'provisioned_capacity_gb': 400,
                         'max_over_subscription_ratio': 2.0,
                         'thin_provisioning': True,
@@ -242,6 +248,8 @@ class HostManagerTestCase(test.TestCase):
                         'replication_domain': None,
                         'sg_consistent_snapshot_support': None,
                         'security_service_update_support': False,
+                        'network_allocation_update_support': False,
+                        'share_server_multiple_subnet_support': False,
                     },
                 }, {
                     'name': 'host2@back2#CCC',
@@ -255,6 +263,8 @@ class HostManagerTestCase(test.TestCase):
                         'driver_version': None,
                         'total_capacity_gb': 10000,
                         'reserved_percentage': 0,
+                        'reserved_snapshot_percentage': 0,
+                        'reserved_share_extend_percentage': 0,
                         'provisioned_capacity_gb': 50000,
                         'max_over_subscription_ratio': 20.0,
                         'thin_provisioning': True,
@@ -271,6 +281,8 @@ class HostManagerTestCase(test.TestCase):
                         'replication_domain': None,
                         'sg_consistent_snapshot_support': None,
                         'security_service_update_support': False,
+                        'network_allocation_update_support': False,
+                        'share_server_multiple_subnet_support': False,
                     },
                 },
             ]
@@ -306,6 +318,8 @@ class HostManagerTestCase(test.TestCase):
                         'driver_version': None,
                         'total_capacity_gb': 51,
                         'reserved_percentage': 0,
+                        'reserved_snapshot_percentage': 0,
+                        'reserved_share_extend_percentage': 0,
                         'provisioned_capacity_gb': 10,
                         'max_over_subscription_ratio': 1.0,
                         'thin_provisioning': False,
@@ -322,6 +336,8 @@ class HostManagerTestCase(test.TestCase):
                         'replication_domain': None,
                         'sg_consistent_snapshot_support': None,
                         'security_service_update_support': False,
+                        'network_allocation_update_support': False,
+                        'share_server_multiple_subnet_support': False,
                     },
                 }, {
                     'name': 'host2@BBB#pool2',
@@ -336,6 +352,8 @@ class HostManagerTestCase(test.TestCase):
                         'driver_version': None,
                         'total_capacity_gb': 52,
                         'reserved_percentage': 0,
+                        'reserved_snapshot_percentage': 0,
+                        'reserved_share_extend_percentage': 0,
                         'provisioned_capacity_gb': 60,
                         'max_over_subscription_ratio': 2.0,
                         'thin_provisioning': True,
@@ -352,6 +370,8 @@ class HostManagerTestCase(test.TestCase):
                         'replication_domain': None,
                         'sg_consistent_snapshot_support': None,
                         'security_service_update_support': False,
+                        'network_allocation_update_support': False,
+                        'share_server_multiple_subnet_support': False,
                     },
                 }, {
                     'name': 'host3@CCC#pool3',
@@ -366,6 +386,8 @@ class HostManagerTestCase(test.TestCase):
                         'driver_version': None,
                         'total_capacity_gb': 53,
                         'reserved_percentage': 0,
+                        'reserved_snapshot_percentage': 0,
+                        'reserved_share_extend_percentage': 0,
                         'provisioned_capacity_gb': 100,
                         'max_over_subscription_ratio': 20.0,
                         'thin_provisioning': True,
@@ -382,6 +404,8 @@ class HostManagerTestCase(test.TestCase):
                         'replication_domain': None,
                         'sg_consistent_snapshot_support': None,
                         'security_service_update_support': False,
+                        'network_allocation_update_support': False,
+                        'share_server_multiple_subnet_support': False,
                     },
                 }, {
                     'name': 'host4@DDD#pool4a',
@@ -396,6 +420,8 @@ class HostManagerTestCase(test.TestCase):
                         'driver_version': None,
                         'total_capacity_gb': 541,
                         'reserved_percentage': 0,
+                        'reserved_snapshot_percentage': 0,
+                        'reserved_share_extend_percentage': 0,
                         'provisioned_capacity_gb': 800,
                         'max_over_subscription_ratio': 2.0,
                         'thin_provisioning': True,
@@ -412,6 +438,8 @@ class HostManagerTestCase(test.TestCase):
                         'replication_domain': None,
                         'sg_consistent_snapshot_support': None,
                         'security_service_update_support': False,
+                        'network_allocation_update_support': False,
+                        'share_server_multiple_subnet_support': False,
                     },
                 }, {
                     'name': 'host4@DDD#pool4b',
@@ -426,6 +454,8 @@ class HostManagerTestCase(test.TestCase):
                         'driver_version': None,
                         'total_capacity_gb': 542,
                         'reserved_percentage': 0,
+                        'reserved_snapshot_percentage': 0,
+                        'reserved_share_extend_percentage': 0,
                         'provisioned_capacity_gb': 2000,
                         'max_over_subscription_ratio': 10.0,
                         'thin_provisioning': True,
@@ -442,6 +472,8 @@ class HostManagerTestCase(test.TestCase):
                         'replication_domain': None,
                         'sg_consistent_snapshot_support': None,
                         'security_service_update_support': False,
+                        'network_allocation_update_support': False,
+                        'share_server_multiple_subnet_support': False,
                     },
                 },
             ]
@@ -494,6 +526,8 @@ class HostManagerTestCase(test.TestCase):
                         'driver_version': None,
                         'total_capacity_gb': 512,
                         'reserved_percentage': 0,
+                        'reserved_snapshot_percentage': 0,
+                        'reserved_share_extend_percentage': 0,
                         'vendor_name': None,
                         'storage_protocol': None,
                         'provisioned_capacity_gb': 312,
@@ -505,6 +539,8 @@ class HostManagerTestCase(test.TestCase):
                         'replication_domain': None,
                         'sg_consistent_snapshot_support': None,
                         'security_service_update_support': False,
+                        'network_allocation_update_support': False,
+                        'share_server_multiple_subnet_support': False,
                     },
                 }, {
                     'name': 'host2@back1#BBB',
@@ -523,6 +559,8 @@ class HostManagerTestCase(test.TestCase):
                         'driver_version': None,
                         'total_capacity_gb': 256,
                         'reserved_percentage': 0,
+                        'reserved_snapshot_percentage': 0,
+                        'reserved_share_extend_percentage': 0,
                         'vendor_name': None,
                         'storage_protocol': None,
                         'provisioned_capacity_gb': 400,
@@ -534,6 +572,8 @@ class HostManagerTestCase(test.TestCase):
                         'replication_domain': None,
                         'sg_consistent_snapshot_support': None,
                         'security_service_update_support': False,
+                        'network_allocation_update_support': False,
+                        'share_server_multiple_subnet_support': False,
                     },
                 },
             ]
@@ -580,6 +620,8 @@ class HostManagerTestCase(test.TestCase):
                         'driver_version': None,
                         'total_capacity_gb': 52,
                         'reserved_percentage': 0,
+                        'reserved_snapshot_percentage': 0,
+                        'reserved_share_extend_percentage': 0,
                         'provisioned_capacity_gb': 60,
                         'max_over_subscription_ratio': 2.0,
                         'thin_provisioning': True,
@@ -591,6 +633,8 @@ class HostManagerTestCase(test.TestCase):
                         'replication_domain': None,
                         'sg_consistent_snapshot_support': None,
                         'security_service_update_support': False,
+                        'network_allocation_update_support': False,
+                        'share_server_multiple_subnet_support': False,
                     },
                 },
             ]
@@ -644,6 +688,8 @@ class HostStateTestCase(test.TestCase):
         share_capability = {'total_capacity_gb': 0,
                             'free_capacity_gb': 100,
                             'reserved_percentage': 0,
+                            'reserved_snapshot_percentage': 0,
+                            'reserved_share_extend_percentage': 0,
                             'timestamp': None,
                             'ipv4_support': True,
                             'ipv6_support': False}
@@ -696,6 +742,8 @@ class HostStateTestCase(test.TestCase):
                  'allocated_capacity_gb': 270,
                  'qos': 'False',
                  'reserved_percentage': 0,
+                 'reserved_snapshot_percentage': 0,
+                 'reserved_share_extend_percentage': 0,
                  'dying_disks': 100,
                  'super_hero_1': 'spider-man',
                  'super_hero_2': 'flash',
@@ -707,6 +755,8 @@ class HostStateTestCase(test.TestCase):
                  'allocated_capacity_gb': 0,
                  'qos': 'False',
                  'reserved_percentage': 0,
+                 'reserved_snapshot_percentage': 0,
+                 'reserved_share_extend_percentage': 0,
                  'dying_disks': 200,
                  'super_hero_1': 'superman',
                  'super_hero_2': 'Hulk',
@@ -752,6 +802,8 @@ class HostStateTestCase(test.TestCase):
                  'allocated_capacity_gb': 0,
                  'qos': 'False',
                  'reserved_percentage': 0,
+                 'reserved_snapshot_percentage': 0,
+                 'reserved_share_extend_percentage': 0,
                  },
             ],
             'timestamp': None,
@@ -778,6 +830,8 @@ class HostStateTestCase(test.TestCase):
             'free_capacity_gb': 'unknown',
             'allocated_capacity_gb': 1,
             'reserved_percentage': 0,
+            'reserved_snapshot_percentage': 0,
+            'reserved_share_extend_percentage': 0,
             'timestamp': None
         }
         fake_context = context.RequestContext('user', 'project', is_admin=True)
@@ -806,6 +860,8 @@ class HostStateTestCase(test.TestCase):
             'provisioned_capacity_gb': provisioned_capacity_gb,
             'allocated_capacity_gb': provisioned_capacity_gb,
             'reserved_percentage': 0,
+            'reserved_snapshot_percentage': 0,
+            'reserved_share_extend_percentage': 0,
             'timestamp': None
         }
         fake_host = host_manager.PoolState('host1', share_capability, '_pool0')
@@ -827,6 +883,8 @@ class HostStateTestCase(test.TestCase):
             'provisioned_capacity_gb': None,
             'allocated_capacity_gb': 0,
             'reserved_percentage': 0,
+            'reserved_snapshot_percentage': 0,
+            'reserved_share_extend_percentage': 0,
             'timestamp': None
         }
         fake_context = context.RequestContext('user', 'project', is_admin=True)
@@ -864,6 +922,8 @@ class HostStateTestCase(test.TestCase):
             'allocated_capacity_gb': 5000,
             'timestamp': None,
             'reserved_percentage': 0,
+            'reserved_snapshot_percentage': 0,
+            'reserved_share_extend_percentage': 0,
         }
         fake_context = context.RequestContext('user', 'project', is_admin=True)
         fake_host = host_manager.HostState('host1')
@@ -886,6 +946,8 @@ class PoolStateTestCase(test.TestCase):
             'share_capability':
                 {'total_capacity_gb': 1024, 'free_capacity_gb': 512,
                  'reserved_percentage': 0, 'timestamp': None,
+                 'reserved_snapshot_percentage': 0,
+                 'reserved_share_extend_percentage': 0,
                  'thin_provisioning': True,
                  'cap1': 'val1', 'cap2': 'val2'},
             'instances':
@@ -908,6 +970,8 @@ class PoolStateTestCase(test.TestCase):
             'share_capability':
                 {'total_capacity_gb': 1024, 'free_capacity_gb': 512,
                  'reserved_percentage': 0, 'timestamp': None,
+                 'reserved_snapshot_percentage': 0,
+                 'reserved_share_extend_percentage': 0,
                  'thin_provisioning': False, 'cap1': 'val1', 'cap2': 'val2'},
             'instances':
                 [
@@ -929,6 +993,8 @@ class PoolStateTestCase(test.TestCase):
             'share_capability':
                 {'total_capacity_gb': 1024, 'free_capacity_gb': 512,
                  'reserved_percentage': 0, 'timestamp': None,
+                 'reserved_snapshot_percentage': 0,
+                 'reserved_share_extend_percentage': 0,
                  'thin_provisioning': [False], 'cap1': 'val1', 'cap2': 'val2'},
             'instances':
                 [
@@ -950,6 +1016,8 @@ class PoolStateTestCase(test.TestCase):
             'share_capability':
                 {'total_capacity_gb': 1024, 'free_capacity_gb': 512,
                  'reserved_percentage': 0, 'timestamp': None,
+                 'reserved_snapshot_percentage': 0,
+                 'reserved_share_extend_percentage': 0,
                  'thin_provisioning': [True, False], 'cap1': 'val1',
                  'cap2': 'val2'},
             'instances':
@@ -972,6 +1040,8 @@ class PoolStateTestCase(test.TestCase):
             'share_capability':
                 {'total_capacity_gb': 1024, 'free_capacity_gb': 512,
                  'reserved_percentage': 0, 'timestamp': None,
+                 'reserved_snapshot_percentage': 0,
+                 'reserved_share_extend_percentage': 0,
                  'cap1': 'val1', 'cap2': 'val2', 'ipv4_support': True,
                  'ipv6_support': False},
             'instances': []
@@ -980,6 +1050,8 @@ class PoolStateTestCase(test.TestCase):
             'share_capability':
                 {'total_capacity_gb': 1024, 'free_capacity_gb': 512,
                  'reserved_percentage': 0, 'timestamp': None,
+                 'reserved_snapshot_percentage': 0,
+                 'reserved_share_extend_percentage': 0,
                  'thin_provisioning': True, 'cap1': 'val1', 'cap2': 'val2',
                  'ipv4_support': True, 'ipv6_support': False},
             'instances': []
@@ -988,6 +1060,8 @@ class PoolStateTestCase(test.TestCase):
             'share_capability':
                 {'total_capacity_gb': 1024, 'free_capacity_gb': 512,
                  'reserved_percentage': 0, 'timestamp': None,
+                 'reserved_snapshot_percentage': 0,
+                 'reserved_share_extend_percentage': 0,
                  'thin_provisioning': [False], 'cap1': 'val1', 'cap2': 'val2',
                  'ipv4_support': True, 'ipv6_support': False},
             'instances': []
@@ -996,6 +1070,8 @@ class PoolStateTestCase(test.TestCase):
             'share_capability':
                 {'total_capacity_gb': 1024, 'free_capacity_gb': 512,
                  'reserved_percentage': 0, 'timestamp': None,
+                 'reserved_snapshot_percentage': 0,
+                 'reserved_share_extend_percentage': 0,
                  'thin_provisioning': [True, False], 'cap1': 'val1',
                  'cap2': 'val2', 'ipv4_support': True, 'ipv6_support': False},
             'instances': []
@@ -1004,6 +1080,8 @@ class PoolStateTestCase(test.TestCase):
             'share_capability':
                 {'total_capacity_gb': 1024, 'free_capacity_gb': 512,
                  'allocated_capacity_gb': 256, 'reserved_percentage': 0,
+                 'reserved_snapshot_percentage': 0,
+                 'reserved_share_extend_percentage': 0,
                  'timestamp': None, 'cap1': 'val1', 'cap2': 'val2',
                  'ipv4_support': False, 'ipv6_support': True
                  },
@@ -1021,6 +1099,8 @@ class PoolStateTestCase(test.TestCase):
             'share_capability':
                 {'total_capacity_gb': 1024, 'free_capacity_gb': 512,
                  'allocated_capacity_gb': 256, 'reserved_percentage': 0,
+                 'reserved_snapshot_percentage': 0,
+                 'reserved_share_extend_percentage': 0,
                  'timestamp': None, 'cap1': 'val1', 'cap2': 'val2',
                  'ipv4_support': True, 'ipv6_support': True},
             'instances': []
@@ -1029,6 +1109,8 @@ class PoolStateTestCase(test.TestCase):
             'share_capability':
                 {'total_capacity_gb': 1024, 'free_capacity_gb': 512,
                  'provisioned_capacity_gb': 256, 'reserved_percentage': 0,
+                 'reserved_snapshot_percentage': 0,
+                 'reserved_share_extend_percentage': 0,
                  'timestamp': None, 'cap1': 'val1', 'cap2': 'val2',
                  'ipv4_support': False, 'ipv6_support': False
                  },
@@ -1047,6 +1129,8 @@ class PoolStateTestCase(test.TestCase):
                 {'total_capacity_gb': 1024, 'free_capacity_gb': 512,
                  'allocated_capacity_gb': 256, 'provisioned_capacity_gb': 1,
                  'thin_provisioning': True, 'reserved_percentage': 0,
+                 'reserved_snapshot_percentage': 0,
+                 'reserved_share_extend_percentage': 0,
                  'timestamp': None, 'cap1': 'val1', 'cap2': 'val2'},
             'instances':
                 [
@@ -1063,6 +1147,8 @@ class PoolStateTestCase(test.TestCase):
                 {'total_capacity_gb': 1024, 'free_capacity_gb': 512,
                  'allocated_capacity_gb': 256, 'provisioned_capacity_gb': 1,
                  'thin_provisioning': [False], 'reserved_percentage': 0,
+                 'reserved_snapshot_percentage': 0,
+                 'reserved_share_extend_percentage': 0,
                  'timestamp': None, 'cap1': 'val1', 'cap2': 'val2'},
             'instances':
                 [
@@ -1079,6 +1165,8 @@ class PoolStateTestCase(test.TestCase):
                 {'total_capacity_gb': 1024, 'free_capacity_gb': 512,
                  'allocated_capacity_gb': 256, 'provisioned_capacity_gb': 1,
                  'thin_provisioning': [True, False], 'reserved_percentage': 0,
+                 'reserved_snapshot_percentage': 0,
+                 'reserved_share_extend_percentage': 0,
                  'timestamp': None, 'cap1': 'val1', 'cap2': 'val2'},
             'instances':
                 [
@@ -1095,6 +1183,8 @@ class PoolStateTestCase(test.TestCase):
                 {'total_capacity_gb': 1024, 'free_capacity_gb': 512,
                  'allocated_capacity_gb': 256, 'provisioned_capacity_gb': 256,
                  'thin_provisioning': False, 'reserved_percentage': 0,
+                 'reserved_snapshot_percentage': 0,
+                 'reserved_share_extend_percentage': 0,
                  'timestamp': None, 'cap1': 'val1', 'cap2': 'val2'},
             'instances':
                 [
@@ -1111,6 +1201,8 @@ class PoolStateTestCase(test.TestCase):
                 {'total_capacity_gb': 1024, 'free_capacity_gb': 512,
                  'allocated_capacity_gb': 256, 'provisioned_capacity_gb': 256,
                  'thin_provisioning': [False], 'reserved_percentage': 0,
+                 'reserved_snapshot_percentage': 0,
+                 'reserved_share_extend_percentage': 0,
                  'timestamp': None, 'cap1': 'val1', 'cap2': 'val2'},
             'instances':
                 [
@@ -1139,7 +1231,7 @@ class PoolStateTestCase(test.TestCase):
         self.assertEqual('pool0', fake_pool.pool_name)
         self.assertEqual(1024, fake_pool.total_capacity_gb)
         self.assertEqual(512, fake_pool.free_capacity_gb)
-        self.assertDictMatch(share_capability, fake_pool.capabilities)
+        self.assertDictEqual(share_capability, dict(fake_pool.capabilities))
 
         if 'thin_provisioning' in share_capability:
             thin_provisioned = scheduler_utils.thin_provisioning(
