@@ -13,6 +13,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import json
 from unittest import mock
 
 import ddt
@@ -88,6 +89,7 @@ class CephFSDriverTestCase(test.TestCase):
         self.mock_object(driver, "json_command", MockCephArgparseModule)
         self.mock_object(driver, 'NativeProtocolHelper')
         self.mock_object(driver, 'NFSProtocolHelper')
+        self.mock_object(driver, 'NFSClusterProtocolHelper')
 
         driver.ceph_default_target = ('mon-mgr', )
 
@@ -101,10 +103,17 @@ class CephFSDriverTestCase(test.TestCase):
         self.mock_object(share_types, 'get_share_type_extra_specs',
                          mock.Mock(return_value={}))
 
-    @ddt.data('cephfs', 'nfs')
-    def test_do_setup(self, protocol_helper):
+    @ddt.data(
+        ('cephfs', None),
+        ('nfs', None),
+        ('nfs', 'fs-manila')
+    )
+    @ddt.unpack
+    def test_do_setup(self, protocol_helper, cephfs_nfs_cluster_id):
         self._driver.configuration.cephfs_protocol_helper_type = (
             protocol_helper)
+        self.fake_conf.set_default('cephfs_nfs_cluster_id',
+                                   cephfs_nfs_cluster_id)
 
         self._driver.do_setup(self._context)
 
@@ -114,10 +123,16 @@ class CephFSDriverTestCase(test.TestCase):
                 rados_client=self._driver._rados_client,
                 volname=self._driver.volname)
         else:
-            driver.NFSProtocolHelper.assert_called_once_with(
-                self._execute, self._driver.configuration,
-                rados_client=self._driver._rados_client,
-                volname=self._driver.volname)
+            if self.fake_conf.cephfs_nfs_cluster_id is None:
+                driver.NFSProtocolHelper.assert_called_once_with(
+                    self._execute, self._driver.configuration,
+                    rados_client=self._driver._rados_client,
+                    volname=self._driver.volname)
+            else:
+                driver.NFSClusterProtocolHelper.assert_called_once_with(
+                    self._execute, self._driver.configuration,
+                    rados_client=self._driver._rados_client,
+                    volname=self._driver.volname)
 
         self._driver.protocol_helper.init_helper.assert_called_once_with()
 
@@ -221,37 +236,34 @@ class CephFSDriverTestCase(test.TestCase):
             share_server=None)
 
     def test_ensure_share(self):
-        expected_exports = {
-            'path': '1.2.3.4,5.6.7.8:/foo/bar',
-            'is_admin_only': False,
-            'metadata': {},
+        create_share_prefix = "fs subvolume create"
+        get_path_prefix = "fs subvolume getpath"
+
+        create_share_dict = {
+            "vol_name": self._driver.volname,
+            "sub_name": self._share["id"],
+            "size": self._share["size"] * units.Gi,
+            "namespace_isolated": True,
+            "mode": DEFAULT_VOLUME_MODE,
         }
-        self.mock_object(
-            self._driver, '_get_export_locations',
-            mock.Mock(return_value=expected_exports))
 
-        returned_exports = self._driver.ensure_share(self._context,
-                                                     self._share)
+        get_path_dict = {
+            "vol_name": self._driver.volname,
+            "sub_name": self._share["id"],
+        }
 
-        self._driver._get_export_locations.assert_called_once_with(self._share)
+        self._driver.ensure_share(self._context,
+                                  self._share)
 
-        self.assertEqual(expected_exports, returned_exports)
+        driver.rados_command.assert_has_calls([
+            mock.call(self._driver.rados_client,
+                      create_share_prefix,
+                      create_share_dict),
+            mock.call(self._driver.rados_client,
+                      get_path_prefix,
+                      get_path_dict)])
 
-    def test_ensure_share_subvolume_not_found(self):
-        message = f"Error ENOENT: subvolume {self._share['id']} does not exist"
-        expected_exception = exception.ShareBackendException(message)
-
-        self.mock_object(
-            self._driver, '_get_export_locations',
-            mock.Mock(side_effect=expected_exception))
-
-        self.assertRaises(
-            exception.ShareResourceNotFound,
-            self._driver.ensure_share,
-            self._context,
-            self._share)
-
-        self._driver._get_export_locations.assert_called_once_with(self._share)
+        self.assertEqual(2, driver.rados_command.call_count)
 
     def test_delete_share(self):
         clone_status_prefix = "fs clone status"
@@ -352,7 +364,8 @@ class CephFSDriverTestCase(test.TestCase):
         snapshot_create_dict = {
             "vol_name": self._driver.volname,
             "sub_name": self._snapshot["share_id"],
-            "snap_name": self._snapshot["snapshot_id"]
+            "snap_name": "_".join([
+                self._snapshot["snapshot_id"], self._snapshot["id"]]),
         }
 
         self._driver.create_snapshot(self._context, self._snapshot, None)
@@ -362,35 +375,23 @@ class CephFSDriverTestCase(test.TestCase):
             snapshot_create_prefix, snapshot_create_dict)
 
     def test_delete_snapshot(self):
-        legacy_snap_name = "_".join(
-            [self._snapshot["snapshot_id"], self._snapshot["id"]])
-
         snapshot_remove_prefix = "fs subvolume snapshot rm"
 
         snapshot_remove_dict = {
             "vol_name": self._driver.volname,
             "sub_name": self._snapshot["share_id"],
-            "snap_name": legacy_snap_name,
-            "force": True
+            "snap_name": "_".join([
+                self._snapshot["snapshot_id"], self._snapshot["id"]]),
+            "force": True,
         }
 
-        snapshot_remove_dict_2 = snapshot_remove_dict.copy()
-        snapshot_remove_dict_2.update(
-            {"snap_name": self._snapshot["snapshot_id"]})
-
         self._driver.delete_snapshot(self._context,
                                      self._snapshot,
                                      None)
 
-        driver.rados_command.assert_has_calls([
-            mock.call(self._driver.rados_client,
-                      snapshot_remove_prefix,
-                      snapshot_remove_dict),
-            mock.call(self._driver.rados_client,
-                      snapshot_remove_prefix,
-                      snapshot_remove_dict_2)])
-
-        self.assertEqual(2, driver.rados_command.call_count)
+        driver.rados_command.assert_called_once_with(
+            self._driver.rados_client,
+            snapshot_remove_prefix, snapshot_remove_dict)
 
     def test_create_share_group(self):
         group_create_prefix = "fs subvolumegroup create"
@@ -464,7 +465,8 @@ class CephFSDriverTestCase(test.TestCase):
         create_share_from_snapshot_dict = {
             "vol_name": self._driver.volname,
             "sub_name": parent_share["id"],
-            "snap_name": self._snapshot["snapshot_id"],
+            "snap_name": "_".join([
+                self._snapshot["snapshot_id"], self._snapshot["id"]]),
             "target_sub_name": self._share["id"]
         }
 
@@ -557,12 +559,16 @@ class CephFSDriverTestCase(test.TestCase):
             'reserved_share_percentage', 5)
         self._driver.configuration.local_conf.set_override(
             'reserved_share_from_snapshot_percentage', 2)
+        self._driver.configuration.local_conf.set_override(
+            'reserved_share_extend_percentage', 2)
 
         self._driver._update_share_stats()
         result = self._driver._stats
 
         self.assertEqual(5, result['pools'][0]['reserved_percentage'])
         self.assertEqual(2, result['pools'][0]['reserved_snapshot_percentage'])
+        self.assertEqual(
+            2, result['pools'][0]['reserved_share_extend_percentage'])
         self.assertEqual(164.94, result['pools'][0]['total_capacity_gb'])
         self.assertEqual(149.84, result['pools'][0]['free_capacity_gb'])
         self.assertTrue(result['ipv4_support'])
@@ -1048,7 +1054,8 @@ class NFSProtocolHelperTestCase(test.TestCase):
         fake_conf = configuration.Configuration(None)
         conf_args_list = [
             ('cephfs_ganesha_server_ip', '1.2.3.4'),
-            ('cephfs_ganesha_export_ips', '127.0.0.1,fd3f:c057:1192:1::1,::1')]
+            ('cephfs_ganesha_export_ips',
+             ['127.0.0.1', 'fd3f:c057:1192:1::1', '::1'])]
         for args in conf_args_list:
             fake_conf.set_default(*args)
 
@@ -1162,8 +1169,7 @@ class NFSProtocolHelperTestCase(test.TestCase):
         expected_ret = {
             "Name": "Ceph",
             "User_Id": "ganesha-fakeid",
-            "Secret_Access_Key": "ganesha-zorilla",
-            "Filesystem": self._nfs_helper.volname
+            "Secret_Access_Key": "ganesha-zorilla"
         }
 
         driver.rados_command.return_value = 'ganesha-zorilla'
@@ -1230,6 +1236,136 @@ class NFSProtocolHelperTestCase(test.TestCase):
         self.assertEqual('/foo/bar', ret)
 
 
+@ddt.ddt
+class NFSClusterProtocolHelperTestCase(test.TestCase):
+
+    def setUp(self):
+        super(NFSClusterProtocolHelperTestCase, self).setUp()
+        self._execute = mock.Mock()
+        self._context = context.get_admin_context()
+        self._share = fake_share.fake_share(share_proto='NFS')
+        self._rados_client = MockRadosModule.Rados()
+        self._volname = "cephfs"
+        self.fake_conf = configuration.Configuration(None)
+
+        self.mock_object(driver.NFSClusterProtocolHelper,
+                         '_get_export_path',
+                         mock.Mock(return_value="ganesha:/foo/bar"))
+        self.mock_object(driver.NFSClusterProtocolHelper,
+                         '_get_export_pseudo_path',
+                         mock.Mock(return_value="ganesha:/foo/bar"))
+        self.mock_object(driver, "rados_command")
+
+        driver.ceph_default_target = ('mon-mgr', )
+
+        self._nfscluster_protocol_helper = driver.NFSClusterProtocolHelper(
+            self._execute,
+            self.fake_conf,
+            rados_client=self._rados_client,
+            volname=self._volname)
+
+        type(self._nfscluster_protocol_helper).nfs_clusterid = (
+            mock.PropertyMock(return_value='fs-manila'))
+
+    @ddt.data(constants.ACCESS_LEVEL_RW, constants.ACCESS_LEVEL_RO)
+    def test_allow_access_rw_ro(self, mode):
+        access_allow_prefix = "nfs export apply"
+        nfs_clusterid = self._nfscluster_protocol_helper.nfs_clusterid
+        volname = self._nfscluster_protocol_helper.volname
+
+        clients = {
+            'access_type': mode,
+            'addresses': ['10.0.0.1'],
+            'squash': 'none'
+        }
+
+        access_allow_dict = {
+            "cluster_id": nfs_clusterid,
+        }
+
+        export = {
+            "path": "ganesha:/foo/bar",
+            "cluster_id": nfs_clusterid,
+            "pseudo": "ganesha:/foo/bar",
+            "squash": "none",
+            "security_label": True,
+            "protocols": [4],
+            "fsal": {
+                "name": "CEPH",
+                "fs_name": volname,
+
+            },
+            "clients": clients
+        }
+
+        inbuf = json.dumps(export).encode('utf-8')
+
+        self._nfscluster_protocol_helper._allow_access(self._share, clients)
+
+        driver.rados_command.assert_called_once_with(
+            self._rados_client,
+            access_allow_prefix, access_allow_dict, inbuf=inbuf)
+
+    def test_deny_access(self):
+        access_deny_prefix = "nfs export rm"
+
+        nfs_clusterid = self._nfscluster_protocol_helper.nfs_clusterid
+
+        access_deny_dict = {
+            "cluster_id": nfs_clusterid,
+            "pseudo_path": "ganesha:/foo/bar"
+        }
+
+        self._nfscluster_protocol_helper._deny_access(self._share)
+
+        driver.rados_command.assert_called_once_with(
+            self._rados_client,
+            access_deny_prefix, access_deny_dict)
+
+    def test_get_export_locations(self):
+        cluster_info_prefix = "nfs cluster info"
+        nfs_clusterid = self._nfscluster_protocol_helper.nfs_clusterid
+
+        cluster_info_dict = {
+            "cluster_id": nfs_clusterid,
+        }
+
+        cluster_info = {"fs-manila": {
+                        "virtual_ip": None,
+                        "backend": [
+                            {"hostname": "fake-ceph-node-1",
+                             "ip": "10.0.0.10",
+                             "port": "1010"},
+                            {"hostname": "fake-ceph-node-2",
+                             "ip": "10.0.0.11",
+                             "port": "1011"}
+                            ]
+                        }}
+
+        driver.rados_command.return_value = json.dumps(cluster_info)
+
+        fake_cephfs_subvolume_path = "/foo/bar"
+        expected_export_locations = [{
+            'path': '10.0.0.10:/foo/bar',
+            'is_admin_only': False,
+            'metadata': {},
+        }, {
+            'path': '10.0.0.11:/foo/bar',
+            'is_admin_only': False,
+            'metadata': {},
+        }]
+
+        export_locations = (
+            self._nfscluster_protocol_helper.get_export_locations(
+                self._share, fake_cephfs_subvolume_path))
+
+        driver.rados_command.assert_called_once_with(
+            self._rados_client,
+            cluster_info_prefix, cluster_info_dict)
+
+        self.assertEqual(expected_export_locations, export_locations)
+
+
 @ddt.ddt
 class CephFSDriverAltConfigTestCase(test.TestCase):
     """Test the CephFS driver with non-default config values."""
