@@ -55,6 +55,8 @@ class LVMHelperTestCase(test.TestCase):
     @ddt.data("62.50g 72.50g", "    72.50g 62.50g\n", "  <62.50g <72.50g\n")
     def test_get_share_server_pools(self, ret_vgs):
         expected_result = [{'reserved_percentage': 0,
+                            'reserved_snapshot_percentage': 0,
+                            'reserved_share_extend_percentage': 0,
                             'pool_name': 'manila_docker_volumes',
                             'total_capacity_gb': 72.5,
                             'free_capacity_gb': 62.5}]
@@ -235,7 +237,7 @@ class LVMHelperTestCase(test.TestCase):
             'preserve_metadata': True,
             'preserve_snapshots': False,
         }
-        self.assertDictMatch(expected_compatibility, migration_compatibility)
+        self.assertDictEqual(expected_compatibility, migration_compatibility)
         if not compatible:
             mock_exception_log.assert_called_once()
 
@@ -252,7 +254,7 @@ class LVMHelperTestCase(test.TestCase):
         expected_progress = {
             'total_progress': 100,
         }
-        self.assertDictMatch(expected_progress, progress)
+        self.assertDictEqual(expected_progress, progress)
 
     @ddt.data({'source_host': 'host@back1', 'dest_host': 'host@back1',
                'shares_specs': {}},
@@ -269,7 +271,7 @@ class LVMHelperTestCase(test.TestCase):
             'nondisruptive': None,
             'preserve_snapshots': None,
             'migration_cancel': None,
-            'migration_get_progress': None
+            'migration_get_progress': None,
         }
         mock_error_log = self.mock_object(storage_helper.LOG, 'error')
 
@@ -279,7 +281,7 @@ class LVMHelperTestCase(test.TestCase):
                 self.context, source_server, dest_host, None, None,
                 shares_specs))
 
-        self.assertDictMatch(not_compatible, migration_compatibility)
+        self.assertDictEqual(not_compatible, migration_compatibility)
         mock_error_log.assert_called_once()
 
     @ddt.data({'source_host': 'host@back1', 'dest_host': 'host@back2#vg1',
@@ -299,7 +301,7 @@ class LVMHelperTestCase(test.TestCase):
             'nondisruptive': False,
             'preserve_snapshots': False,
             'migration_cancel': True,
-            'migration_get_progress': True
+            'migration_get_progress': True,
         }
 
         source_server = {'id': 'fake_id', 'host': source_host}
@@ -308,7 +310,7 @@ class LVMHelperTestCase(test.TestCase):
                 self.context, source_server, dest_host, None, None,
                 shares_specs))
 
-        self.assertDictMatch(compatible, migration_compatibility)
+        self.assertDictEqual(compatible, migration_compatibility)
 
     def test_share_server_migration_continue(self):
         end1Phase = self.LVMHelper.share_server_migration_continue(
@@ -321,7 +323,7 @@ class LVMHelperTestCase(test.TestCase):
         expected_progress = {
             'total_progress': 100,
         }
-        self.assertDictMatch(expected_progress, progress)
+        self.assertDictEqual(expected_progress, progress)
 
     def test_get_share_pool_name(self):
         fake_vg_name = 'fake_vg'
