@@ -727,6 +727,8 @@ class HPE3ParDriverTestCase(test.TestCase):
             'free_capacity_gb': 0,
             'max_over_subscription_ratio': None,
             'reserved_percentage': 0,
+            'reserved_snapshot_percentage': 0,
+            'reserved_share_extend_percentage': 0,
             'provisioned_capacity_gb': 0,
             'share_backend_name': 'HPE_3PAR',
             'snapshot_support': True,
@@ -746,6 +748,11 @@ class HPE3ParDriverTestCase(test.TestCase):
             'goodness_function': None,
             'ipv4_support': True,
             'ipv6_support': False,
+            'max_share_server_size': -1,
+            'max_shares_per_share_server': -1,
+            'security_service_update_support': False,
+            'share_server_multiple_subnet_support': False,
+            'network_allocation_update_support': False,
         }
 
         result = self.driver.get_share_stats(refresh=True)
@@ -785,6 +792,8 @@ class HPE3ParDriverTestCase(test.TestCase):
             'hpe3par_flash_cache': False,
             'hp3par_flash_cache': False,
             'reserved_percentage': 0,
+            'reserved_snapshot_percentage': 0,
+            'reserved_share_extend_percentage': 0,
             'provisioned_capacity_gb': expected_capacity
         }
 
@@ -798,7 +807,11 @@ class HPE3ParDriverTestCase(test.TestCase):
             'free_capacity_gb': 0,
             'provisioned_capacity_gb': 0,
             'reserved_percentage': 0,
+            'reserved_snapshot_percentage': 0,
+            'reserved_share_extend_percentage': 0,
             'max_over_subscription_ratio': None,
+            'max_share_server_size': -1,
+            'max_shares_per_share_server': -1,
             'qos': False,
             'thin_provisioning': True,
             'pools': [{
@@ -810,10 +823,15 @@ class HPE3ParDriverTestCase(test.TestCase):
                 'hpe3par_flash_cache': False,
                 'hp3par_flash_cache': False,
                 'reserved_percentage': 0,
+                'reserved_snapshot_percentage': 0,
+                'reserved_share_extend_percentage': 0,
                 'provisioned_capacity_gb': expected_capacity}],
             'snapshot_support': True,
             'create_share_from_snapshot_support': True,
             'revert_to_snapshot_support': False,
+            'security_service_update_support': False,
+            'share_server_multiple_subnet_support': False,
+            'network_allocation_update_support': False,
             'mount_snapshot_support': False,
             'share_group_stats': {
                 'consistent_snapshot_support': None,
@@ -847,9 +865,13 @@ class HPE3ParDriverTestCase(test.TestCase):
             'driver_version': expected_version,
             'free_capacity_gb': 0,
             'max_over_subscription_ratio': None,
+            'max_share_server_size': -1,
+            'max_shares_per_share_server': -1,
             'pools': None,
             'provisioned_capacity_gb': 0,
             'reserved_percentage': 0,
+            'reserved_snapshot_percentage': 0,
+            'reserved_share_extend_percentage': 0,
             'share_backend_name': 'HPE_3PAR',
             'storage_protocol': 'NFS_CIFS',
             'thin_provisioning': True,
@@ -858,6 +880,9 @@ class HPE3ParDriverTestCase(test.TestCase):
             'snapshot_support': True,
             'create_share_from_snapshot_support': True,
             'revert_to_snapshot_support': False,
+            'security_service_update_support': False,
+            'share_server_multiple_subnet_support': False,
+            'network_allocation_update_support': False,
             'mount_snapshot_support': False,
             'share_group_stats': {
                 'consistent_snapshot_support': None,
@@ -912,7 +937,7 @@ class HPE3ParDriverTestCase(test.TestCase):
 
         self.init_driver()
 
-        network_info = {
+        network_info = [{
             'network_allocations': [
                 {'ip_address': constants.EXPECTED_IP_1234}],
             'cidr': '/'.join((constants.EXPECTED_IP_1234,
@@ -920,7 +945,7 @@ class HPE3ParDriverTestCase(test.TestCase):
             'network_type': constants.EXPECTED_VLAN_TYPE,
             'segmentation_id': constants.EXPECTED_VLAN_TAG,
             'server_id': constants.EXPECTED_SERVER_ID,
-        }
+        }]
 
         expected_result = {
             'share_server_name': constants.EXPECTED_SERVER_ID,
@@ -950,7 +975,7 @@ class HPE3ParDriverTestCase(test.TestCase):
 
         self.init_driver()
 
-        network_info = {
+        network_info = [{
             'network_allocations': [
                 {'ip_address': constants.EXPECTED_IP_1234}],
             'cidr': '/'.join((constants.EXPECTED_IP_1234,
@@ -958,7 +983,7 @@ class HPE3ParDriverTestCase(test.TestCase):
             'network_type': constants.EXPECTED_VXLAN_TYPE,
             'segmentation_id': constants.EXPECTED_VLAN_TAG,
             'server_id': constants.EXPECTED_SERVER_ID,
-        }
+        }]
         metadata = {'request_host': constants.EXPECTED_HOST}
 
         self.assertRaises(exception.NetworkBadConfigurationException,
@@ -970,7 +995,7 @@ class HPE3ParDriverTestCase(test.TestCase):
 
         self.init_driver()
 
-        network_info = {
+        network_info = [{
             'network_allocations': [
                 {'ip_address': constants.EXPECTED_IP_1234}],
             'cidr': '/'.join((constants.EXPECTED_IP_1234,
@@ -978,7 +1003,7 @@ class HPE3ParDriverTestCase(test.TestCase):
             'network_type': constants.EXPECTED_VLAN_TYPE,
             'segmentation_id': constants.EXPECTED_VLAN_TAG,
             'server_id': constants.EXPECTED_SERVER_ID,
-        }
+        }]
         metadata = {'request_host': constants.EXPECTED_HOST}
 
         expected_vfs = self.driver.fpgs[
