@@ -13,6 +13,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from http import client as http_client
+import time
+from unittest import mock
 
 try:
     import xml.etree.cElementTree as ET
@@ -20,12 +23,9 @@ except ImportError:
     import xml.etree.ElementTree as ET
 
 import ddt
-import mock
-from oslo_config import cfg
-import six
-import time
-
 from eventlet import greenthread
+from oslo_config import cfg
+
 from manila import exception
 from manila.share.drivers.qnap import api
 from manila.share.drivers.qnap import qnap
@@ -81,8 +81,8 @@ class QnapShareDriverLoginTestCase(QnapShareDriverBaseTestCase):
     def setUp(self):
         """Setup the Qnap Share Driver login TestCase."""
         super(QnapShareDriverLoginTestCase, self).setUp()
-        self.mock_object(six.moves.http_client, 'HTTPConnection')
-        self.mock_object(six.moves.http_client, 'HTTPSConnection')
+        self.mock_object(http_client, 'HTTPConnection')
+        self.mock_object(http_client, 'HTTPSConnection')
 
     @ddt.unpack
     @ddt.data({'mng_url': 'http://1.2.3.4:8080', 'port': '8080', 'ssl': False},
@@ -93,9 +93,9 @@ class QnapShareDriverLoginTestCase(QnapShareDriverBaseTestCase):
         fake_get_basic_info_response_es = (
             fakes.FakeGetBasicInfoResponseEs_1_1_3())
         if ssl:
-            mock_connection = six.moves.http_client.HTTPSConnection
+            mock_connection = http_client.HTTPSConnection
         else:
-            mock_connection = six.moves.http_client.HTTPConnection
+            mock_connection = http_client.HTTPConnection
         mock_connection.return_value.getresponse.side_effect = [
             fake_login_response,
             fake_get_basic_info_response_es,
@@ -128,7 +128,7 @@ class QnapShareDriverLoginTestCase(QnapShareDriverBaseTestCase):
     def test_do_setup_positive_with_diff_nas(self, fake_basic_info):
         """Test do_setup with different NAS model."""
         fake_login_response = fakes.FakeLoginResponse()
-        mock_connection = six.moves.http_client.HTTPSConnection
+        mock_connection = http_client.HTTPSConnection
         mock_connection.return_value.getresponse.side_effect = [
             fake_login_response,
             fake_basic_info,
@@ -173,7 +173,7 @@ class QnapShareDriverLoginTestCase(QnapShareDriverBaseTestCase):
     def test_create_api_executor(self, fake_basic_info, expect_result):
         """Test do_setup with different NAS model."""
         fake_login_response = fakes.FakeLoginResponse()
-        mock_connection = six.moves.http_client.HTTPSConnection
+        mock_connection = http_client.HTTPSConnection
         mock_connection.return_value.getresponse.side_effect = [
             fake_login_response,
             fake_basic_info,
@@ -206,7 +206,7 @@ class QnapShareDriverLoginTestCase(QnapShareDriverBaseTestCase):
                                           fake_basic_info, expect_result):
         """Test do_setup with different NAS model."""
         fake_login_response = fakes.FakeLoginResponse()
-        mock_connection = six.moves.http_client.HTTPSConnection
+        mock_connection = http_client.HTTPSConnection
         mock_connection.return_value.getresponse.side_effect = [
             fake_login_response,
             fake_basic_info,
@@ -225,7 +225,7 @@ class QnapShareDriverLoginTestCase(QnapShareDriverBaseTestCase):
         fake_login_response = fakes.FakeLoginResponse()
         fake_get_basic_info_response_error = (
             fakes.FakeGetBasicInfoResponseError())
-        mock_connection = six.moves.http_client.HTTPSConnection
+        mock_connection = http_client.HTTPSConnection
         mock_connection.return_value.getresponse.side_effect = [
             fake_login_response,
             fake_get_basic_info_response_error,
@@ -715,15 +715,13 @@ class QnapShareDriverTestCase(QnapShareDriverBaseTestCase):
             expected_call_list,
             mock_api_return.get_share_info.call_args_list)
         mock_api_return.clone_snapshot.assert_called_once_with(
-            'fakeShareName@fakeSnapshotName', 'fakeShareName')
+            'fakeShareName@fakeSnapshotName', 'fakeShareName', 10)
 
     @mock.patch.object(qnap.QnapShareDriver, '_get_location_path')
-    @mock.patch('manila.share.API')
     @mock.patch.object(qnap.QnapShareDriver, '_gen_random_name')
     def test_create_share_from_snapshot_diff_size(
             self,
             mock_gen_random_name,
-            mock_share_api,
             mock_get_location_path):
         """Test create share from snapshot."""
         fake_snapshot = fakes.SnapshotClass(
@@ -740,9 +738,6 @@ class QnapShareDriverTestCase(QnapShareDriverBaseTestCase):
             'False',
             'False',
             'fakeVolName']
-        mock_share_api.return_value.get.return_value = {'size': 5}
-        mock_api_executor.return_value.edit_share.return_value = (
-            None)
 
         self._do_setup('http://1.2.3.4:8080', '1.2.3.4', 'admin',
                        'qnapadmin', 'Storage Pool 1',
@@ -760,19 +755,7 @@ class QnapShareDriverTestCase(QnapShareDriverBaseTestCase):
             expected_call_list,
             mock_api_return.get_share_info.call_args_list)
         mock_api_return.clone_snapshot.assert_called_once_with(
-            'fakeShareName@fakeSnapshotName', 'fakeShareName')
-        expect_share_dict = {
-            'sharename': 'fakeShareName',
-            'old_sharename': 'fakeShareName',
-            'new_size': 10,
-            'thin_provision': True,
-            'compression': True,
-            'deduplication': False,
-            'ssd_cache': False,
-            'share_proto': 'NFS'
-        }
-        mock_api_return.edit_share.assert_called_once_with(
-            expect_share_dict)
+            'fakeShareName@fakeSnapshotName', 'fakeShareName', 10)
 
     def test_create_share_from_snapshot_without_snapshot_id(self):
         """Test create share from snapshot."""
@@ -1114,6 +1097,8 @@ class QnapShareDriverTestCase(QnapShareDriverBaseTestCase):
         mock_api_executor = qnap.QnapShareDriver._create_api_executor
         mock_api_executor.return_value.get_share_info.return_value = (
             self.get_share_info_return_value())
+        mock_api_executor.return_value.get_snapshot_info.return_value = (
+            self.get_snapshot_info_return_value())
         mock_private_storage = mock.Mock()
         mock_private_storage.update.return_value = None
         mock_private_storage.get.side_effect = [
