@@ -17,7 +17,6 @@ from unittest import mock
 
 from oslo_config import cfg
 from oslo_utils import units
-import six
 
 from manila import context
 from manila import exception
@@ -113,7 +112,9 @@ class QuobyteShareDriverTestCase(test.TestCase):
     @mock.patch('manila.share.drivers.quobyte.jsonrpc.JsonRpc.__init__',
                 mock.Mock(return_value=None))
     @mock.patch.object(jsonrpc.JsonRpc, 'call',
-                       side_effect=exception.QBRpcException)
+                       side_effect=exception.QBRpcException(
+                           result='fake_result',
+                           qbcode=666))
     def test_do_setup_failure(self, mock_call):
         self.assertRaises(exception.QBException,
                           self._driver.do_setup, self._context)
@@ -343,7 +344,9 @@ class QuobyteShareDriverTestCase(test.TestCase):
                  driver_version=self._driver.DRIVER_VERSION,
                  total_capacity_gb=42,
                  free_capacity_gb=23,
-                 reserved_percentage=0))
+                 reserved_percentage=0,
+                 reserved_snapshot_percentage=0,
+                 reserved_share_extend_percentage=0))
 
     def test_get_capacities_gb(self):
         capval = 42115548133
@@ -352,8 +355,8 @@ class QuobyteShareDriverTestCase(test.TestCase):
         self._driver._get_qb_replication_factor = mock.Mock(
             return_value=replfact)
         self._driver.rpc.call = mock.Mock(
-            return_value={'total_physical_capacity': six.text_type(capval),
-                          'total_physical_usage': six.text_type(useval)})
+            return_value={'total_physical_capacity': str(capval),
+                          'total_physical_usage': str(useval)})
 
         self.assertEqual((39.223160718, 6.960214182),
                          self._driver._get_capacities())
@@ -365,8 +368,8 @@ class QuobyteShareDriverTestCase(test.TestCase):
         self._driver._get_qb_replication_factor = mock.Mock(
             return_value=replfact)
         self._driver.rpc.call = mock.Mock(
-            return_value={'total_physical_capacity': six.text_type(capval),
-                          'total_physical_usage': six.text_type(useval)})
+            return_value={'total_physical_capacity': str(capval),
+                          'total_physical_usage': str(useval)})
 
         self.assertEqual((3.0, 0), self._driver._get_capacities())
 
@@ -377,7 +380,7 @@ class QuobyteShareDriverTestCase(test.TestCase):
             return_value={'configuration':
                           {'volume_metadata_configuration':
                            {'replication_factor':
-                            six.text_type(fakerepl)}}})
+                            str(fakerepl)}}})
 
         self.assertEqual(fakerepl, self._driver._get_qb_replication_factor())
 
