@@ -23,7 +23,6 @@ from unittest import mock
 import ddt
 from oslo_concurrency import processutils
 from oslo_config import cfg
-from six import moves
 
 from manila.common import constants as const
 from manila import compute
@@ -404,17 +403,17 @@ class GenericShareDriverTestCase(test.TestCase):
         self._driver._unmount_device(self.share, self.server)
 
         self.assertEqual(1, time.sleep.call_count)
-        self.assertEqual([mock.call(self.share) for i in moves.range(2)],
+        self.assertEqual([mock.call(self.share) for i in range(2)],
                          self._driver._get_mount_path.mock_calls)
         self.assertEqual([mock.call(mount_path,
-                                    self.server) for i in moves.range(2)],
+                                    self.server) for i in range(2)],
                          self._driver._is_device_mounted.mock_calls)
         self._driver._remove_mount_permanently.assert_called_once_with(
             self.share.id, self.server)
         self.assertEqual(
             [mock.call(self.server, ['sudo', 'umount', mount_path,
                                      '&&', 'sudo', 'rmdir', mount_path])
-             for i in moves.range(2)],
+             for i in range(2)],
             self._driver._ssh_exec.mock_calls,
         )
 
@@ -834,7 +833,7 @@ class GenericShareDriverTestCase(test.TestCase):
 
     @mock.patch('time.sleep')
     def test_wait_for_available_volume_error_extending(self, mock_sleep):
-        fake_volume = {'status': 'error_extending', 'id': 'fake'}
+        fake_volume = {'status': const.STATUS_EXTENDING_ERROR, 'id': 'fake'}
         self.assertRaises(exception.ManilaException,
                           self._driver._wait_for_available_volume,
                           fake_volume, 5, 'error', 'timeout')
@@ -1183,23 +1182,23 @@ class GenericShareDriverTestCase(test.TestCase):
 
     def test__setup_server(self):
         sim = self._driver.instance_manager
-        net_info = {
+        net_info = [{
             'server_id': 'fake',
             'neutron_net_id': 'fake-net-id',
             'neutron_subnet_id': 'fake-subnet-id',
-        }
+        }]
         self._driver.setup_server(net_info)
         sim.set_up_service_instance.assert_called_once_with(
-            self._context, net_info)
+            self._context, net_info[0])
 
     def test__setup_server_revert(self):
 
         def raise_exception(*args, **kwargs):
             raise exception.ServiceInstanceException
 
-        net_info = {'server_id': 'fake',
-                    'neutron_net_id': 'fake-net-id',
-                    'neutron_subnet_id': 'fake-subnet-id'}
+        net_info = [{'server_id': 'fake',
+                     'neutron_net_id': 'fake-net-id',
+                     'neutron_subnet_id': 'fake-subnet-id'}]
         self.mock_object(self._driver.service_instance_manager,
                          'set_up_service_instance',
                          mock.Mock(side_effect=raise_exception))
@@ -1332,7 +1331,9 @@ class GenericShareDriverTestCase(test.TestCase):
             'qos', 'driver_version', 'share_backend_name',
             'free_capacity_gb', 'total_capacity_gb',
             'driver_handles_share_servers',
-            'reserved_percentage', 'vendor_name', 'storage_protocol',
+            'reserved_percentage', 'reserved_snapshot_percentage',
+            'reserved_share_extend_percentage',
+            'vendor_name', 'storage_protocol',
         ]
 
         result = self._driver.get_share_stats(True)
