@@ -16,11 +16,10 @@ Unit tests for Veritas Manila driver.
 """
 import hashlib
 import json
+from unittest import mock
 
-import mock
 from oslo_config import cfg
 import requests
-import six
 
 from manila import context
 from manila import exception
@@ -142,6 +141,8 @@ class ACCESSShareDriverTestCase(test.TestCase):
         self.configuration.replication_domain = 'Disable'
         self.configuration.filter_function = 'Disable'
         self.configuration.goodness_function = 'Disable'
+        self.configuration.max_shares_per_share_server = -1
+        self.configuration.max_share_server_size = -1
 
     def test_create_share(self):
         self.mock_object(self._driver, '_get_va_share_name')
@@ -187,8 +188,8 @@ class ACCESSShareDriverTestCase(test.TestCase):
         sharepath = self._driver._get_va_share_path(sharename)
         self._driver._get_vip.return_value = '1.1.1.1'
         vip = self._driver._get_vip()
-        location = (six.text_type(vip) + ':' +
-                    six.text_type(sharepath) + ':' + six.text_type(snapname))
+        location = (str(vip) + ':' +
+                    str(sharepath) + ':' + str(snapname))
 
         ret = self._driver.create_share_from_snapshot(self._context,
                                                       self.share,
@@ -430,6 +431,8 @@ class ACCESSShareDriverTestCase(test.TestCase):
             'total_capacity_gb': 10,
             'free_capacity_gb': 9,
             'reserved_percentage': 0,
+            'reserved_snapshot_percentage': 0,
+            'reserved_share_extend_percentage': 0,
             'QoS_support': False,
             'create_share_from_snapshot_support': True,
             'driver_handles_share_servers': False,
@@ -443,7 +446,10 @@ class ACCESSShareDriverTestCase(test.TestCase):
             'replication_domain': 'Disable',
             'revert_to_snapshot_support': False,
             'share_group_stats': {'consistent_snapshot_support': None},
-            'snapshot_support': True
+            'snapshot_support': True,
+            'security_service_update_support': False,
+            'share_server_multiple_subnet_support': False,
+            'network_allocation_update_support': False,
         }
 
         self.assertEqual(data, self._driver._stats)
