@@ -140,7 +140,9 @@ class ShareDriverTestCase(test.TestCase):
             'qos', 'driver_version', 'share_backend_name',
             'free_capacity_gb', 'total_capacity_gb',
             'driver_handles_share_servers',
-            'reserved_percentage', 'vendor_name', 'storage_protocol',
+            'reserved_percentage', 'reserved_snapshot_percentage',
+            'reserved_share_extend_percentage',
+            'vendor_name', 'storage_protocol',
             'snapshot_support', 'mount_snapshot_support',
         ]
         share_driver = driver.ShareDriver(True, configuration=conf)
@@ -622,7 +624,7 @@ class ShareDriverTestCase(test.TestCase):
             'nondisruptive': False,
             'preserve_snapshots': False,
             'migration_cancel': False,
-            'migration_get_progress': False
+            'migration_get_progress': False,
         }
 
         driver_compatibility = (
@@ -945,6 +947,62 @@ class ShareDriverTestCase(test.TestCase):
         self.assertIsNone(share_group_update)
         self.assertEqual(expected_share_updates, share_update)
 
+    def test_update_share_server_security_service(self):
+        share_driver = self._instantiate_share_driver(None, True)
+        self.assertRaises(NotImplementedError,
+                          share_driver.update_share_server_security_service,
+                          'fake_context',
+                          {'id', 'share_server_id'},
+                          {'fake', 'fake_net_info'},
+                          [{"id": "fake_instance_id"}],
+                          [{"id": "fake_rule_id"}],
+                          {'id', 'fake_sec_service_id'},
+                          current_security_service=None)
+
+    def test_check_update_share_server_security_service(self):
+        share_driver = self._instantiate_share_driver(None, True)
+        self.assertRaises(
+            NotImplementedError,
+            share_driver.check_update_share_server_security_service,
+            'fake_context',
+            {'id', 'share_server_id'},
+            {'fake', 'fake_net_info'},
+            [{"id": "fake_instance_id"}],
+            [{"id": "fake_rule_id"}],
+            {'id', 'fake_sec_service_id'},
+            current_security_service=None)
+
+    def test_check_update_share_server_network_allocations(self):
+        share_driver = self._instantiate_share_driver(None, True)
+        self.assertRaises(
+            NotImplementedError,
+            share_driver.check_update_share_server_network_allocations,
+            'fake_context',
+            {'id', 'share_server_id'},
+            {'admin_network_allocations': [], 'subnets': []},
+            {"id": "fake_subnet_id"},
+            [{"id": "fake_security_service_id"}],
+            [{'id', 'fake_share_instance_id'}],
+            [{"id": "fake_rule_id"}])
+
+    def test_update_share_server_network_allocations(self):
+        share_driver = self._instantiate_share_driver(None, True)
+        self.assertRaises(
+            NotImplementedError,
+            share_driver.update_share_server_network_allocations,
+            'fake_context',
+            {'id', 'share_server_id'},
+            {'admin_network_allocations': [], 'subnets': []},
+            {
+                'share_network_subnet_id': 'fake_share_network_subnet_id',
+                'neutron_net_id': 'fake_neutron_net_id',
+                'neutron_subnet_id': 'fake_neutron_subnet_id',
+                'network_allocations': []
+            },
+            [{"id": "fake_security_service_id"}],
+            [{"id": "fake_share_id"}],
+            [{"id": "fake_snapshot_id"}])
+
     def test_create_share_group_from_sg_snapshot_with_no_members(self):
         share_driver = self._instantiate_share_driver(None, False)
         fake_share_group_dict = {}
